/*******************************************************************************
Comparison of Winning and Losing Bids in Bidding Treatment Localities
1Data/dofiles/analysis/summ_bids_winner_loser.do

Summarize bid characteristics, by winners/losers
*******************************************************************************/

** SETUP AND MACROS *******************************************************

clear all
set more off

cd "$RASKIN"

****************************
* 1. Input data 
****************************

u "1Data/codeddata/competition/bidders", clear
merge m:1 commid using "1Data/codeddata/competition/biddingrejection"
drop _m
keep if winner!=.
tempfile winners_losers
sa `winners_losers'

****************************
* 2. Output summary table 
****************************

** Setup/Locals
local outfile "$RASKIN_TABLES/appendixtable13.summ_bids_winner_loser"

local outcomes price_dist pay_before pay_during pay_after ///
		deliver_village deliver_subvillage deliver_household dist_credit
format `outcomes' %10.2fc
local n : word count `outcomes'
	
forv i = 1/3 { //Panel A, B, or C
	est clear
	u `winners_losers', clear
	
	* 3 Panels: All Bidding Villages, Open Bidding, Min # Bids
	local panel		 : word `i' of "Panel A: " "Panel B: " "Panel C: "
	local and		 : word `i' of "" "&" "&"
	local if		 : word `i' of "" "if" "if"
	local condition  : word `i' of "" "tr_nomin==1" "tr_minbids==1" 
	local cond_title : word `i' of "Bids in All Bidding Localities" "Bids in Regular Bidding Localities" "Bids in Localities with Min # Bids"
	local c			 : word `i' of "all" "nomin" "min"

	* Number of bids and villages
	qui count `if' `condition' 
	local n_bids = `r(N)'
	bys commid: gen n_vals = _n == 1
	qui count if n_vals `and' `condition'
	local n_villages = `r(N)'
	
	* Summary stats: Winner vs. Loser
	foreach win in 1 0 {
		eststo `c'_`win': estpost summ `outcomes' if winner == `win' `and' `condition'
	}
		
	* P-Value: Winner = Loser, clustered by village
	forv i=1/`n' {
		local v : word `i' of `outcomes'
		local o = `i'+3
		qui reg `v' winner `if' `condition', cl(hhea)
		test winner = 0
		local `c'_t_`o' = `r(p)'
	}

	* Create Table
	tempfile table

	# delimit ;
	esttab `c'_1 `c'_0
		using `table',
		title("`panel'`cond_title' (`n_bids' bids in `n_villages' villages)")
		starlevels(* 0.10 ** 0.05 *** 0.01) 
		cells(`"mean(label("Mean") fmt(%10.2fc))
				sd(label("Std. Dev.") fmt(%10.2fc))
				count(label("Observations") fmt(%10.0fc))"'
		)
		mtitles("Winners" "Losers")
		noobs nonum label replace csv
		;
	# delimit cr

	* Clean Table
	insheet using `table', comma clear

	foreach type in "Mean" "Std. Dev." {
		foreach var of varlist _all {
			quietly count if `var' != "`type'" & `var' != ""
			if `r(N)' <= 1 {
				drop `var'
			}
		}
	}
	
	* Add P-Value clustered by village
	gen ttest_`c' = .
	format ttest_`c' %10.2fc
	forv i=1/`n' {
		local o = `i'+3
		replace ttest_`c' = ``c'_t_`o'' in `o'
	}

	//Generate Stars
	gen star_`c'	= ""
	replace star_`c'= "*" 		if ttest_`c' <.1
	replace star_`c'= "**" 		if ttest_`c' <.05
	replace star_`c'= "***" 	if ttest_`c' <.01

	//Format Values
	tostring ttest_`c', replace usedisplayformat force

	//Add Stars
	replace ttest_`c' = ttest_`c'+star_`c' 
	drop star_`c' 

	replace ttest_`c' = "P-Value" in 2
	replace ttest_`c' = "Winners = Losers" in 3
	
	* Export      **************************************************************
	export excel "`outfile'", sheet(`c') sheetrep
 } //Closes i loop (which panel/locality sample)

 
 
