/*******************************************************************************
Who Distributes Raskin Six Months After Intervention? 
By Women Quota and Enhanced Supervision Subtreatments
1Data/dofiles/analysis/enhanced_women_who_distributes.do

Comparing characteristics of Raskin distributors, across subtreatments
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

** INPUT DATA ******************************************************************

** Grab Data
u "1Data/codeddata/competition/distributors", clear
keep if current_dist==1
egen combined_sub_off = rowmax(relative_sub_off_dist sub_off_dist)

** Shortened Labels
la var pg04_olddist_any "In charge of any responsibilities before May 2013"
la var own_village_dist "Lives in village"
la var off_dist "Distributor/spouse is/was village official"
la var relative_off_dist "Distributor/spouse is related to village official"
la var combined_sub_off "Distributor/spouse is/was or is related to subvillage official"
la var trader_dist "Is a trader"

la var vehicle_dist "Owns truck and/or boat"
la var digitspan_hi "Avg Digit Span above median"
la var high_points "Raw dice score above median"
la var yred_dist "Years of education"
la var savings_dist "Has personal savings account for business"

** Treatment Variables
//Enhanced Supervision
gen biddingorinfo_enh 	= TR2c==1 | TR2e==1 //enhanced supervision subtreatment of bidding or info treatment
gen biddingorinfo_noenh = (TR2c==0 & tr_dist==1) | (TR2e==0 & tr_moni==1) //non-enhanced supervision subtreatment of bidding or info treatment
gen bidding_enh 		= TR2c==1
gen bidding_noenh 		= TR2c==0 & tr_dist==1

la var biddingorinfo_enh 	"Enhanced Supervision" 
la var biddingorinfo_noenh 	"No Enhanced Supervision" 
la var bidding_enh			"Enhanced Supervision"
la var bidding_noenh		"No Enhanced Supervision"

//Women Quota
gen biddingorinfo_wqta 	= TR2b==1 | TR2d==1 //women quota subtreatment of bidding or info treatment
gen biddingorinfo_noqta = (TR2b==0 & tr_dist==1) | (TR2d==0 & tr_moni==1) //no women quota for bidding or info treatment
gen bidding_wqta  		= TR2b==1
gen bidding_noqta 		= TR2b==0 & tr_dist==1

la var biddingorinfo_wqta  	"Women Quota" 
la var biddingorinfo_noqta 	"No Women Quota" 
la var bidding_wqta 		"Women Quota"
la var bidding_noqta		"No Women Quota"

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
local outfile "$RASKIN_TABLES/appendixtable4a.enhanced_women_who_distributes.xml"

** Run!	
local bidding 	  "bidding_wqta"			
local no_bidding   "bidding_noqta"	
local biddingorinfo	 "biddingorinfo_wqta"		
local no_biddingorinfo "biddingorinfo_noqta"
local tr		"Women"		
local treat		"Women Quota"	

local outcomes  "pg04_olddist_any off_dist relative_off_dist combined_sub_off trader_dist own_village_dist" 
local sheet	"A"

est clear
local num = 0
local names
foreach v of varlist `outcomes' { //Loop through outcomes
	local ++num
				
	** Run Regression
	eststo `v', title("(`num')") : ///
		areg `v'  `no_biddingorinfo' `biddingorinfo' `no_bidding' `bidding', a(strata_simple)
	
	** P-Values
	test `biddingorinfo' = `no_biddingorinfo'
	local test3_4 = `r(p)'
	
	test `bidding' = `no_bidding'
	local test1_2 = `r(p)'
	
	test `bidding' + `biddingorinfo' = 0
	local test1_3 = `r(p)'
	
	test `no_bidding' + `no_biddingorinfo' = 0
	local test2_4 = `r(p)'

	estadd scalar pval_info_subs 	= `test3_4'
	estadd scalar pval_bidding_subs = `test1_2'
	estadd scalar pval_nosub0 		= `test2_4'
	estadd scalar pval_sub0			= `test1_3'
	
	local pvalxml pval_info_subs pval_bidding_subs //pval_nosub0 pval_sub0
				
	** Add Control Mean
	qui summ `v' if e(sample) & TR2_2013 == 1
	local m0 = `r(mean)'
	estadd scalar ymean_ctl = `r(mean)'
	
	** Formatting
	if inlist("`v'","subsidy_rcvd","markup_hh") local dec = "0"
	else local dec = "3"
	local clab : var l `v'
	local names `" `names' `"`: var l `v''"' "'
	local cellfmt `cellfmt' (SCCR0 NCCR`dec' NCCR2)	
	
} //closes outcome loop (v)
		
** Export sheets for each specification to one file using xml_tab
# delimit ;
xml_tab *,
	save("`outfile'")
	replace sheet(`tr'_`sheet') 
	title("Who Distributes Raskin Six Months After Intervention?, by `treat' Subtreatment")
	cnames(`names')
	showeq
	below
	keep(`no_biddingorinfo' `biddingorinfo' `no_bidding' `bidding')
	stats(`pvalxml' ymean_ctl)
	rblanks(COL_NAMES "Info or Bidding", `biddingorinfo' "Bidding", `bidding' "P-Value")
	;
# delimit cr				


