/*******************************************************************************
Raskin Distribution Process
By Women Quota and Enhanced Supervision Subtreatments
1Data/dofiles/analysis/enhanced_women_effect_on_process.do

Household-level regressions on Raskin distribution process, across subtreatments
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

** PREP DATA *******************************************************************

** Grab Data
use "1Data/codeddata/competition/endmidcs1", clear

** Treatment Variables
//Enhanced Supervision
gen biddingorinfo_enh 	= TR2c==1 | TR2e==1 //enhanced supervision subtreatment of bidding or info treatment
gen biddingorinfo_noenh = (TR2c==0 & tr_dist==1) | (TR2e==0 & tr_moni==1) //non-enhanced supervision subtreatment of bidding or info treatment
gen bidding_enh 		= TR2c==1
gen bidding_noenh 		= TR2c==0 & tr_dist==1

la var biddingorinfo_enh 	"Enhanced Supervision" 
la var biddingorinfo_noenh 	"No Enhanced Supervision" 
la var bidding_enh			"Enhanced Supervision"
la var bidding_noenh		"No Enhanced Supervision"

//Women Quota
gen biddingorinfo_wqta 	= TR2b==1 | TR2d==1 //women quota subtreatment of bidding or info treatment
gen biddingorinfo_noqta = (TR2b==0 & tr_dist==1) | (TR2d==0 & tr_moni==1) //no women quota for bidding or info treatment
gen bidding_wqta  		= TR2b==1
gen bidding_noqta 		= TR2b==0 & tr_dist==1

la var biddingorinfo_wqta  	"Women Quota" 
la var biddingorinfo_noqta 	"No Women Quota" 
la var bidding_wqta 		"Women Quota"
la var bidding_noqta		"No Women Quota"

** Construct fake baseline controls so loop will run (all the same--> omitted)
g satis_qual_cat01_f2 = 1
g satis_qual_cat01_f_mis = 1
	
** Shortened Labels
la var bought_last2m 	"Bought Raskin"
la var markup_hh 		"Price markup"
la var amtraskin 		"Amount purchased"
la var satis_qual_cat01 "Satisfied with rice quality"
la var distance 		"Distance to purchase point (meters)"
la var time 			"Time to purchase point (minutes)"
la var pay_adv 			"Paid for rice in advance" 
la var satis_prog_cat01	"Satisfied with Raskin program"

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
local outfile "$RASKIN_TABLES/appendixtable4b.enhanced_women_effect_on_process.xml"
local outcomes bought_last2m markup_hh amtraskin ///
  satis_qual_cat01 distance time pay_adv satis_prog_cat01
local sortlist tr_dist tr_moni 	
local cellfmt 

** Run!  
local bidding 	 "bidding_wqta"  	
local no_bidding   	"bidding_noqta" 	
local biddingorinfo		"biddingorinfo_wqta"    	
local no_biddingorinfo "biddingorinfo_noqta"  
local tr	 	"Women"				 
local treat		"Women Quota"			 

est clear
local num = 0
local names
foreach v of varlist `outcomes'{ //Loop through outcomes
	local ++num
	local hhcontrol
	cap conf v `v'_f2
			
	** Run Regression
	eststo `v', title("(`num')") : ///
	  areg `v'  `no_biddingorinfo' `biddingorinfo' `no_bidding' `bidding' `v'_f2 `v'_f_mis ///
		i.sample, cl(hhea) a(strata_simple)
					
	** P-Values
	test `biddingorinfo' = `no_biddingorinfo'
	local test3_4 = `r(p)'
	
	test `bidding' = `no_bidding'
	local test1_2 = `r(p)'
	
	test `bidding' + `biddingorinfo' = 0
	local test1_3 = `r(p)'
	
	test `no_bidding' + `no_biddingorinfo' = 0
	local test2_4 = `r(p)'

	estadd scalar pval_bidding_subs = `test1_2'
	estadd scalar pval_info_subs 	= `test3_4'
	estadd scalar pval_nosub0 		= `test2_4'
	estadd scalar pval_sub0			= `test1_3'
	
	local pvalxml pval_info_subs pval_bidding_subs //pval_nosub0 pval_sub0
	
	** Add Control Mean
	qui summ `v' if e(sample) & TR2_2013 == 1
	local m0 = `r(mean)'
	estadd scalar ymean_ctl = `r(mean)'
						
	** Formatting
	if inlist("`v'","subsidy_rcvd_kab","markup_hh") local dec = "0"
	else local dec = "3"
	local clab : var l `v'
	local names `" `names' `"`: var l `v''"' "'
	local cellfmt `cellfmt' (SCCR0 NCCR`dec' NCCR2)

} //closes outcome loop (v)
				
** Export sheets for each specification to one file using xml_tab
# delimit ;
xml_tab *,
	save("`outfile'")
	replace sheet(`tr') 
	title("Effects on Rice Distribution Process, by `treat' Subtreatment")
	cnames(`names')
	showeq
	below
	keep(`no_biddingorinfo' `biddingorinfo' `no_bidding' `bidding')
	stats(`pvalxml' N ymean_ctl)
	format((SCLR0) `cellfmt')
	rblanks(COL_NAMES "Info or Bidding", `biddingorinfo' "Bidding", `bidding' "P-Value")
	;
# delimit cr				


