/*******************************************************************************
Randomization Checks (with Randomization Inference Joint P-Values)
1Data/dofiles/analysis/rand_check_comp.do

NB: village officials and sub-village officials come from Midline Community Survey RD05.
*******************************************************************************/

** SETUP AND MACROS ************************************************************
clear all
set more off
set matsize 1600
set maxvar 31000

cd "$RASKIN"

********************************************************************************
** 0. Data Prep **
********************************************************************************

** VARIABLES
local hhvars ///
  logconsumption_f yredhhhead_f bought_last2m_f markup_hh_f amtraskin_f  ///
  subsidy_f satis_hh_f excl_error_f incl_error_f
local village_vars ///
  distance_kec_t2 pctagri_t2 lognumberhh_f yredrthead_f ///
  village_off_f sub_off_f

local vars `hhvars' `village_vars'

** DATA
u "1Data/codeddata/competition/endmidcs1", clear
preserve
	keep tr_* TR2* sample strata hhea
	assert sample!=99
	replace sample = 99 //no sample for village level observations
	duplicates drop
	isid hhea
	merge 1:1 hhea using "1Data/codeddata/competition/rand_check_village" 
	assert _m==3
	drop _m
	tempfile village
	sa `village'
restore
append using `village'

cap drop subsidy_rcvd_f
rename subsidy_rcvd_kab_f subsidy_f

destring hhea, gen(hhea_des)
replace desa_id2 = hhea if mi(desa_id2)

keep `vars' tr_* TR2* sample strata desa_id2 hhea_des

tab strata, gen(group_strat)
tab sample, gen(group_samp)

cap gen tr_any = tr_dist==1 | tr_moni==1

tempfile data
sa `data'
	
********************************************************************************
** 1. MAIN TABLE OUTPUT **
********************************************************************************

** Setup/Locals
local outfile "$RASKIN_TABLES/appendixtable6ab.rand_check_comp"

** Get Data	
est clear
u `data', clear

** Create Table Framework
gen title = "Baseline Summary Statistics and Randomization Checks for Main Treatments" in 1
forv i = 1/7{
	local lab: word `i' of "N" "Control" "Bidding" "Information" "Bidding" "Information" "Difference"
	local name: word `i' of N Control Bidding Information StratumFEd StratumFEm Difference
	gen `name' = "`lab'" in 3
	replace `name' = "(`i')" in 4
}

** More Locals for Regressions
local j = 5
local k = 6

local firstvar	: word 1 of `vars'
local last		: word count `vars'
local lastvar	: word `last' of `vars'
local allbutlast: list vars - lastvar
local allbutlast: list allbutlast - firstvar

display "`allbutlast'"
foreach v in `vars'{
	** Variable Name
	display "`: var l `v''"
	replace title = "`: var l `v''" in `j'
	
	** Control Group Mean
	sum `v' if TR2_2013 == 1
	local mean 		= round(`r(mean)',.01)
	replace Control = "`mean'" in `j'

	** Bidding Mean
	sum `v' if tr_dist == 1
	local mean 		= round(`r(mean)',.01)
	replace Bidding = "`mean'" in `j'
	
	** Info Mean
	sum `v' if tr_moni == 1
	local mean 			= round(`r(mean)',.01)
	replace Information = "`mean'" in `j'
	
	** Number of Observations, Standard Error, P-Value
	xi: reg `v' tr_dist tr_moni i.sample i.strata_simple, cl(hhea)
	
	//Number of Obs
	replace N 	= "`e(N)'" in `j'						
	
	//Save Coefficients
	local c_d 	= round(_b[tr_dist],.01)				
	local c_m 	= round(_b[tr_moni],.01)
	
	//Save SE
	local se_d 	= round(_se[tr_dist],.01)				
	local se_m 	= round(_se[tr_moni],.01)
	
	//P-Value
	local p_d 	= 2 * ttail(e(df_r),abs(_b[tr_dist] / _se[tr_dist]))
	local p_m 	= 2 * ttail(e(df_r),abs(_b[tr_moni] / _se[tr_moni]))
	
	//Stars
	local stars_d
		if `p_d' < 0.10 local stars_d = "*" 
		if `p_d' < 0.05 local stars_d = "**" 
		if `p_d' < 0.01 local stars_d = "***"
	local stars_m
		if `p_m' < 0.10 local stars_m = "*" 
		if `p_m' < 0.05 local stars_m = "**" 
		if `p_m' < 0.01 local stars_m = "***"	
	
	//Coefficient Row
	replace StratumFEd 	= "`c_d'" + "`stars_d'" in `j'
	replace StratumFEm 	= "`c_m'" + "`stars_m'" in `j'
	
	//SE Row
	replace StratumFEd = "(" + "`se_d'" + ")" in `k' 	
	replace StratumFEm = "(" + "`se_m'" + ")" in `k' 	
	
	** Test of Bidding = Info
	lincom tr_dist-tr_moni								//Test Bidding = Info	
	local c 	= round(`r(estimate)',.01)
	local se 	= round(`r(se)',.01)
	local p 	=  2 * ttail( `r(df)', abs( `r(estimate)' / `r(se)' ))
	local stars
		if `p' 	< 0.10 local stars = "*" 
		if `p' 	< 0.05 local stars = "**" 
		if `p' 	< 0.01 local stars = "***"
		
	replace Difference = "`c'"+"`stars'"  	in `j'
	replace Difference = "(" + "`se'" + ")" in `k'	

	** Update Locals for Loop
	local j = `j' + 2
	local k = `k' + 2
	
	** Store Results for Joint Test
	eststo StratumFEd_`v': xi: reg `v' tr_dist tr_moni i.sample i.strata_simple 
	eststo StratumFEm_`v': xi: reg `v' tr_dist tr_moni i.sample i.strata_simple 	 
	eststo Difference_`v': xi: reg `v' tr_dist tr_moni i.sample i.strata_simple 	
}

local j = `j' + 1
local k = `j' + 1

** Joint test
forv y = 1/3 {
	local type : word `y' of StratumFEd StratumFEm Difference

	* Note: suest requires us to add "_mean" after estimation results
	suest `type'_* , cluster(hhea)

	if "`type'"=="StratumFEd" {
		test _b[`type'_`firstvar'_mean: tr_dist] 	= 0, notest
		foreach v in `allbutlast' {
		test _b[`type'_`v'_mean: tr_dist] 			= 0, notest accum
		}
		test _b[`type'_`lastvar'_mean: tr_dist] 	= 0, accum
			
		local chi2 = round(`r(chi2)',.01)
		local pval = round(`r(p)',.01)
		replace StratumFEd = "`chi2'" in `j' 
		replace StratumFEd = "`pval'" in `k'
	}
	
	else if "`type'"=="StratumFEm" {
		test _b[`type'_`firstvar'_mean: tr_moni] 	= 0, notest
		foreach v in `allbutlast' {
		test _b[`type'_`v'_mean: tr_moni] 			= 0, notest accum
		}
		test _b[`type'_`lastvar'_mean: tr_moni] 	= 0, accum
		
		local chi2 = round(`r(chi2)',.01)
		local pval = round(`r(p)',.01)
		replace StratumFEm = "`chi2'" in `j' 
		replace StratumFEm = "`pval'" in `k'
	}
	
	else if "`type'"=="Difference" {
		test _b[`type'_`firstvar'_mean: tr_dist] 	= _b[`type'_`firstvar'_mean: tr_moni], 	notest
		foreach v in `allbutlast' {
		test _b[`type'_`v'_mean: tr_dist] 			= _b[`type'_`v'_mean: tr_moni], 		notest accum
		}
		test _b[`type'_`lastvar'_mean: tr_dist] 	= _b[`type'_`lastvar'_mean: tr_moni], 	accum
		
		local chi2 = round(`r(chi2)',.01)
		local pval = round(`r(p)',.01)
		replace Difference = "`chi2'" in `j' 
		replace Difference = "`pval'" in `k'
	}
}

replace title = "Chi square, joint significance" in `j'		
replace title = "P-value, joint significance" in `k'	

** SAVE
keep title - Difference
replace Control = "Means" in 2
replace StratumFEd = ///
"Difference Between Treatment and Control, with Stratum FE" in 2
keep in 1/`k'

export excel "`outfile'", sheet("rand_check_main") sheetrep

********************************************************************************
** 2. SUBTREATMENT TABLE OUTPUT **
********************************************************************************

** Get Data
est clear
u `data', clear

** Create Table Framework
cap gen tr_nomin = TR2a == 0 if !mi(TR2a)
cap gen tr_minbids = TR2a
gen title = "Baseline Summary Statistics and Randomization Checks for Bidding Subtreatment" in 1
forv i = 1/4{
	local lab: word `i' of "N" "Open Bids" "Min # Bids" "Difference"
	local name: word `i' of N Open Min StratumFEm
	gen `name' = "`lab'" in 3
	replace `name' = "(`i')" in 4
}

** More Locals for Regressions
local Treatment	MinBids
local treat		TR2a 
local col		m
local num		
local j = 5
local k = 6

local firstvar	: word 1 of `vars'
local last		: word count `vars'
local lastvar	: word `last' of `vars'
local allbutlast: list vars - lastvar
local allbutlast: list allbutlast - firstvar

foreach v in `vars'{
	** Variable Name
	display "`: var l `v''"
	replace title = "`: var l `v''" in `j'
	
	** Open Bidding Mean
	qui sum `v' 	if tr_nomin == 1
	local mean 		= round(`r(mean)',.01)
	replace Open 	= "`mean'" in `j'
	
	** Min # Bids Mean
	qui sum `v' 	if tr_minbids == 1
	local mean 		= round(`r(mean)',.01)
	replace Min		= "`mean'" in `j'
	
	** Test Difference
	xi: reg `v' `treat' i.sample i.strata_simple if tr_dist==1, cl(hhea)
	replace N 		= "`e(N)'" in `j'				
	local c 		= round(_b[`treat'],.01)
	local se 		= round(_se[`treat'],.01)
	local p 		= 2 * ttail(e(df_r),abs(_b[`treat'] / _se[`treat']))
	
	local stars
		if `p' < 0.10 local stars = "*" 
		if `p' < 0.05 local stars = "**" 
		if `p' < 0.01 local stars = "***"
		
	replace StratumFE`col' = "`c'" + "`stars'" 	in `j'	
	replace StratumFE`col' = "(" + "`se'" + ")" in `k'	
	
	** Store Results for Joint Test
	eststo StratumFE`col'_`v': xi: reg `v' `treat' i.sample i.strata_simple if tr_dist==1

	local j = `j' + 2
	local k = `k' + 2
}
local j = `j' + 1
local k = `j' + 1

** Joint test	
foreach type in StratumFE`col' {
	suest `type'_* , cluster(hhea)
	
	* suest requires us to add "_mean" after estimation results
	test _b[`type'_`firstvar'_mean: `treat'] 	= 0, notest
	foreach v in `allbutlast' {
	test _b[`type'_`v'_mean: `treat'] 			= 0, notest accum
	}
	test _b[`type'_`lastvar'_mean: `treat'] 	= 0, accum
	
	local chi2 = round(`r(chi2)',.01)
	local pval = round(`r(p)',.01)
	replace `type' = "`chi2'" in `j' 
	replace `type' = "`pval'" in `k'
}

replace title = "Chi square, joint significance" in `j'		
replace title = "P-value, joint significance" in `k'	

** SAVE	
keep title - StratumFEm
replace Open = "Means" in 2
replace StratumFEm = ///
	"Difference Between Min # Bids and Open Bidding, with Stratum FE" in 2
keep in 1/`k'

export excel "`outfile'", sheet("rand_check_subtr") sheetrep


****************************
** 3. RI Joint Test **
****************************.
/* This gives us the RI joint p-value for all treatments and subtreatments */

** CREATE DATA
u "1Data/codeddata/competition/rerandomization", clear
merge 1:m desa_id2 using `data'
assert _m==3
drop _m
saveold "1Data/codeddata/competition/balance_rerandomization", replace
gen p_d 	= .
gen p_m 	= .
gen p_dif 	= .
gen p_min 	= .

local iterations = 1000

qui forv i =1/`iterations'{
	timer on 1
	
	local j = `i'
	est clear

	local firstvar	: word 1 of `vars'
	local last		: word count `vars'
	local lastvar	: word `last' of `vars'
	local allbutlast: list vars - lastvar
	local allbutlast: list allbutlast - firstvar

	foreach v in `vars' {
		eststo StratumFEd_`v'	: xi: reg `v' tr_dist_`i' tr_moni_`i' 	i.sample i.strata_simple 	
		eststo StratumFEm_`v'	: xi: reg `v' tr_dist_`i' tr_moni_`i' 	i.sample i.strata_simple 	
		eststo Difference_`v'	: xi: reg `v' tr_dist_`i' tr_moni_`i' 	i.sample i.strata_simple
		eststo Minbids_`v'		: xi: reg `v' TR2a_`i' 					i.sample i.strata_simple if tr_dist_`i'==1
	}

	//Joint test	
	forv y = 1/4 {
		local type : word `y' of StratumFEd StratumFEm Difference Minbids
		
		* suest requires us to add "_mean" after estimation results
		suest `type'_* , cluster(desa_id2)
		
		if "`type'"=="StratumFEd" {
			test _b[`type'_`firstvar'_mean: tr_dist_`i'] 	= 0, notest
			foreach v in `allbutlast' {
			test _b[`type'_`v'_mean: tr_dist_`i'] 			= 0, notest accum
			}
			test _b[`type'_`lastvar'_mean: tr_dist_`i']		= 0, accum
				
			replace p_d 	= `r(p)' in `j'
		}
		
		else if "`type'"=="StratumFEm" {
			test _b[`type'_`firstvar'_mean: tr_moni_`i'] 	= 0, notest
			foreach v in `allbutlast' {
			test _b[`type'_`v'_mean: tr_moni_`i'] 			= 0, notest accum
			}
			test _b[`type'_`lastvar'_mean: tr_moni_`i'] 	= 0, accum
			
			replace p_m 	= `r(p)' in `j'
		}
		
		else if "`type'"=="Difference" {
			test _b[`type'_`firstvar'_mean: tr_dist_`i'] 	= _b[`type'_`firstvar'_mean: tr_moni_`i'], 	notest
			foreach v in `allbutlast' {
			test _b[`type'_`v'_mean: tr_dist_`i'] 			= _b[`type'_`v'_mean: tr_moni_`i'], 		notest accum
			}
			test _b[`type'_`lastvar'_mean: tr_dist_`i'] 	= _b[`type'_`lastvar'_mean: tr_moni_`i'], 	accum
			
			replace p_dif 	= `r(p)' in `j'
		}
		
		else if "`type'"=="Minbids" {
			test _b[`type'_`firstvar'_mean: TR2a_`i'] 		= 0, notest
			foreach v in `allbutlast' {
			test _b[`type'_`v'_mean: TR2a_`i'] 				= 0, notest accum
			}
			test _b[`type'_`lastvar'_mean: TR2a_`i'] 		= 0, accum
			
			replace p_min 	= `r(p)' in `j'
		}
		
	}
	
	timer off 1
	noi timer list 1
}	

keep p_*

keep in 1/`iterations'

//P-Values from original randomization
foreach v of varlist p_* {
	local orig_`v' = `v' in 1
	gen `v'_0 = `orig_`v'' if !mi(`v')
}

//More Unlikely in Data than Original
foreach v of varlist p_d p_m p_dif p_min {
	gen `v'_moreunlikely = `v'_0 > `v' if !mi(`v'_0) & !mi(`v') //p-value greater under original randomization than iterations
}

//Variable Labels
forv i = 1/4 {
	local var  : word `i' of  d m dif min
	local name : word `i' of  "Bidding" "Info" "Bidding - Info" "Min Bids"
	la var p_`var' "P-Value for `name' from Re-randomizations"
	la var p_`var'_0 "P-Value for `name' from Original Randomization"
	la var p_`var'_moreunlikely "P-val for `name' from orig rand > p-val for `name' from re-rand"
}

saveold "1Data/codeddata/competition/RI_pval", replace

** EXPORT RI JOINT TEST VALUES
u "1Data/codeddata/competition/RI_pval", clear
est clear

forv i = 1/4 {
	local var  : word `i' of  d m dif min
	local name : word `i' of  "Bidding Joint Test" "Info Joint Test" "Bidding - Info Joint Test" "Min Bids Joint Test"
	gen `var'_joint = ""
	qui summ p_`var'_moreunlikely
	local mean = round(`r(mean)',.01)
	replace `var'_joint = "`mean'" in 2
	replace `var'_joint = "`name'" in 1
}

** SAVE
keep *_joint
keep in 1/2

export excel "`outfile'", ///
	sheet("rand_check_RI_joint") sheetrep


	
