/*******************************************************************************
Raskin Distribution Process
1Data\dofiles\analysis\effect_on_process.do

Household-level regressions on Raskin distribution process.	
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
set maxvar 32700

cd "$RASKIN"

** PREP DATA *******************************************************************

** Grab Data
use "1Data/codeddata/competition/endmidcs1", clear

** Construct dummy baseline controls so loop will run (all the same--> omitted)
g satis_qual_cat01_f2 = 1
g satis_qual_cat01_f_mis = 1

** Shortened Labels
la var bought_last2m 	"Bought Raskin"
la var markup_hh 		"Price markup"
la var amtraskin 		"Amount purchased"
la var satis_qual_cat01 "Satisfied with rice quality"
la var distance 		"Distance to purchase point (meters)"
la var time 			"Time to purchase point (minutes)"
la var pay_adv 			"Paid for rice in advance" 
la var satis_prog_cat01	"Satisfied with Raskin program"

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

rename tr_nomin tr_nominbids

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
*local outfile "$RASKIN_TABLES/effect_on_process.xml"
local outcomes bought_last2m markup_hh amtraskin ///
  satis_qual_cat01 distance time pay_adv satis_prog_cat01

  
** Run!  
forv i = 1/3 { //Sample: All Households, Eligibles, or Inelgibles
	
	
	local condition	: word `i' of "" "if eligible == 1" "if eligible == 0"
	local elig_title: word `i' of "All Eligibility" "Eligible" "Ineligible"
	local e			: word `i' of All Elig Inel
				
	forv j = 1/2 { //Controls
		local hhc_title : word `j' of "with controls" "without controls"
		local h			: word `j' of Ctl Nctl
				
		forv l = 1/2 { //Panel A or B
			local tr_dist		: word `l' of "tr_dist"     "tr_nominbids tr_minbids"
			local tr_title		: word `l' of "Panel A: Combined Effect of Outsourcing" "Panel B: Estimating Additional Efect of Competition"
			local tr			: word `l' of MAIN MIN
			local rblanks 		: word `l' of "tr_dist P-Value" "tr_minbids P-Value"						
			
			if ("`e'"=="All") | ("`h'"=="Ctl") { //Only want to run certain specification combinations
				/* 	Table 3: All eligibility, with baseline controls
					Appendix Table 6: All eligibility, without baseline controls 
					Appendix Table 7A: Eligibiles only, with baseline controls
					Appendix Table 7B: Ineligibiles only, with baseline controls */
					
				est clear
				local num = 0
				local names
				
				foreach v of varlist `outcomes' { //Loop through outcomes
					local ++num
					local hhcontrol
					local cellfmt
					
					** Confirm we have baseline variables (if used)
					cap conf v `v'_f2
					if !_rc local hhcontrol : word `j' of "`v'_f2 `v'_f_mis" ""
					else if "`hhc_title'" == "with controls" continue
				
				
				* Run Randomization inference p-value
				
				* generate estimates for calculating RI p-values
				if "`tr_dist'" =="tr_dist" {
				
					** Run Regression
					display "i = `i'; j = `j'; l = `l'"
					*eststo `v', title("(`num')") : ///
					
					areg `v' tr_monidist `tr_dist' `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
					  
					    scalar breg        =  _b[tr_monidist]
						scalar breg_dist   =  _b[`tr_dist']
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						lincom tr_monidist +`tr_dist'
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(join r(estimate) se_join r(se))
				
				}
				
				
			    if "`tr_dist'"=="tr_nominbids tr_minbids" {
				
					** Run Regression
					display "i = `i'; j = `j'; l = `l'"
					eststo `v', title("`v'") : ///
					areg `v' tr_monidist tr_nominbids tr_minbids `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
					  
					    scalar breg              =  _b[tr_monidist]
						scalar breg_nominbids    =  _b[tr_nominbids]
						scalar breg_minbids      =  _b[tr_minbids]
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))

						lincom tr_minbids - tr_nominbids
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onetwo r(estimate) se_1_2 r(se))

						lincom tr_minbids + tr_monidist 
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onethree r(estimate) se_1_3 r(se))
						
						lincom tr_nominbids + tr_monidist
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(twothree r(estimate) se_2_3 r(se))
								
				
				}	
				
				
				}
				
				if "`tr'"=="MIN" {
				esttab using "$RASKIN/2Output/tables/table3appendixtable78ab.effect_onprocess_NOri`tr'_`h'_`e'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_1_2 pval_1_3 pval_2_3 mean sd N, labels("P value tr_minbids-tr_nominbids" "P value tr_minbids+tr_monidist" "P value tr_nominbids+tr_monidist" "control mean") layout(@ @ @ "@ @" @)) replace csv mtitles

				
				}
				
				if "`tr'"=="MAIN" {
				esttab using "$RASKIN/2Output/tables/table3appendixtable78ab.effect_onprocess_NOri`tr'_`h'_`e'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_join mean sd N, labels("P value tr_monidist+tr_dist" "control mean") layout(@ "@ @" @)) replace csv mtitles

				}
				
				
				
				}
				
				 
				
				}
				
				}
				
				
                
				
				}

