/*******************************************************************************
Raskin Distribution Process
1Data\dofiles\analysis\effect_on_process.do

Household-level regressions on Raskin distribution process.	
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
set maxvar 32700

cd "$RASKIN"

** PREP DATA *******************************************************************

** Grab Data
use "1Data/codeddata/competition/endmidcs1", clear

** Construct dummy baseline controls so loop will run (all the same--> omitted)
g satis_qual_cat01_f2 = 1
g satis_qual_cat01_f_mis = 1

** Shortened Labels
la var bought_last2m 	"Bought Raskin"
la var markup_hh 		"Price markup"
la var amtraskin 		"Amount purchased"
la var satis_qual_cat01 "Satisfied with rice quality"
la var distance 		"Distance to purchase point (meters)"
la var time 			"Time to purchase point (minutes)"
la var pay_adv 			"Paid for rice in advance" 
la var satis_prog_cat01	"Satisfied with Raskin program"

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

*merge with alreay made data for rerandomization
merge m:1 desa_id2 using "1Data/codeddata/competition/rerandomization_5000", assert(match)
drop _merge

local nrand 5000


*drop unused variables to save memory
*drop TR2b* TR2c* TR2d* TR2e*

*create tr_monidist for rerandomization
forvalue i= 1/`nrand' {

gen tr_monidist_`i'=tr_moni_`i' ==1 | tr_dist_`i'==1       
	   
	}

drop tr_moni_* //to save memory

*rename TR2a==1 to be trminbids for randomization inference
forvalue i= 1/`nrand' {

gen tr_minbids_`i'=1 if TR2a_`i' ==1

replace tr_minbids_`i'=0 if TR2a_`i' ==0 | TR2a_`i' ==.

}


*rename TR2a==0 to be tr_nominbids for randomization inference
forvalue i= 1/`nrand' {

gen tr_nominbids_`i'=1 if TR2a_`i' ==0

replace tr_nominbids_`i'=0 if TR2a_`i' ==1 | TR2a_`i' ==.
      }

rename tr_nomin tr_nominbids

drop TR2a_* //to save memory 


*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval(real) indvar(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar'" 

matrix pval[1,1]=`pval' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Define a program for generating p value from Rand Inference
* when given list of betas from fake treatment assignments
*************************************************************

cap prog drop ri_pval 
program define ri_pval, rclass // Name of the command
	args ri_ests act_est
	
	preserve
	use `ri_ests', clear
	local nrand = _N
	keep if abs(b)> abs(`=`act_est'')
	if _N==0{
		local b_p= 0.001
		}
	else {
		local b_p = _N / `nrand' 
		}
	restore
	return scalar pval = `b_p'

end


** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
*local outfile "$RASKIN_TABLES/effect_on_process.xml"
local outcomes bought_last2m markup_hh amtraskin ///
  satis_qual_cat01 distance time pay_adv satis_prog_cat01

  
** Run!  
forv i = 1/3 { //Sample: All Households, Eligibles, or Inelgibles
	
	
	local condition	: word `i' of "" "if eligible == 1" "if eligible == 0"
	local elig_title: word `i' of "All Eligibility" "Eligible" "Ineligible"
	local e			: word `i' of All Elig Inel
				
	forv j = 1/2 { //Controls
		local hhc_title : word `j' of "with controls" "without controls"
		local h			: word `j' of Ctl Nctl
				
		forv l = 1/2 { //Panel A or B
			local tr_dist		: word `l' of "tr_dist"     "tr_nominbids tr_minbids"
			local tr_title		: word `l' of "Panel A: Combined Effect of Outsourcing" "Panel B: Estimating Additional Efect of Competition"
			local tr			: word `l' of MAIN MIN
			local rblanks 		: word `l' of "tr_dist P-Value" "tr_minbids P-Value"						
			
			if ("`e'"=="All") | ("`h'"=="Ctl") { //Only want to run certain specification combinations
				/* 	Table 3: All eligibility, with baseline controls
					Appendix Table 6: All eligibility, without baseline controls 
					Appendix Table 7A: Eligibiles only, with baseline controls
					Appendix Table 7B: Ineligibiles only, with baseline controls */
					
				est clear
				local num = 0
				local names
				
				foreach v of varlist `outcomes' { //Loop through outcomes
					local ++num
					local hhcontrol
					local cellfmt
					
					** Confirm we have baseline variables (if used)
					cap conf v `v'_f2
					if !_rc local hhcontrol : word `j' of "`v'_f2 `v'_f_mis" ""
					else if "`hhc_title'" == "with controls" continue
				
				
				* Run Randomization inference p-value
				
				* generate estimates for calculating RI p-values
				if "`tr_dist'" =="tr_dist" {
				
				tempname rand_inf
				tempfile rand_inf_ests
				postfile `rand_inf' b using `rand_inf_ests', replace
				
				tempname rand_inf_dist
				tempfile rand_inf_ests_dist
				postfile `rand_inf_dist' b using `rand_inf_ests_dist', replace
				
				tempname rand_inf_join
				tempfile rand_inf_ests_join
				postfile `rand_inf_join' b using `rand_inf_ests_join', replace
				
				
				forval i = 1/`nrand' {
				
				local tr_dist_inf   : word `l' of "tr_dist_`i'"
				 areg `v' tr_monidist_`i' `tr_dist_inf' `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
		        post `rand_inf'        (_b[tr_monidist_`i'])
				post `rand_inf_dist'   (_b[tr_dist_`i'])
	            
				scalar p = _b[tr_monidist_`i'] + _b[tr_dist_`i']
		        post `rand_inf_join' (p)
				
				}
	            postclose `rand_inf'
				postclose `rand_inf_dist'
				postclose `rand_inf_join'
				
					** Run Regression
					display "i = `i'; j = `j'; l = `l'"
					*eststo `v', title("(`num')") : ///
					
					areg `v' tr_monidist `tr_dist' `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
					  
					    scalar breg        =  _b[tr_monidist]
						scalar breg_dist   =  _b[`tr_dist']
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						
						ri_pval `rand_inf_ests' breg
						matrix pval_tr_monidist = (r(pval))
	                    matrix colnames pval_tr_monidist = tr_monidist
						
						
						ri_pval `rand_inf_ests_dist' breg_dist
	                    matrix pval_tr_dist = (r(pval))
	                    matrix colnames pval_tr_dist = tr_dist
						
						
						matrix pval = (pval_tr_monidist,pval_tr_dist)
	                    estadd matrix pval
						*matlist pval
						
						
						lincom tr_monidist +`tr_dist'
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(join r(estimate) se_join r(se))
						ri_pval `rand_inf_ests_join' r(estimate)
						matrix pval_join = (r(pval))
						eststo `v', add(pval_join r(pval))

				
				}
				
				
			    if "`tr_dist'"=="tr_nominbids tr_minbids" {
				
				tempname rand_inf
				tempfile rand_inf_ests
				postfile `rand_inf' b using `rand_inf_ests', replace
				
				tempname rand_inf_nominbids
				tempfile rand_inf_ests_nominbids
				postfile `rand_inf_nominbids' b using `rand_inf_ests_nominbids', replace
				
				tempname rand_inf_minbids
				tempfile rand_inf_ests_minbids
				postfile `rand_inf_minbids' b using `rand_inf_ests_minbids', replace
				
				tempname rand_inf_1_2
				tempfile rand_inf_ests_1_2
				postfile `rand_inf_1_2' b using `rand_inf_ests_1_2', replace
				
				tempname rand_inf_1_3
				tempfile rand_inf_ests_1_3
				postfile `rand_inf_1_3' b using `rand_inf_ests_1_3', replace
				
				tempname rand_inf_2_3
				tempfile rand_inf_ests_2_3
				postfile `rand_inf_2_3' b using `rand_inf_ests_2_3', replace
				
				
				
				forval i = 1/`nrand' {
				
				*local tr_dist_inf   : word `l' of "tr_nominbids_`i' tr_minbids_`i'"
				qui areg `v' tr_monidist_`i' tr_nominbids_`i' tr_minbids_`i' `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
		        
				post `rand_inf'             (_b[tr_monidist_`i'])
				post `rand_inf_nominbids'   (_b[tr_nominbids_`i'])
				post `rand_inf_minbids'     (_b[tr_minbids_`i'])
	            
				scalar p = _b[tr_minbids_`i'] - _b[tr_nominbids_`i']
		        post `rand_inf_1_2' (p)
				
				scalar p = _b[tr_minbids_`i'] + _b[tr_monidist_`i']
		        post `rand_inf_1_3' (p)
				
				scalar p = _b[tr_nominbids_`i'] + _b[tr_monidist_`i']
		        post `rand_inf_2_3' (p)
				
				
				
				}
	            postclose `rand_inf'
				postclose `rand_inf_nominbids'
				postclose `rand_inf_minbids'
				postclose `rand_inf_1_2'
				postclose `rand_inf_1_3'
				postclose `rand_inf_2_3'
				
					** Run Regression
					display "i = `i'; j = `j'; l = `l'"
					eststo `v', title("`v'") : ///
					areg `v' tr_monidist tr_nominbids tr_minbids `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
					  
					    scalar breg              =  _b[tr_monidist]
						scalar breg_nominbids    =  _b[tr_nominbids]
						scalar breg_minbids      =  _b[tr_minbids]
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						
						ri_pval `rand_inf_ests'    breg
					    matrix pval_tr_monidist = (r(pval))
	                    matrix colnames pval_tr_monidist = tr_monidist
						
						ri_pval `rand_inf_ests_nominbids' breg_nominbids
						matrix pval_tr_nominbids = (r(pval))
	                    matrix colnames pval_tr_nominbids = tr_nominbids
						
						ri_pval `rand_inf_ests_minbids' breg_minbids
						matrix pval_tr_minbids = (r(pval))
	                    matrix colnames pval_tr_minbids = tr_minbids
						
						
						matrix pval = (pval_tr_monidist,pval_tr_nominbids,pval_tr_minbids)
	                    estadd matrix pval 
						
					

						lincom tr_minbids - tr_nominbids
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onetwo r(estimate) se_1_2 r(se))
						ri_pval `rand_inf_ests_1_2' r(estimate)
						matrix pval_1_2 = (r(pval))
						eststo `v', add(pval_1_2 r(pval))
						
						lincom tr_minbids + tr_monidist 
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onethree r(estimate) se_1_3 r(se))
						ri_pval `rand_inf_ests_1_3' r(estimate)
						matrix pval_1_3 = (r(pval))
						eststo `v', add(pval_1_3 r(pval))
						
						lincom tr_nominbids + tr_monidist
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(twothree r(estimate) se_2_3 r(se))
						ri_pval `rand_inf_ests_2_3' r(estimate)
						matrix pval_2_3 = (r(pval))
						eststo `v', add(pval_2_3 r(pval))
								
				
				}	
				
				
				}
				
				if "`tr'"=="MIN" {
				esttab using "$RASKIN/2Output/tables/table3appendixtable78ab.effect_onprocess_ri`tr'_`h'_`e'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_1_2 pval_1_3 pval_2_3 mean sd N, labels("P value tr_minbids-tr_nominbids" "P value tr_minbids+tr_monidist" "P value tr_nominbids+tr_monidist" "control mean") layout(@ @ @ "@ @" @)) replace csv mtitles

				
				}
				
				if "`tr'"=="MAIN" {
				esttab using "$RASKIN/2Output/tables/table3appendixtable78ab.effect_onprocess_ri`tr'_`h'_`e'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_join mean sd N, labels("P value tr_monidist+tr_dist" "control mean") layout(@ "@ @" @)) replace csv mtitles

				}
				
				
				
				}
				
				 
				
				}
				
				}
				
				
                
				
				}

				use `rand_inf_ests', clear
				count
eststo clear
