/*******************************************************************************
Endline Costs to Current Distributor
1Data\dofiles\analysis\distributor_cost.do

Does treatment decrease distributor costs?
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
set maxvar 32700

cd "$RASKIN"

** GET DATA ********************************************************************
** Grab Data
u "1Data/codeddata/competition/current_distributor_costs.dta", clear
merge m:1 hhea using "1Data/codeddata/competition/good_strata"
assert _m==3
drop _merge

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

** Cost Coding

** Drop if Missing All Cost Data
egen rownonmiss = rownonmiss(total_transport_cost total_other_cost compensation_cost)
drop if rownonmiss == 0
drop rownonmiss

** Fill Missings with 0, if At Least One Cost Exists
foreach x in total_transport_cost total_other_cost compensation_cost {
	replace `x' = 0 if `x'==.
}

** Total Costs incurred by distributor
egen total_cost = rowtotal(total_transport_cost total_other_cost compensation_cost), missing
la var total_cost "Total costs of distribution (Rp)"

** Topcoding
foreach x in total_transport_cost total_other_cost compensation_cost total_cost {
	summ `x', d
	replace `x' = . if `x' > `r(p99)'
}


*merge with already made data for rerandomization
merge m:1 desa_id2 using "1Data/codeddata/competition/rerandomization_5000"

keep if _merge==3
drop _merge

local nrand 5000
*create tr_monidist for rerandomization
forvalue i= 1/`nrand' {

gen tr_monidist_`i'=tr_moni_`i' ==1 | tr_dist_`i'==1       
	   
	}

drop tr_moni_* //to save memory

*rename TR2a==1 to be trminbids for randomization inference
forvalue i= 1/`nrand' {

gen tr_minbids_`i'=1 if TR2a_`i' ==1

replace tr_minbids_`i'=0 if TR2a_`i' ==0 | TR2a_`i' ==.

}


*rename TR2a==0 to be tr_nominbids for randomization inference
forvalue i= 1/`nrand' {

gen tr_nominbids_`i'=1 if TR2a_`i' ==0

replace tr_nominbids_`i'=0 if TR2a_`i' ==1 | TR2a_`i' ==.
      }

rename tr_nomin tr_nominbids

drop TR2a_* //to save memory 

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval(real) indvar(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar'" 

matrix pval[1,1]=`pval' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Define a program for generating p value from Rand Inference
* when given list of betas from fake treatment assignments
*************************************************************

cap prog drop ri_pval 
program define ri_pval, rclass // Name of the command
	args ri_ests act_est
	
	preserve
	use `ri_ests', clear
	local nrand = _N
	keep if abs(b)> abs(`=`act_est'')
	if _N==0{
		local b_p= 0.001
		}
	else {
		local b_p = _N / `nrand' 
		}
	restore
	return scalar pval = `b_p'

end



** REGRESSION ******************************************************************

** Setup/Locals
*local outfile "$RASKIN_TABLES/distributor_costs.xml"	
local outcomes total_transport_cost compensation_cost total_other_cost total_cost

** Run!
forv x = 1/2 { //Panel A or B
	local tr_dist	: word `x' of "tr_dist" "tr_nominbids tr_minbids"
	local tr	: word `x' of main minbids
	local apprep	: word `x' of replace append
	local rblanks	: word `x' of "tr_dist P-Value" "tr_nomin P-Value"
			
	est clear
	local num = 0
	local names
	
	
	if `x'==1 {
	
	foreach v of varlist `outcomes'{ //Loop through outcomes
		local ++num
					
		** Run Randomization inference     
			    tempname rand_inf
				tempfile rand_inf_ests
				postfile `rand_inf' b using `rand_inf_ests', replace
				
				tempname rand_inf_dist
				tempfile rand_inf_ests_dist
				postfile `rand_inf_dist' b using `rand_inf_ests_dist', replace
				
				tempname rand_inf_join
				tempfile rand_inf_ests_join
				postfile `rand_inf_join' b using `rand_inf_ests_join', replace
			   
			 
			   forval i = 1/`nrand' {
			    areg `v' tr_monidist_`i' tr_dist_`i', a(strata_simple) robust
			    post `rand_inf'        (_b[tr_monidist_`i'])
			    post `rand_inf_dist'   (_b[tr_dist_`i'])
	            
				scalar p = _b[tr_monidist_`i'] + _b[tr_dist_`i']
		        post `rand_inf_join' (p)
			   
			   }
			    postclose `rand_inf'
				postclose `rand_inf_dist'
				postclose `rand_inf_join'
		
		
		** Run Regression
		eststo `v', title("`v'") : ///
			areg `v' tr_monidist tr_dist, a(strata_simple) robust	
		    scalar breg        =  _b[tr_monidist]
			scalar breg_dist   =  _b[tr_dist]
		
		 *Add control mean
			    summ `v' if e(sample) == 1 & TR2_2013 == 1
				eststo `v', add(mean r(mean) sd r(sd))
			
			*P values 
			   ri_pval `rand_inf_ests' breg
			   matrix pval_tr_monidist = (r(pval))
	           matrix colnames pval_tr_monidist = tr_monidist
						
						
			   ri_pval `rand_inf_ests_dist' breg_dist
	           matrix pval_tr_dist = (r(pval))
	           matrix colnames pval_tr_dist = tr_dist
						
						
			   matrix pval = (pval_tr_monidist,pval_tr_dist)
	           estadd matrix pval
			  
						
						
			  lincom tr_monidist + tr_dist
						
			   
			   ri_pval `rand_inf_ests_join' r(estimate)
			   matrix pval_join = (r(pval))
			   eststo `v', add(pval_join r(pval))
		
			
			}
		
		
		esttab using "$RASKIN/2Output/tables/distributor_cost_`tr'_5k.csv", se keep(tr_monidist tr_dist) cells("b se pval") stat(pval_join mean sd N, labels("P value tr_monidist+tr_dist" "control mean") layout(@ "@ @" @)) replace csv mtitles

		
		
		
		
		/** P-Values		
		
			test tr_dist + tr_monidist = 0
			local test_dif = `r(p)'
			
			estadd scalar pval_diff = `test_dif'
			local pvalxml pval_diff */
		
		
		}
		
		
		
		if `x'==2 { //Panel B
			
		foreach v of varlist `outcomes' {
		local ++num 
			
			*Run randomization inference 
				tempname rand_inf
				tempfile rand_inf_ests
				postfile `rand_inf' b using `rand_inf_ests', replace
				
				tempname rand_inf_nominbids
				tempfile rand_inf_ests_nominbids
				postfile `rand_inf_nominbids' b using `rand_inf_ests_nominbids', replace
				
				tempname rand_inf_minbids
				tempfile rand_inf_ests_minbids
				postfile `rand_inf_minbids' b using `rand_inf_ests_minbids', replace
				
				tempname rand_inf_1_2
				tempfile rand_inf_ests_1_2
				postfile `rand_inf_1_2' b using `rand_inf_ests_1_2', replace
				
				tempname rand_inf_1_3
				tempfile rand_inf_ests_1_3
				postfile `rand_inf_1_3' b using `rand_inf_ests_1_3', replace
				
				tempname rand_inf_2_3
				tempfile rand_inf_ests_2_3
				postfile `rand_inf_2_3' b using `rand_inf_ests_2_3', replace
				
				forval i = 1/`nrand' {
				
				qui areg `v' tr_monidist_`i' tr_nominbids_`i' tr_minbids_`i' , a(strata_simple) robust
				
		        
				post `rand_inf'             (_b[tr_monidist_`i'])
				post `rand_inf_nominbids'   (_b[tr_nominbids_`i'])
				post `rand_inf_minbids'     (_b[tr_minbids_`i'])
	            
				scalar p = _b[tr_minbids_`i'] - _b[tr_nominbids_`i']
		        post `rand_inf_1_2' (p)
				
				scalar p = _b[tr_minbids_`i'] + _b[tr_monidist_`i']
		        post `rand_inf_1_3' (p)
				
				scalar p = _b[tr_nominbids_`i'] + _b[tr_monidist_`i']
		        post `rand_inf_2_3' (p)
				
				
				
				}
	            postclose `rand_inf'
				postclose `rand_inf_nominbids'
				postclose `rand_inf_minbids'
				postclose `rand_inf_1_2'
				postclose `rand_inf_1_3'
				postclose `rand_inf_2_3'
				
				** Run Regression
					
					eststo `v', title("`v'") : ///
					areg `v' tr_monidist tr_nominbids tr_minbids, a(strata_simple) robust
					  
					    scalar breg              =  _b[tr_monidist]
						scalar breg_nominbids    =  _b[tr_nominbids]
						scalar breg_minbids      =  _b[tr_minbids]
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						
						ri_pval `rand_inf_ests'    breg
					    matrix pval_tr_monidist = (r(pval))
	                    matrix colnames pval_tr_monidist = tr_monidist
						
						ri_pval `rand_inf_ests_nominbids' breg_nominbids
						matrix pval_tr_nominbids = (r(pval))
	                    matrix colnames pval_tr_nominbids = tr_nominbids
						
						ri_pval `rand_inf_ests_minbids' breg_minbids
						matrix pval_tr_minbids = (r(pval))
	                    matrix colnames pval_tr_minbids = tr_minbids
						
						
						matrix pval = (pval_tr_monidist,pval_tr_nominbids,pval_tr_minbids)
	                    estadd matrix pval 
						

						lincom tr_minbids - tr_nominbids
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onetwo r(estimate) se_1_2 r(se))
						ri_pval `rand_inf_ests_1_2' r(estimate)
						matrix pval_1_2 = (r(pval))
						eststo `v', add(pval_1_2 r(pval))
						
						lincom tr_minbids + tr_monidist 
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onethree r(estimate) se_1_3 r(se))
						ri_pval `rand_inf_ests_1_3' r(estimate)
						matrix pval_1_3 = (r(pval))
						eststo `v', add(pval_1_3 r(pval))
						
						lincom tr_nominbids + tr_monidist
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(twothree r(estimate) se_2_3 r(se))
						ri_pval `rand_inf_ests_2_3' r(estimate)
						matrix pval_2_3 = (r(pval))
						eststo `v', add(pval_2_3 r(pval))
				
				}
			
			
			
		esttab using "$RASKIN/2Output/tables/table4.distributor_cost_`tr'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_1_2 pval_1_3 pval_2_3 mean sd N, labels("P value tr_minbids-tr_nominbids" "P value tr_minbids+tr_monidist" "P value tr_nominbids+tr_monidist" "control mean") layout(@ @ @ "@ @" @)) replace csv mtitles


		}
					
		}
