
/*******************************************************************************
Where Did Original Distributor Win and Continue Distributing?
1Data\dofiles\analysis\where_old_different_cond.do

3 Sections: 
- 1. Where was no bidding meeting held, or meeting had no bids?
- 2. Where did original distributor win?
	(conditional on holding bidding meeting with 1+ bid)
- 3. Where is original distributor still distributing?
	(conditional on original distributor not winning)
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
eststo clear
cd "$RASKIN"

** INPUT DATA ******************************************************************

** Baseline HH Perception of Corruption -- only ask about locality head
use "$TARGET2/Baseline/hh_kpi.dta",clear
*rename kpi02c corruption_head
gen corruption_head=kpi02c
recode corruption_head (7 8 =.)
replace corruption_head=(corruption_head-1)/3 
gen hhea = substr(hhid,1,3)
collapse corruption*, by(hhea)
tempfile baseline
sa `baseline'

** Baseline variables from household survey (averaged at village level)
u "1Data/codeddata/competition/endmidcs1", clear
keep if tr_dist==1 
collapse bought_last2m_f markup_hh_f amtraskin_f ///
			 satis_prog_cat01_f distance_f pay_adv_f strata_simple, by(hhea)
la var markup_hh_f "Avg Price Markup (Rp/kg)"
la var satis_prog_cat01_f "Avg Satisfaction with Program Quality (0-1 scale)"
la var bought_last2m_f "HH Bought Raskin in Last 2 Months"
la var amtraskin_f "Avg Amount of Raskin Purchased (kg)"
la var distance_f "Avg Distance to Purchase Point (meters)"
la var pay_adv_f "HH purchased Raskin in advance"

merge 1:1 hhea using "1Data/codeddata/competition/biddingrejection"
gen multiplebidders = n_bidders > 1 & !mi(n_bidders)
assert _m==3
drop _m

** Data on Old Bidders
merge 1:1 commid using "1Data/codeddata/competition/old_dist_vars"
assert tr_dist!=1 if _m==2
drop if _m==2
assert _m==3
drop _m

** Recode costs in 10,000s of Rp
foreach var in transport_cost other_cost {
	replace `var' = `var'/10000
}

** Want this to be unconditional --> code old_win = 1 if bidding not held/no bids
replace old_win = 1 if reject_bidding==1 | reject_nobids==1 | return_sq==1
tab old_win, mi

replace reject_bidding = 1 if reject_nobids==1

** Merge in locality corruption score
merge 1:1 hhea using `baseline'
drop _m

** Create and save temp file
tempfile reject_bidding
sa `reject_bidding' //Section 1 data

** Conditioning
keep if reject_bidding==0
tempfile old_win
sa `old_win' //Section 2 data

** Is new distributor the same as distributor at baseline?
/* current_old is based on matching current distributor name to 
	distributor name at the start of facilitation, from form data */
preserve	
	u "1Data/codeddata/competition/distributors", clear
	keep if tr_dist==1 
	keep if current_dist==1
	keep if pr_id2=="0" //original villages only
	keep hhea current_old
	tempfile dist
	sa `dist'
restore

cap drop current_old
merge 1:1 hhea using `dist'
drop _m

** Conditioning
keep if old_win==0
tempfile current_old
sa `current_old' //Section 3 data

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
local outfile "$RASKIN_TABLES/table5.56.where_old_different_cond_corrupt.xml"

** Run!
local LHS	"current_old"
local LHS_sheet	"Current"
local LHS_title  "Where is Original Distributor Still Distributing?"					
local method 	 "Logistic Regression" 
local method_sheet  "Logit_NoFE"
local type	 	 "logit" 

//load in data
u ``LHS'', clear

** Predictors
local hh_vars 		markup_hh_f bought_last2m_f amtraskin_f satis_prog_cat01_f distance_f pay_adv_f
local form_vars 	corruption_head dist_credit transport_cost other_cost 

est clear

forv i = 1/4 { //columns: which predictors do we include?
	local type_sheet 		: word `i' of "one_by_one" "hh_vars" "form_vars" "all"
	local independent_vars  : word `i' of "`hh_vars' `form_vars'" ///
		"`hh_vars'" "`form_vars'" "`hh_vars' `form_vars'"
		
	local names
	local cellfmt (SCCR0 NCCR3 NCCR3)
	
	** Run Regression	
	if `i'==1 { //run 1-by-1 regressions
		foreach v of varlist `independent_vars' { 
			eststo `v', title("(`num')") : ///
			`type' `LHS' `v', robust
		}
	}
	else { //predictors: hh variables, survey variables, or both
		eststo `type_sheet', title("(`num')") : ///
			`type' `LHS' `independent_vars', robust
	}

	* add joint p-values
	if `i' == 2 { //hh variables only (column 2/6/10)
		test bought_last2m_f 		= markup_hh_f, 			notest 
		test markup_hh_f 			= amtraskin_f, 			notest accum
		test amtraskin_f 			= satis_prog_cat01_f, 	notest accum
		test satis_prog_cat01_f 	= distance_f, 			notest accum
		test distance_f 			= pay_adv_f, 			notest accum
		test pay_adv_f				= 0, 					accum
		estadd scalar pval_joint	= `r(p)'
	}
	
	if `i' == 3 { //form variables only (column 3/7/11)
		test corruption_head			= dist_credit, 			notest
		test dist_credit 			= transport_cost, 		notest accum
		test transport_cost			= other_cost, 			notest accum
		test other_cost				= 0,					accum
		estadd scalar pval_joint 	= `r(p)'
	}
	
	if `i' == 4 { //all variables (column 4/8/12)
		test bought_last2m_f 		= markup_hh_f, 			notest
		test markup_hh_f 			= amtraskin_f, 			notest accum
		test amtraskin_f 			= satis_prog_cat01_f, 	notest accum
		test satis_prog_cat01_f 	= distance_f, 			notest accum
		test distance_f 			= pay_adv_f, 			notest accum
		test pay_adv_f 				= corruption_head, 			notest accum
		test corruption_head		= dist_credit, 			notest accum
		test dist_credit 			= transport_cost, 		notest accum
		test transport_cost 		= other_cost, 			notest accum
		test other_cost				= 0,					accum
		estadd scalar pval_joint	= `r(p)'
	}			
	
	** Add Baseline Mean
	qui summ `LHS' if e(sample)
	estadd scalar ymean = `r(mean)'
	
	} //closes i loop (columns/which predictors do we include?)

** Export sheet using xml_tab **************************************************
# delimit ;
xml_tab *,
	save("`outfile'") replace
	sheet("`LHS_sheet'`method_sheet'") 
	title("`LHS_title',"
	"Estimated `method'")
	cnames("1-by-1" "" "" "" "" "" "" "" "" ""
	"Joint (Household Only)" "Joint (Form Only)" "Joint (All)")
	showeq
	below
	drop(_cons)
	format((SCLR0) `cellfmt')
	rblanks(COL_NAMES, pay_adv_f)
	stats(pval_joint N ymean)
	;
# delimit cr



