**********************************************
**********************************************
* Extra coding relative to the TNP2K presentations
/* Info on village officials, knowledge about Raskin 
	eligibility status, and sample weights. 

There are two weights options: 
	fs (full sample) and cs1 (cs1-comparable sample).
	fs  - all CS1 and all midline observations
	cs1 - drop sample A from midline and exclude PKH ineligibles from CS1 (1127) and midline (608)
*/
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

*************************************
** 1.2. Add info on officials and informal leaders
*************************************

* get midline to SW crosswalk (see section SW in the survey)
u "1Data/originaldata/2_Midline/crosswalk_midline_all.dta", clear
duplicates drop hhid_sm, force
keep hhid_midline hhid_sm 
tempfile cross
sa `cross'

*** get officials in the village
use "1Data/originaldata/TargetingIIData/Baseline/hh_cr00.dta", clear

drop cr06*

forv i=1/5{
	rename cr05a`i'_jbt  cr05a_jbt`i'
	rename cr05a`i'_krt  cr05a_krt`i'
	rename cr05a`i'_hhid cr05a_hhid`i'
	rename cr05b`i'_jbt  cr05b_jbt`i'
	rename cr05b`i'_krt  cr05b_krt`i'
	rename cr05b`i'_hhid cr05b_hhid`i'
}

reshape long cr05a_jbt  cr05a_krt cr05a_hhid cr05b_jbt  ///
			  cr05b_krt cr05b_hhid, i(hhid)

* village officials in the baseline (identified by others)
preserve
	drop cr05b_jbt cr05b_krt cr05b_hhid
	drop cr05a_krt
	* drop non-officials from here
	foreach v in F G H I J K L{
		replace cr05a_jbt="" if cr05a_jbt=="`v'"
	}
	drop if cr05a_jbt==""
	g temp = substr(hhid,1,3)
	replace cr05a_hhid= temp + cr05a_hhid
	drop temp
	
	gen one=1
	bys  cr05a_hhid: egen nhits=sum(one)
	drop if nhits<3
	
	* take the most common position 
	bys cr05a_hhid: egen off_pos_base=mode(cr05a_jbt), maxmode 
	
	contract off_pos_base cr05a_hhid
	
	* numerize
	replace off_pos_base="1" if off_pos_base!=""
	encode off_pos_base , gen(temp)
	drop off_pos_base
	rename temp off_base 
	
	drop _freq
	isid  cr05a_hhid
	rename cr05a_hhid hhid_sm	
	merge 1:1 hhid_sm using `cross'
	drop if _m==2
	drop if hhid_midline==""
	drop _m hhid_sm
	
	tempfile official_base
	sa `official_base'
restore

* village officials in the midline (self-declared)
preserve
	use "1Data/originaldata/2_Midline/hh_pm2.dta", clear
	
	* keep only self and same household observations
	keep if pm02==4 | pm03=="A"
	
	keep  hhid pm2type
	rename pm2type off_pos_mid
	rename hhid hhid_midline
	
	* numerize
	replace off_pos_mid="1" if off_pos_mid!=""
	encode off_pos_mid, gen(temp)
	drop off_pos_mid
	rename temp off_mid
	
	duplicates drop hhid, force
	
	tempfile official_mid
	sa `official_mid'
restore

* village informal leaders	
preserve
	drop cr05a_jbt cr05a_krt cr05a_hhid
	drop cr05b_krt
	* drop officials from here
	foreach v in A B C D E{
	replace cr05b_jbt="" if cr05b_jbt=="`v'"
	}
	drop if cr05b_jbt==""
	g temp = substr(hhid,1,3)
	replace cr05b_hhid= temp + cr05b_hhid
	drop temp
	
	* take the most common position 
	bys cr05b_hhid: egen ldr_pos_base=mode(cr05b_jbt), maxmode 
	
	contract ldr_pos_base cr05b_hhid
		
	* numerize
	replace ldr_pos_base="1" if ldr_pos_base!=""
	encode ldr_pos_base, gen(temp)
	drop ldr_pos_base
	rename temp ldr_base

	drop _freq
	isid  cr05b_hhid
	rename cr05b_hhid hhid_sm	
	merge 1:1 hhid_sm using `cross'
	drop if _m==2
	drop if hhid_midline==""
	drop _m hhid_sm
	
	tempfile leader
	sa `leader'
restore

*****************************
* 1.3. Combine with midline data (for all HHs that were originally sampled)
*****************************

u "1Data/originaldata/2_Midline/crosswalk_midline.dta", clear

*** add village leader information
merge 1:1 hhid_midline using `official_base'
drop if _m==2
drop _m

merge 1:1 hhid_midline using `official_mid'
assert _m!=2
drop _m

merge 1:1 hhid_midline using `leader'
drop if _m==2
drop _m
	

keep hhid_midline off_base off_mid ldr_base
	
tempfile heads
save `heads'

****************************
* 1.4. Coding knowledge variables - midline
****************************

* outcome 7a/b: HH knows correct status of other households
preserve
	
* get real types
	u "1Data/originaldata/2_Midline/crosswalk_midline.dta", clear
	
	merge 1:1 hhid_midline using `heads'
	count if _m!=3
	assert `r(N)'<=0
	drop _m
	
	rename hhid_midline sw03_hhid		
	gen status=(hhid_udb!="")
	
	keep  sw03_hhid off_base off_mid ldr_base status
	
	tempfile types
	sa `types'

* get respondent beliefs about Raskin status of other households
	u "1Data/originaldata/2_Midline/hh_sw4.dta", clear
	g temp = substr(hhid,1,3)
	replace sw03_hhid = temp+sw03_hhid
	drop temp
		
	merge m:1 sw03_hhid using `types'
	assert _m!=1
	drop if _m==2
	drop _m	
	
* r = respondent, t = target
	rename hhid hhid_r_mid
	rename sw03_hhid hhid_t_mid
	
	merge 1:1 hhid_r_mid hhid_t_mid using "1Data/codeddata/cards_paper/paper/beliefs_family.dta"
	assert _m!=1
	drop if _m==2
	drop _m
	
* generate vars using all matched real types
	g dkstatusoth = sw03==8		
	replace sw03 = 1 if sw03==2
	replace sw03 = 3 if sw03==4
	replace sw03 = 0 if sw03==3
	replace sw03 = . if sw03==8	
	assert sw03==0 | sw03==1 | sw03==.
	
* How are "Don't know" treated?
* The first set of variables codes that as an error		
* The second set of variables (ending in _d) drops those observations

* generate vars separately by target type	
	g knowstatusothr   = sw03==status 
	g knowstatusothr_d = knowstatusothr  
	replace knowstatusothr_d = . if dkstatusoth==1
	la var knowstatusothr "Respondent knows other's status, DK = 0"
	la var knowstatusothr_d "Respondent knows other's status, DK = ."
	
	rename off_base off_base_t
	rename off_mid  off_mid_t
	rename ldr_base ldr_base_t
	rename status status_t
	
	drop  sw03_no
	
	rename sw03 thinkspoor
		
	tempfile knowstatus_mid`
	sa `knowstatus_mid'
		
restore

* merge - drop old variables and add new ones
u "1Data/codeddata/cards_paper/midline/combined_mid.dta",clear
drop  knowstatusothr*
rename hhid hhid_midline

merge 1:1 hhid_midline using `heads'
assert _m!=1
keep if _m==3
drop _m

rename off_base off_base_r
rename off_mid  off_mid_r
rename ldr_base ldr_base_r

rename hhid_midline hhid

*************
* 1.5 sample comparability
*************
* PKH restrictions
preserve
	use "1Data/originaldata/2_Midline/hh_ar1.dta", clear
	* time of baseline T2 - Dec 2010 - Feb 2011

	* exclude babies born after sept/2011 and teens who were 16 in dec 2010
	gen tooyoung = (ar04a_m < 19)
	gen tooold   = (ar04a_yr >= 18)
	
	gen temp = !tooyoung & !tooold
	by hhid: egen pkhelig = sum(temp)
	replace pkhelig = pkhelig>0

	duplicates drop hhid, force
	keep hhid pkhelig
	tempfile pkhelig
	sa `pkhelig'
restore

merge 1:1 hhid using `pkhelig'
count if _m!=3
assert `r(N)'<=1
drop _m

tab jpal_id pkh, m row //nofreq

* exclude PKH ineligibles from the CS1 comparable
replace analysis_2=. if pkhelig==0
replace analysis_2=0 if analysis_2==.

* lose around 500 obs per weight type
foreach suf in CvC ENH B10 PRC CPN{
	replace weight_cs1_`suf'=. if analysis_2==0
}

***************************************
*** SAVE MIDLINE VERSION
***************************************

saveold "1Data/codeddata/cards_paper/paper/combined.dta", replace


***********************
* 2.1. Prepare CS1 data
***********************
u "1Data/codeddata/cards_paper/CombinedVP.dta", clear	

*generate (simplify) sample variable
gen sam = 3
replace sam = 2 if sample==3
replace sam = 1 if sample==1
drop sample 
rename sam samplecs1

* prepare to combine with midline

drop  targetportion* raskinpercent weight_pool gotcard_gr usedcard_gr  ///
	  rasksocialized_ldr raskposter raskannounce raskmeeting rasksocialized_hh rasksocialized_hh2 ///
	  amtraskin_diffusable price_hh_diffusable price_ldr ///
	  rask_dist rask_dist_diffusable rask_dist_oct rask_dist_nov subsidy_rcvd_diffusable price_variance ///
	  price_range satis_list_hh 

	  
drop knowstatusothr dkstatusoth knowstatusothr_b	  



rename bought_s_oct bought_last2m

gen wave=1
	
*****************************
* 2.2. Further coding CS1 : Knowledge and Sample comparability
*****************************
 
 * village officials in cs1 (self-declared)
preserve
	use "1Data/originaldata/1_CS1/NewUpdate/hh_pm2.dta", clear
	
	* keep only self and same household observations
	keep if pm02==4 | pm03=="A"
	
	keep  hhid pm2type
	rename pm2type off_pos_cs1
	
	* numerize
	replace off_pos_cs1="1" if off_pos_cs1!=""
	encode off_pos_cs1 , gen(temp)
	drop off_pos_cs1
	rename temp off_cs1

	duplicates drop hhid, force
	
	tempfile official_cs1
	sa `official_cs1'
restore

 * outcome 7a/b: HH knows correct status of other households
preserve
	
	* get real types
	u "1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1_sw.dta", clear
	
	
	merge 1:1 hhid using `official_cs1'
	assert _m!=2
	drop _m
	
	rename hhid sw03_hhid
	gen status=(hhid_udb!="")
	keep  sw03_hhid off_cs1 status
	
	tempfile types
	sa `types'
	
	* get respondent beliefs about Raskin status of other hhds
	u "1Data/originaldata/1_CS1/NewUpdate/hh_sw4.dta", clear
	g temp = substr(hhid,1,3)
	replace sw03_hhid = temp+sw03_hhid
	drop temp
	
	merge m:1 sw03_hhid using `types'
	keep if _m==3
	drop _m	
	
	* r = respondent, t = target
	rename hhid hhid_r_cs1
	rename sw03_hhid hhid_t_cs1
	
	* generate vars using all matched real types
	g dkstatusoth = sw03==8		
	replace sw03 = 1 if sw03==2
	replace sw03 = 3 if sw03==4
	replace sw03 = 0 if sw03==3
	replace sw03 = . if sw03==8	
	drop if !(sw03==0 | sw03==1 | sw03==.)
	assert sw03==0 | sw03==1 | sw03==.

	* How are Don't know treated?
	* The first set of variables codes that as an error		
	* The second set of variables (ending in _d) drops those observations

	* generate vars separately by target type	
	g knowstatusothr      = sw03==status 
	g knowstatusothr_d = knowstatusothr  
	replace knowstatusothr_d = . if dkstatusoth==1
	la var knowstatusothr "Respondent knows other's status, DK = 0"
	la var knowstatusothr_d "Respondent knows other's status, DK = ."
	
	drop  sw03_no 
	rename off_cs1 off_cs1_t
	rename status status_t
	
	rename sw03 thinkspoor

	tempfile knowstatus_cs1
	sa `knowstatus_cs1'
		
restore

cap drop  knowstatusothr*

merge 1:1 hhid using `official_cs1'
assert _m!=2
drop _m

rename off_cs1 off_cs1_r
 
********** PKH
 
* drop from cs1 HHs that were not eligible for PKH at the time of basline T2
preserve
	use "1Data/originaldata/1_CS1/NewUpdate/hh_ar.dta", clear
	* time of baseline T2 - Dec 2010 - Feb 2011

	* exclude babies born after sept/2011 and teens who were 16 in dec 2010
	gen tooyoung = (ar04a_m < 19)
	gen tooold   = (ar04a_yr >= 18)

	gen temp = !tooyoung & !tooold
	by hhid: egen pkhelig = sum(temp)
	replace pkhelig = pkhelig>0

	duplicates drop hhid, force
	keep hhid pkhelig
	tempfile pkhelig
	sa `pkhelig'
restore

merge 1:1 hhid using `pkhelig'
count if _m!=3
assert `r(N)'<=1
keep if _m==3
drop _m

* exclude PKH ineligibles from the CS1 comparable
gen analysis_2=1 
replace analysis_2=0 if pkhelig==0 

***************************
* Save temporary version of CS1 (no weights yet)
***************************
tempfile cs1
sa `cs1', replace

***************************************
* 3. Pool with CS1. Adjust sample restrictions and weights
***************************************
*****************************
* 3.1 Weights statistics midline
*****************************

u "1Data/codeddata/cards_paper/paper/combined.dta", clear
 
* replace missing by zeros, for now
foreach suf in CvC ENH B10 PRC CPN{
	replace  weight_fs_`suf' = 0 if  weight_fs_`suf' ==.
	replace weight_cs1_`suf' = 0 if weight_cs1_`suf' ==.
 }
 
* add total weights by kecamatan from MIDLINE 
forv i=1/14{
	local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
	local t1 : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
	
	* FULL SAMPLE
	bys kec_id: egen  n1_`suf'_`t1'_fs_mid = sum(weight_fs_`suf'*(type==1)*`t1')
	bys kec_id: egen  n2_`suf'_`t1'_fs_mid = sum(weight_fs_`suf'*(type==2)*`t1')
	bys kec_id: egen  n3_`suf'_`t1'_fs_mid = sum(weight_fs_`suf'*(type==3)*`t1')
	bys kec_id: egen tot_`suf'_`t1'_fs_mid = sum(weight_fs_`suf'*`t1')
	
	* CS1 comparable sample
	bys kec_id: egen  n1_`suf'_`t1'_cs1_mid = sum(weight_cs1_`suf'*(type==1)*`t1')
	bys kec_id: egen  n2_`suf'_`t1'_cs1_mid = sum(weight_cs1_`suf'*(type==2)*`t1')
	bys kec_id: egen  n3_`suf'_`t1'_cs1_mid = sum(weight_cs1_`suf'*(type==3)*`t1')
	bys kec_id: egen tot_`suf'_`t1'_cs1_mid = sum(weight_cs1_`suf'*`t1')
		
}

* store midline weight statistics
keep kec_id type n* tot_*
duplicates drop kec_id, force
tempfile midws
sa `midws'

	
*****************************
* 3.2 Weights statistics CS1
*****************************
use `cs1', clear

rename weightB10 weight_fs_B10
rename weightENH weight_fs_ENH
rename weightPRC weight_fs_PRC
rename weightCPN weight_fs_CPN
gen    weight_fs_CvC=weight_fs_ENH

* lose around 1000 observations per weight type (more for B10) because of dropping PKH ineligibles.
foreach suf in CvC ENH B10 PRC CPN{
	g weight_cs1_`suf' = weight_fs_`suf'
	replace weight_cs1_`suf'=. if analysis_2==0
}



* replace missing by zeros, for now 
foreach suf in CvC ENH B10 PRC CPN{
	replace  weight_fs_`suf' = 0 if  weight_fs_`suf' ==.
	replace weight_cs1_`suf' = 0 if weight_cs1_`suf' ==.
}

*** Step 1 - weight statistics
* add total weights by kecamatan from CS1 - temporary counts
forv i=1/14{
	local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
	local t1 : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
	
* Temporary counts
	bys kec_id: egen n1_`suf'_`t1'_temp_cs1 = sum(weight_fs_`suf'*(type==1)*`t1')
	bys kec_id: egen n2_`suf'_`t1'_temp_cs1 = sum(weight_fs_`suf'*(type==2)*`t1')
	bys kec_id: egen n3_`suf'_`t1'_temp_cs1 = sum(weight_fs_`suf'*(type==3)*`t1')
	bys kec_id: egen tot_`suf'_`t1'_temp_cs1 = sum(weight_fs_`suf'*`t1')
	
}


*** Step 2 - drop cells that are empty in midline
* add weights by kecamatan from midline
merge m:1 kec_id using `midws'
assert _m==3
drop _m

* drop dummies, specific to the weight variable and sample.
foreach suf in CvC ENH PRC CPN B10{	
	gen drop_fs_`suf'  = 0
	gen drop_cs1_`suf' = 0
}

forv i=1/14{
	forv j=1/3{
		local suf: word `i' of CvC CvC 		 ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
		local t  : word `i' of CTL treatment CTL ENH STD CTL PRC NOP CTL CPN NOC CTL B10 ALL
		local ig : word `j' of 1 2 3
		
		* Drop if cs1 cell is not empty but midline cell is empty
		replace drop_fs_`suf'  = 1 if (n`ig'_`suf'_`t'_temp_cs1 > 0 &  n`ig'_`suf'_`t'_fs_mid == 0) & type == `ig' & `t'
		replace drop_cs1_`suf' = 1 if (n`ig'_`suf'_`t'_temp_cs1 > 0 & n`ig'_`suf'_`t'_cs1_mid == 0) & type == `ig' & `t'
	}
}

* Drop 25 observations for (fs) and 88 for (cs1)
foreach suf in CvC ENH PRC CPN B10{	
	replace  weight_fs_`suf' = . if drop_fs_`suf' ==1
	replace weight_cs1_`suf' = . if drop_cs1_`suf' ==1
}

drop drop_*
	
***********************	
**** SAVE CS1 ready for pooling
***********************
* drop temporary counts
drop n?_*_temp_cs1 tot_*_temp_cs1
sa `cs1', replace
	
*** Step 3 - redo weight statistics after dropping observations
preserve
	forv i=1/14{
		local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
		local t1 : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
		
		* FULL SAMPLE
		bys kec_id: egen  n1_`suf'_`t1'_fs_cs1 = sum(weight_fs_`suf'*(type==1)*`t1')
		bys kec_id: egen  n2_`suf'_`t1'_fs_cs1 = sum(weight_fs_`suf'*(type==2)*`t1')
		bys kec_id: egen  n3_`suf'_`t1'_fs_cs1 = sum(weight_fs_`suf'*(type==3)*`t1')
		bys kec_id: egen tot_`suf'_`t1'_fs_cs1 = sum(weight_fs_`suf'*`t1')
				
		* CS1 comparable sample
		bys kec_id: egen  n1_`suf'_`t1'_cs1_cs1 = sum(weight_cs1_`suf'*(type==1)*`t1')
		bys kec_id: egen  n2_`suf'_`t1'_cs1_cs1 = sum(weight_cs1_`suf'*(type==2)*`t1')
		bys kec_id: egen  n3_`suf'_`t1'_cs1_cs1 = sum(weight_cs1_`suf'*(type==3)*`t1')
		bys kec_id: egen tot_`suf'_`t1'_cs1_cs1 = sum(weight_cs1_`suf'*`t1')
		
	}

	duplicates drop kec_id, force
	keep kec_id type n* tot_*
	tempfile cs1ws
	sa `cs1ws'
restore	

***********************
* 3.3 Load midline data and prepare to combine with CS1
***********************
u "1Data/codeddata/cards_paper/paper/combined.dta", clear		

rename hhid hhid_midline
drop type_panel treated_panel

drop  weight_fs_PRC_2 -  weight_fs_ENH_2  weight_cs1_PRC_2 - weight_cs1_ENH_2 gotcard_gr usedcard_mar usedcard_gr ///
	   rasksocialized_ldr raskposter raskannounce  rasksocialized_hh amtraskin_diffusable ///
	   price_hh_diffusable subsidy_rcvd_diffusable price_variance price_range 

gen wave=2
gen hhid=""
gen boughtrask_oct=.
gen boughtrask_nov=.

rename bought_s_mar bought_last2m

* make kecagroup variable compatible
decode kecagroup, gen(k2)
drop kecagroup
rename k2 kecagroup


*****************************
* 3.4 Weights again
*****************************
 
* add total weights by kecamatan from CS1
merge m:1 kec_id using `cs1ws'
assert _m==3
drop _m
	
* COUNT # n_mid =/= 0 and n_cs1==0
* drop dummies, specific to the weight variable and sample.
foreach suf in CvC ENH PRC CPN B10{	
	gen drop_fs_`suf'  = 0
	gen drop_cs1_`suf' = 0
}

forv i=1/14{
	forv j=1/3{
		//local n  : word `i' of ctl trt 		 enh std prc nop cpn noc b10 all
		local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
		local t  : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
		local ig : word `j' of 1 2 3
		
	* Drop if cs1 cell is empty and midline cell is not empty
		replace drop_fs_`suf'  = 1 if (n`ig'_`suf'_`t'_fs_cs1 == 0 &  n`ig'_`suf'_`t'_fs_mid > 0) &  type == `ig' & `t'
		replace drop_cs1_`suf' = 1 if (n`ig'_`suf'_`t'_cs1_cs1 == 0 & n`ig'_`suf'_`t'_cs1_mid > 0) &  type == `ig' & `t'
	}
}
	
* Count how many will be dropped from midline. no need to drop as this will be done automatically when reweighting
* lose 7 observations in full sample, and 50 in cs1-comparable sample	
foreach suf in CvC ENH PRC CPN B10{	
	tab  drop_fs_`suf' if  weight_fs_`suf' != .
	tab drop_cs1_`suf' if weight_cs1_`suf' != .
}

drop drop_*

********************************************	
*** reweight midline to be the same as cs1
********************************************
* basic formula: 
* multiply by (cs1 cell weight), divide by (midline cell weight)
* multiply by (midline total cell weight - all income groups), divide by (cs1 total cell weight - all income groups)

forv i=1/14{
	local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
	local t1 : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
	
	local do3: word `i' of 0 1 1 1 1

	* FULL SAMPLE
	replace weight_fs_`suf' = weight_fs_`suf' * n1_`suf'_`t1'_fs_cs1/n1_`suf'_`t1'_fs_mid * tot_`suf'_`t1'_fs_mid/tot_`suf'_`t1'_fs_cs1 if type==1 & `t1'
	replace weight_fs_`suf' = weight_fs_`suf' * n2_`suf'_`t1'_fs_cs1/n2_`suf'_`t1'_fs_mid * tot_`suf'_`t1'_fs_mid/tot_`suf'_`t1'_fs_cs1 if type==2 & `t1'
	replace weight_fs_`suf' = weight_fs_`suf' * n3_`suf'_`t1'_fs_cs1/n3_`suf'_`t1'_fs_mid * tot_`suf'_`t1'_fs_mid/tot_`suf'_`t1'_fs_cs1 if type==3 & `t1'

	* CS1 comparable sample
	replace weight_cs1_`suf' = weight_cs1_`suf' * n1_`suf'_`t1'_cs1_cs1/n1_`suf'_`t1'_cs1_mid * tot_`suf'_`t1'_cs1_mid/tot_`suf'_`t1'_cs1_cs1 if type==1 & `t1'
	replace weight_cs1_`suf' = weight_cs1_`suf' * n2_`suf'_`t1'_cs1_cs1/n2_`suf'_`t1'_cs1_mid * tot_`suf'_`t1'_cs1_mid/tot_`suf'_`t1'_cs1_cs1 if type==2 & `t1'
	replace weight_cs1_`suf' = weight_cs1_`suf' * n3_`suf'_`t1'_cs1_cs1/n3_`suf'_`t1'_cs1_mid * tot_`suf'_`t1'_cs1_mid/tot_`suf'_`t1'_cs1_cs1 if type==3 & `t1'

}

********************
* 3.5 Finally POOL 
********************
append using `cs1'
	
*test that the relative ratios of the three income groups is the same for midline and cs1 data, by treatment x keca_id, and for the 2 samples (fs and cs1)
preserve
	destring kec_id, gen(k2)
	drop kec_id
	rename k2 kec_id
	
	foreach smpl in cs1 fs{
		forv i=1/14{
			local tr : word `i' of CTL treatment CTL STD ENH CTL B10 ALL CTL CPN NOC CTL PRC NOP
			local suf: word `i' of CvC CvC       ENH ENH ENH B10 B10 B10 CPN CPN CPN PRC PRC PRC   
			
			qui tab kec_id type if `tr' & wave==1 [aweight=weight_`smpl'_`suf'], matcell(m1) matrow(n1)		
			qui tab kec_id type if `tr' & wave==2 [aweight=weight_`smpl'_`suf'], matcell(m2)
				 
			svmat n1
			svmat m1
			svmat m2
			g m1t = m11+m12+m13
			g m2t = m21+m22+m23
			
			replace m11=m11/m1t
			replace m12=m12/m1t
			replace m13=m13/m1t
			
			replace m21=m21/m2t
			replace m22=m22/m2t
			replace m23=m23/m2t
			
			gen d1 = abs(m11 - m21)
			gen d2 = abs(m12 - m22)
			gen d3 = abs(m13 - m23)
			
			count if (d1>.05 & d1!=.)
			if `r(N)'>0 pause "group 1 `tr' `suf'"	
			count if (d2>.05 & d2!=.)
			if `r(N)'>0 pause "group 2 `tr' `suf'"
			count if (d3>.05 & d3!=.)
			if `r(N)'>0 pause "group 3 `tr' `suf'"
			
			drop n11-d3
		}
	}
restore

* final check on the number of observations dropped, by weight type 
foreach suf in CvC ENH PRC CPN{
	
	replace weight_fs_`suf'=.  if weight_fs_`suf'==0
	replace weight_cs1_`suf'=. if weight_cs1_`suf'==0
	
	gen wtt_fs = 0
	gen wtt_cs1= 0
	replace wtt_fs = 1 if weight_fs_`suf'!=0  &  weight_fs_`suf'!=.
	replace wtt_cs1= 1 if weight_cs1_`suf'!=0 & weight_cs1_`suf'!=.
	
	di "`suf' FULL SAMPLE"
	tab wave if treated!=., m
	tab wave wtt_fs if treated!=. , m

	//pause
	
	di "`suf' CS1"
	tab wave if treated!=., m
	tab wave pkh if treated!=., m
	tab wave if treated!=. & (jpal_id!="A1" & jpal_id!="A2"), m 
	tab wave  wtt_cs1 if treated!=., m
	tab wave wtt_cs1 if treated!=. & jpal_id!="A1" & jpal_id!="A2" & pkh==1, m
	
	//pause
	
	drop wtt*
	
}

*separately for B10
gen wtt_fs = 0
gen wtt_cs1= 0
replace wtt_fs = 1 if weight_fs_B10!=0  &  weight_fs_B10!=.
replace wtt_cs1= 1 if weight_cs1_B10!=0 & weight_cs1_B10!=.

tab wtt_fs , m
tab analysis_2  wtt_cs1 , m

drop wtt*

************************
* Final changes to pooled sample
************************

* unique ID
gen hhid_pooled=""
replace hhid_pooled = "cs1" + hhid if hhid!=""
replace hhid_pooled = "mid" + hhid_midline if hhid_midline!=""
rename hhid hhid_cs1
		
* sample dummies
replace samplea=0 if samplea!=1
replace sampleb=0 if sampleb!=1
replace samplec=0 if samplec!=1
replace t2trm1 = t2treatment==0
replace t2trm2 = t2treatment==1
replace t2trm3 = t2treatment==2
gen sample1cs1 = 0
gen sample2cs1 = 0
gen sample3cs1 = 0
replace sample1cs1 = 1 if samplecs1==1
replace sample2cs1 = 1 if samplecs1==2
replace sample3cs1 = 1 if samplecs1==3

* combine official position from cs1 and midline - for targets
gen off_pooled_r = off_cs1_r
replace off_pooled_r = off_mid_r if wave==2
drop off_cs1_r off_mid_r

* Regional heterogeneity
gen java = inlist(kab_id,"3312","3327")
gen tr_java = treatment * java
la var tr_java "Card Treatment x Java"
gen tr_offj = treatment * (1-java)
la var tr_offj "Card Treatment x Off Java"

* Variable labels
la var treatment "Card Treatment"
la var B10 "Cards to Bottom 10"
la var ALL "Cards to All"
la var CPN "Cards with Coupons"
la var NOC "Cards without Coupons"	
la var PRC "Cards with Printed Price"
la var NOP "Cards without Price"
la var ENH "Public Information"
la var STD "Standard Information"
	
***************************
* 4. SAVE POOLED SAMPLE
***************************
*clean up	
drop n?_* tot_*
order hhid_pooled hhid_cs1 hhid_mid, before(hhea)
order wave int_day int_month, after(hhea)
order t2trm1 t2trm2 t2trm3 , after(t2treatment)
order pkhelig analysis_2 sample samplea sampleb samplec samplecs1 sample1cs1 sample2cs1 sample3cs1 type, after(jpal_id)
order kecagroup, after(kec_id)
order price_hh_oct price_hh_nov, before(price_hh_jan)
order subsidy_rcvd_oct subsidy_rcvd_nov, before(subsidy_rcvd_jan)
order amtraskin_aug amtraskin_sept amtraskin_oct amtraskin_nov, before(amtraskin_jan)
order boughtrask_oct boughtrask_nov, after(boughtrask)
order usedcoup, after(usedcard)
drop analysis_3 
rename sample sample_mid	
	
saveold "1Data/codeddata/cards_paper/paper/combined_pooled.dta", replace

***************************
* 5. SAVE POOLED SAMPLE for knowledge variables, many observations
***************************

preserve
	keep if wave==1
	rename hhid_cs1 hhid_r_cs1
	tempfile pooled_cs1
	sa `pooled_cs1'
restore

preserve
	keep if wave==2
	rename hhid_midline hhid_r_mid
	tempfile pooled_mid
	sa `pooled_mid'
restore

preserve
	u `knowstatus_mid', clear
	merge m:1 hhid_r_mid using `pooled_mid'
	count if _m!=3
	assert `r(N)'<=1
	keep if _m==3
	drop _m
	
	tempfile temp_mid
	sa `temp_mid'
restore

u `knowstatus_cs1', clear
merge m:1 hhid_r_cs1 using `pooled_cs1'
count if _m!=3
assert `r(N)'<=9
keep if _m==3
drop _m

append using `temp_mid'

drop  hhid_midline hhid_cs1
	
* combine official position from cs1 and midline - for respondendent
gen off_pooled_t = off_cs1_t
replace off_pooled_t = off_mid_t if wave==2
drop off_cs1_t off_mid_t

* reorder variables
order  hhid_r_cs1 hhid_r_mid hhid_pooled hhid_t_cs1 hhid_t_mid hhea, before( status_t)
order  off_base_r ldr_base_r off_pooled_r, after( hhea)
order  off_base_t ldr_base_t off_pooled_t, after( off_pooled_r)
order  cr01_rel, after(off_pooled_t)
order dkstatusoth knowstatusothr knowstatusothr_d, after(hhea)

rename hhid_pooled hhid_r_pooled

***** Save *********************************************************************

saveold "1Data/codeddata/cards_paper/paper/knowledge_pooled.dta", replace
	
