**********************************************
**********************************************
* Basic coding; weights and treatment status
**********************************************
**********************************************

clear all
set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input baseline data
****************************

u "1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta", clear
keep if ksr3type=="a"
replace ksr11_kg = ksr11_lt*.8 if ksr11_kg==.
replace ksr11_kg = 0 if ksr08==3
replace ksr11_kg = . if ksr11_kg > 100	// trimmed at 100
ren ksr11_kg amtraskin
g hhea = substr(hhid,1,3)
keep hhea amtraskin
la var amtraskin "Raskin purchased (in kg)"
tempfile baseline
sa `baseline'

****************************
* 2. Input data on # HHs / vill
****************************

u "1Data/originaldata/0_Listing/l_location_clean", clear
rename hhea desa_id2
tempfile numhh
sa `numhh'

****************************
* 3. UDB prep
****************************

u "1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean.dta", clear

* List of beneficiaries by bot10 status
preserve
	keep hhid skesj
	ren hhid hhid_udb
	tempfile udb
	sa `udb'
restore

* Kabupaten
preserve
	keep desa_id2 kab_id
	ren desa_id2 hhea
	duplicates drop
	tempfile kabname
	sa `kabname'
restore

* SW crosswalk work
preserve
	ren hhid hhid_udb
	keep hhid_udb skesj
	merge 1:m hhid_udb using "1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1_sw.dta"	// 1:m because of missings
	keep if _m!=1
	g type = 1 if skesj==1
	replace type = 2 if _m==3 & skesj==.
	replace type = 3 if _m==2
	assert type!=.
	drop _m
	keep hhid type
	saveold "1Data/codeddata/cards_paper/crosswalk_SW.dta", replace
restore

*********	
* Weights for pooled stats; that is, weights to make surveyed sample look like whole population
*village and # of HHs
keep desa_id2 skesj
merge m:1 desa_id using `numhh'					// merge in total # households
assert _m!=2	// 572 vills in the listing
keep if _m==3
drop _m

*target portions by village
g targetportion_all = .
levelsof desa_id2
qui foreach d in `r(levels)' {
	count if skesj==1 & desa_id2=="`d'"
	replace targetportion_all = `r(N)'/n_hh if skesj==1 & desa_id2=="`d'"
	count if skesj==. & desa_id2=="`d'"
	replace targetportion_all = `r(N)'/n_hh if skesj==. & desa_id2=="`d'"
	assert targetportion_all < 1 if desa_id2=="`d'"
	}

*create weights separately by type
bys desa_id2 skesj: keep if _n==1
g type = 1 if skesj==1
replace type = 2 if skesj==.
bys desa_id2: egen totportion = total(target)
count if totportion > .8
assert `r(N)' < 20
local dropcount = `r(N)'*4
drop if totportion > .8

*adjustment to deal with non-beneficiaries
g raskinpercent = totportion
replace totportion = 1-totportion
expand type, gen(dup)
replace type = dup+type
drop dup
replace target = totportion if type==3
drop totportion
bys desa_id2: egen temp = total(target)
assert abs(1-temp)<.001
bys desa_id2: assert _N==3

*clean up
so desa_id2 type
ren desa_id2 hhea
keep hhea type target raskinpercent
tempfile weights
sa `weights'	

****************************
* 4. Strata
****************************

u "1Data/originaldata/TargetingIIData/Baseline/coded_baseline_partV.dta", clear
drop if maintreatment==1
keep hhea kecagroup
duplicates drop
tempfile first
sa `first'
u "1Data/originaldata/TargetingIIData/Baseline/coded_baseline_partV_hybrid.dta", clear
keep hhea kecagroup
duplicates drop
append using `first'
tempfile kecagrps
sa `kecagrps'


****************************
* 5. Collect basic data
****************************

u "1Data/originaldata/1_CS1/NewUpdate/hh_cov.dta"
keep if hhcov4==1	// drop those who didn't do interview
keep hhid hhea jpal_id hhivwdd_1 hhivwmm_1
ren hhivwdd_1 int_day
la var int_day "Day of interview"
ren hhivwmm_1 int_month
la var int_month "Month of interview"
ren hhea desa_id2

merge m:1 desa_id2 using "1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"

assert _m != 1
keep if _m==3
drop _m
ren desa_id2 hhea

merge m:1 hhea using `kecagrps'
assert _m!= 1
keep if _m==3
drop _m


****************************
* 6. Recode beneficiary status
****************************
* some people in type 3 are actually beneficiaries. record which sample they came from, and give them the right type.

merge 1:1 hhid using "1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1.dta"
assert _m==3
drop _m
ta jpal_id
g sample = .
preserve
	keep if hhid_udb!=""
	merge 1:1 hhid_udb using `udb'
	assert _m !=1
	keep if _m==3
	drop _m
	assert skesj==1 if jpal_id=="1"
	assert skesj==. if jpal_id=="2"
	replace sample = 1 if jpal_id=="1"
	replace sample = 2 if skesj==1 & jpal_id=="3"
	replace sample = 3 if jpal_id=="2"
	replace sample = 4 if skesj==. & jpal_id=="3"
	replace jpal_id="1" if skesj==1
	replace jpal_id="2" if skesj==.
	tempfile udb2
	sa `udb2'
restore
drop if hhid_udb!=""
append using `udb2'
ta jpal_id
replace sample = 5 if sample==. & jpal_id=="3"
assert sample!=.
la define sample 1 "PPLS-B10, sample 1" 2 "PPLS-B10, sample 3" 3 "PPLS-other, sample 2" 4 "PPLS-other, sample3" 5 "Other HHs"
la values sample sample
g type = 1 if jpal_id=="1"
replace type = 2 if jpal_id=="2"
replace type = 3 if jpal_id=="3"
la define type 1 "Bottom 10" 2 "Other Beneficiary" 3 "Non-Beneficiary"
la values type type
tab type, g(t)

****************************
* 7. Coding treatments
****************************

g ALL = TR1==2
g CTL = TR1==1
g B10 = TR1==3
g PRC = TR1a==0
g NOP = TR1a==1
g CPN = TR1b==0
g NOC = TR1b==1
g STD = TR1c==0
g ENH = TR1c==1
g treatment = B10+ALL
assert treatment+CTL==1
g treated = 1 if (type==1) | (type==2 & inlist(TR1,1,2))
replace treated = 0 if type==3
g type2a = 1 if type==1
g type2b = 1 if treated==1 & type==2
g type2c = 1 if treated==. | (type==2 & CTL==1)

****************************
* 8. Make Targeting II version for baseline analysis
****************************

preserve
	foreach x of varlist sample jpal_id type* t1 t2 t3 treated int* hhid_udb skesj hhid {
		cap drop `x'
	}
	duplicates drop
	merge 1:m hhea using `baseline'
	assert _m!=1
	keep if _m==3
	drop _m
	pause
	saveold "1Data/codeddata/cards_paper/TargetingIIRaskin.dta", replace
restore

****************************
* 9. Weights
****************************

count if treated==1 & CTL!=1
local treated = `r(N)'
count if CTL==1 & treated==1
local control = `r(N)'
g controlportion = .
g targetportion = .

* for main treatment
count if treated==1
local tnum = `r(N)'
g weightB10=.
forv x = 1/4 {
	count if sample==`x' & CTL!=1 & treated==1
	local samp = `r(N)'
	replace targetportion = `samp'/`treated' if sample==`x' & treated==1
	count if sample==`x' & CTL==1 & treated==1
	local samp = `r(N)'
	replace controlportion = `samp'/`control' if sample==`x' & treated==1
	replace weightB10 = targetportion/controlportion if CTL==1 & sample==`x' & treated==1
	}
	replace weightB10 = 1 if sample==5 | treatment==1

* looped for subtreatments
forv x = 1/3 {																					// loop treatments
	local t1 : word `x' of NOP NOC STD															// binary var names
	local t2 : word `x' of PRC CPN ENH	
	count if `t1'==1 & treated==1
	local t1num = `r(N)'
	count if `t2'==1 & treated==1
	local t2num = `r(N)'
	g weight`t2' = .
	g `t1'portion = .
	g `t2'portion = .
	forv x = 1/4 {																				// loop samples
		count if sample==`x' & CTL!=1 & treated==1												// target weight
		local samp = `r(N)'
		replace targetportion = `samp'/`treated' if sample==`x' & treated==1
		count if sample==`x' & CTL==1 & treated==1												// proportion in control
		local samp = `r(N)'
		replace controlportion = `samp'/`control' if sample==`x' & treated==1
		replace weight`t2' = targetportion/controlportion if CTL==1 & sample==`x' & treated==1	// weight for control
		count if sample==`x' & `t1'==1 & treated==1												// proportion in ENH treatment.
		local samp = `r(N)'
		replace `t1'portion = `samp'/`t1num' if sample==`x' & treated==1
		replace weight`t2' = targetportion/`t1'portion if treated==1 & `t1'==1 & sample==`x'	// weight for ENH
		count if sample==`x' & `t2'==1 & treated==1												// proportion in STD
		local samp = `r(N)'
		replace `t2'portion = `samp'/`t2num' if sample==`x' & treated==1						
		replace weight`t2' = targetportion/`t2'portion if treated==1 & `t2'==1 & sample==`x'	// weight for STD
		}
	replace weight`t2' = 1 if sample==5	// these are not weighted
	}

* for representative village sample
merge m:1 hhea type using `weights'
count if _m==1
assert `r(N)'==`dropcount'
pause	// _m==2 if we happened not to sample any beneficiaries.
drop if _m==2
drop _m
bys hhea: g tot = _N
g portion = .
g weight_pool = .
levelsof hhea
foreach d in `r(levels)' {
forv x = 1/3 {
	count if type==`x' & hhea=="`d'"
	replace portion = `r(N)' / tot if type==`x' & hhea=="`d'"
	replace weight_pool = targetportion_all / portion if type==`x' & hhea=="`d'"
	}
	}
	drop portion tot

****************************
* 10. Kabupaten names
****************************

merge m:1 hhea using `kabname'
assert _m!=1
keep if _m==3
drop _m

**************************** 
* 11. Clean up and save
****************************

keep hhid hhea kab_id type type2* t* TR1* kecagroup ALL CTL B10 PRC NOP NOC CPN STD ENH treatment treated kec_id sample int_day int_month weight* raskinpercent

saveold "1Data/codeddata/cards_paper/beneficiaries and randomization.dta", replace

