**********************************************
**********************************************
* Basic coding; weights and treatment status
**********************************************
**********************************************

** SETUP AND MACROS *******************************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"
	
****************************
* 1. Input baseline data
****************************

u "1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta", clear
keep if ksr3type=="a"
replace ksr11_kg = ksr11_lt*.8 if ksr11_kg==.
replace ksr11_kg = 0 if ksr08==3
replace ksr11_kg = . if ksr11_kg > 100	// trimmed at 100
ren ksr11_kg amtraskin
g hhea = substr(hhid,1,3)
keep hhea amtraskin
la var amtraskin "Raskin purchased (in kg)"
tempfile baseline
sa `baseline'

****************************
* 2. Input data on # HHs / vill
****************************

u "1Data/originaldata/0_Listing/l_location_clean", clear
tempfile numhh
sa `numhh'

****************************
* 3. UDB prep
****************************

u "1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean.dta", clear

* List of beneficiaries by bot10 status
preserve
	keep hhid skesj
	ren hhid hhid_udb
	tempfile udb
	sa `udb'
restore

* Kabupaten
preserve
	keep desa_id2 kab_id
	ren desa_id2 hhea
	duplicates drop
	tempfile kabname
	sa `kabname'
restore

****************************
* 5. Collect basic data
****************************

u "1Data/originaldata/2_Midline/hh_cov.dta", clear
keep if hhcov4 == 1	// drop those who didn't do interview
keep hhid hhea jpal_id hhivwdd_1 hhivwmm_1
ren hhivwdd_1 int_day
la var int_day "Day of interview"
ren hhivwmm_1 int_month
la var int_month "Month of interview"
ren hhea desa_id2

// check all obs have acceptable jpal_id
assert jpal_id!="A1" | jpal_id!="A2" | jpal_id!="B1" | jpal_id!="B2" | ///
        jpal_id!="B3" | jpal_id!="B4" | jpal_id!="C1" | jpal_id!="C2" 

merge m:1 desa_id2 using "1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"

assert _m != 1
keep if _m==3
drop _m
ren desa_id2 hhea

// note on strata: kec_id and t2treatment already loaded.
encode kec_id, generate(kecagroup)
gen t2trm1 = t2treatment==1
gen t2trm2 = t2treatment==2
gen t2trm3 = t2treatment==3
assert t2trm1+t2trm2+t2trm3==1

****************************
* 6. Recode beneficiary status
****************************

/* Merge on hhid_udb, so we can then merge to the file which tells which
	type Sample A people are. */
ren hhid hhid_midline
merge 1:1 hhid_midline using ///
	"1Data/originaldata/2_Midline/crosswalk_midline.dta"
assert _m!=1
keep if _m==3
drop _m

* merge with udb to record everyone's PPLS status
merge m:1 hhid_udb using `udb'

* drop UDB not in the survey
drop if _m == 2

* assert that the only un-matched from master are either sample B or C, or sample A without udb
assert !(_m==1 & hhid_udb!="")

* generate type=1 if Bottom10, =2 if PPLS-other and =3 if non-PPLS
gen type = 1 if skesj == 1
replace type = 2 if _m == 3 & skesj != 1

// samples B1, B2, B3, B4, C1 and C2 matched
replace type = 3 if type==.

tab jpal_id type, m

la define type 1 "Bottom 10" 2 "Other Beneficiary" 3 "Non-Beneficiary"
la values type type
	
drop _m
tab type, g(t)

* define the 11 subsamples on which we use weights to force balance 
gen     sample=1 if type==1 & (jpal_id=="A1" | jpal_id=="A2")
replace sample=2 if type==1 & (jpal_id=="B1")
replace sample=2 if type==1 & (jpal_id=="B2")
replace sample=3 if type==1 & (jpal_id=="B3")
replace sample=3 if type==1 & (jpal_id=="B4")
replace sample=4 if type==1 & (jpal_id=="C2")  
replace sample=5 if type==1 & (jpal_id=="C1")  

replace sample=6 if type==2 & (jpal_id=="A1" | jpal_id=="A2")
replace sample=7 if type==2 & (jpal_id=="B2")
replace sample=8 if type==2 & (jpal_id=="B4")
replace sample=9 if type==2 & (jpal_id=="C2")  
replace sample=10 if type==2 & (jpal_id=="C1")  

replace sample=11  if type==3 & (jpal_id=="A1" | jpal_id=="A2")
replace sample=12 if type==3 & (jpal_id=="C1")
replace sample=13 if type==3 & (jpal_id=="C2") 
replace sample=14 if type==3 & (jpal_id=="B1")
replace sample=15 if type==3 & (jpal_id=="B2") 

assert sample!=.
la define labelsample 1 "PPLS-B10, sample A" ///
				 2 "PPLS-B10, sample B1" ///
				 3 "PPLS-B10, sample B3" ///
				 4 "PPLS-B10, sample C2" ///
			 	 5 "PPLS-B10, sample C1" ///
				 6 "PPLS-other, sample A" ///
				 7 "PPLS-other, sample B2" ///
				 8 "PPLS-other, sample B4" ///
				 9 "PPLS-other, sample C2" ///
				 10 "PPLS-other, sample C1" ///
				 11 "non-PPLS, sample A" ///
				 12 "non-PPLS, sample C1" ///
				 13 "non-PPLS, sample C2" ///
				 14 "non-PPLS, sample B1" ///
				 15 "non-PPLS, sample B2"  
la values sample labelsample

************************************
***** 6.a Panel Sample - re-define type according to targeting 2 consumption 
************************************

* start by loading T2 data in order to define the cutoffs
preserve
	* Targeting 2 baseline, Endline 1 and Endline 2 consumption -- t2c
	use "1Data/originaldata/TargetingIIData/Endline2/ConsumptionAcrossWaves", clear
	keep  hhid  baselogconsumption end1consumption end1logconsumption end2logconsumption
	rename hhid hhid_sm
	pause t2c
	tempfile t2c
	sa `t2c'
restore

*match and restrict to panel sample
preserve

	merge 1:m hhid_midline using "1Data/originaldata/2_Midline/crosswalk_midline_all.dta"
	assert _m!=1
	keep if _m==3
	drop _m

	* keep the panel sample (A1, B1, B2 and C1) as well as A2
	keep if jpal_id=="A1" | jpal_id=="A2" | jpal_id=="B1" | jpal_id=="B2" | jpal_id=="C1"

	count if hhid_sm=="" & jpal_id=="A1"
	assert `r(N)'<=42     // can't match 42 hhds in sample A1
	count if hhid_sm=="" & jpal_id=="A2"
	assert `r(N)'<=204     // can't match 204 hhds in sample A2
	count if hhid_sm=="" & (jpal_id=="B1" | jpal_id=="B2" | jpal_id=="C1")
	assert `r(N)'<=0     

	drop if hhid_sm==""

	* add endline 2
	merge 1:1 hhid_sm using `t2c'
	
	pause merge  panel
	
	assert _m!=1 if jpal_id=="A1" | jpal_id=="B1" | jpal_id=="B2" | jpal_id=="C1"
	drop if _m!=3
	drop _m
	
	kdensity baselogconsumption if type==1, nogr generate(x1 d1)
	kdensity baselogconsumption if type==2, nogr at(x1) generate(x2 d2)
	kdensity baselogconsumption if type==3, nogr at(x1) generate(x3 d3)
	
	gen cut1 = 1 if x1>12 & x1<13 & d1[_n-1]>d2[_n-1] & d1[_n]<d2[_n]
	gen cut2 = 1 if x1>13 & x1<14 & d2[_n-1]>d3[_n-1] & d2[_n]<d3[_n]

	sum x1 if cut1==1
	assert `r(N)'==1
	local c1=`r(mean)'
	
	sum x1 if cut2==1
	assert `r(N)'==1
	local c2=`r(mean)'

	pause do the cutoffs look ok? (~12.85 and ~13.3)
	
	* re-define type using the cutoff 
	
	gen 	type_panel=1 if baselogconsumption<`c1'
	replace type_panel=2 if baselogconsumption>`c1'
	replace type_panel=3 if baselogconsumption>`c2'
	replace type_panel=. if baselogconsumption==.
	
	*define the variable that defines eligibility 
	g treated_panel = 1 if (type_panel == 1) | (type_panel == 2 & inlist(TR1,1,2))
	replace treated_panel = 0 if type_panel== 3
	
	keep hhid_midline type_panel treated_panel 
	tempfile paneltype
	sa `paneltype'
	
restore

merge 1:1 hhid_midline using `paneltype'
count if _m==3
assert `r(N)'==3864
drop _m

****************************
* 6b. Analysis samples: 1=all, 2=CS1 comparable, 3=Panel
****************************

gen analysis_2=1 if jpal_id=="B1" | jpal_id=="B2" | jpal_id=="B3" | jpal_id=="B4" | jpal_id=="C1" | jpal_id=="C2"  
gen analysis_3=1 if type_panel!=. 

****************************
* 7. Coding treatments
****************************

g ALL = TR1 == 2
g CTL = TR1 == 1
g B10 = TR1 == 3
g PRC = TR1a == 0
g NOP = TR1a == 1
g CPN = TR1b == 0
g NOC = TR1b == 1
g STD = TR1c == 0
g ENH = TR1c == 1
g treatment = B10 + ALL
assert treatment + CTL == 1
g treated = 1 if (type == 1) | (type == 2 & inlist(TR1,1,2))
	/*  the variable "treated" should have been called "eligible"  */
replace treated = 0 if type== 3
g type2a = 1 if type == 1
g type2b = 1 if treated == 1 & type == 2
g type2c = 1 if treated == . | (type == 2 & CTL == 1)

****************************
* 8. Make Targeting II version for baseline analysis
****************************

preserve
	drop sample jpal_id type* t1 t2 t3 treated* int* hhid_udb skesj hhid_midline analysis* 
	duplicates drop
	merge 1:m hhea using `baseline'
	assert _m!=1
	keep if _m==3
	drop _m
	saveold "1Data/codeddata/cards_paper/midline/TargetingIIRaskin_mid.dta", replace
restore

****************************
* 9. Weights
****************************

* dummy for samples A, B and C
gen samplea=0
gen sampleb=0
gen samplec=0
replace samplea=1 if jpal_id=="A1" | jpal_id=="A2"
replace sampleb=1 if jpal_id=="B1" | jpal_id=="B2" | jpal_id=="B3" | jpal_id=="B4"
replace samplec=1 if jpal_id=="C1" | jpal_id=="C2"

*		*********************************
*		**** Full Sample (FS) weights ***
*		*********************************
{
* the number of treated eligible in treatment and control
count if treated == 1 & CTL != 1
local Net = `r(N)'
count if treated == 1 & CTL == 1
local Nec = `r(N)'
		
* the number of treated ineligible in treatment and control
count if treated == 0 & CTL != 1
local Nit = `r(N)'
count if treated == 0 & CTL == 1
local Nic = `r(N)'

gen weight_fs_CvC=.

* Treated vs Untreated (TvU) graphs
gen weight_fs_PRC=.
gen weight_fs_CPN=.
gen weight_fs_ENH=.

* by sample (byS) graphs
gen weight_fs_B10=.

* by sample (bySw) graphs
gen weight_fs_PRC_2=.
gen weight_fs_CPN_2=.
gen weight_fs_ENH_2=.

***** FS weights for Control vs Cards graphs
forv x = 1/10{
	*control cell size
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	*treatment cell size, excluding PPLS-other (they have treated=.)
	count if sample == `x' & CTL != 1 & treated == 1
	local trm_cellsize = `r(N)'

	replace weight_fs_CvC = `trm_cellsize'/`Net' * `Nec'/`ctl_cellsize' ///
	         if sample == `x' & CTL == 1
	replace weight_fs_CvC = 1 if sample == `x' & CTL != 1 & treated != .
}

// check : the mean should be 1 among eligible (we are not changing 
// total weight of the eligible group)
sum weight_fs_CvC if treated==1 & CTL==1
sum weight_fs_CvC if treated==1 & CTL==0

forv x = 11/15{
	*control cell size
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	*treatment cell size
	count if sample == `x' & CTL != 1 
	local trm_cellsize = `r(N)'

	replace weight_fs_CvC = `trm_cellsize'/`Nit' * `Nic'/`ctl_cellsize' ///
	      if sample == `x' & CTL == 1
	replace weight_fs_CvC = 1 if sample == `x' & CTL != 1 & treated != .
}
// check : the mean should be 1 
sum weight_fs_CvC if treated==0 & CTL==1
sum weight_fs_CvC if treated==0 & CTL==0

******* FS weights for PRC, CPN and ENH, for Treated vs Untreated graphs
forv a = 1/3 {								// loop treatments
	local t1 : word `a' of NOP NOC STD		// binary var names
	local t2 : word `a' of PRC CPN ENH	
	count if treated == 1 & `t1' == 1
	local Net1 = `r(N)'
	count if treated == 1 & `t2' == 1
	local Net2 = `r(N)'
	count if treated == 0 & `t1' == 1
	local Nit1 = `r(N)'
	count if treated == 0 & `t2' == 1
	local Nit2 = `r(N)'
	
forv x = 1/10{
	di "x if `x'"
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' & CTL != 1 & treated == 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1 & treated == 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1 & treated == 1
	local trm2_cellsize = `r(N)'

	di "`trm_cellsize'/`Net'"
	
	replace weight_fs_`t2' = `trm_cellsize'/`Net'*`Nec' /`ctl_cellsize'  ///
	       if sample == `x' & CTL == 1
	replace weight_fs_`t2' = `trm_cellsize'/`Net'*`Net1'/`trm1_cellsize' ///
	       if sample == `x' & `t1'== 1 & treated == 1
	replace weight_fs_`t2' = `trm_cellsize'/`Net'*`Net2'/`trm2_cellsize' ///
	       if sample == `x' & `t2'== 1 & treated == 1
}

// check : the mean should be 1 
sum weight_fs_`t2' if treated==1 &  CTL==1
sum weight_fs_`t2' if treated==1 & `t1'==1
sum weight_fs_`t2' if treated==1 & `t2'==1

forv x = 11/15{
	di "x if `x'"
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' & CTL != 1 & treated == 0
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1 & treated == 0
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1 & treated == 0
	local trm2_cellsize = `r(N)'

	replace weight_fs_`t2' = `trm_cellsize'/`Nit'*`Nic' /`ctl_cellsize'  ///
	        if sample == `x' & CTL == 1
	replace weight_fs_`t2' = `trm_cellsize'/`Nit'*`Nit1'/`trm1_cellsize' ///
	        if sample == `x' & `t1'== 1 & treated == 0
	replace weight_fs_`t2' = `trm_cellsize'/`Nit'*`Nit2'/`trm2_cellsize' ///
	        if sample == `x' & `t2'== 1 & treated == 0
}

// check : the mean should be 1 
sum weight_fs_`t2' if treated==0 & CTL==1
sum weight_fs_`t2' if treated==0 & `t1'==1
sum weight_fs_`t2' if treated==0 & `t2'==1

assert weight_fs_`t2'!=. | treated==.
pause check : the mean should be 1 

}

**** Make FS weights for "By sample B10/ALL" graphs 
// (not excluding PPLS-other here)
// We want to keep the total weight in each sample (B10, PPLS-o, n-PPLS) 
// times treatment arm (control, B10, ALL) constant. 
// Basically just re-weighting the 3-4 subsamples that go into one sample x treatment arm
// holding their total weight fixed

* the number of B10 hhds in treatment and control
count if type == 1 & CTL != 1
local N1t = `r(N)'
count if type == 1 & CTL == 1
local N1c = `r(N)'
count if type == 1 & ALL == 1
local N1t1 = `r(N)'
count if type == 1 & B10 == 1
local N1t2 = `r(N)'

di "`N1t1'+`N1t2' = `N1t'"  // true

* the number of PPLS-other hhds in treatment and control
count if type == 2 & CTL != 1
local N2t = `r(N)'
count if type == 2 & CTL == 1
local N2c = `r(N)'
count if type == 2 & ALL == 1
local N2t1 = `r(N)'
count if type == 2 & B10 == 1
local N2t2 = `r(N)'

* the number of non-PPLShhds in treatment and control
count if type == 3 & CTL != 1
local N3t = `r(N)'
count if type == 3 & CTL == 1
local N3c = `r(N)'
count if type == 3 & ALL == 1
local N3t1 = `r(N)'
count if type == 3 & B10 == 1
local N3t2 = `r(N)'

forv x = 1/5{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_fs_B10 = `trm_cellsize' / `N1t' * `N1c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_fs_B10 = `trm_cellsize' / `N1t' * `N1t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_fs_B10 = `trm_cellsize' / `N1t' * `N1t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_fs_B10 if CTL==1 & type==1
sum weight_fs_B10 if ALL==1 & type==1
sum weight_fs_B10 if B10==1 & type==1

forv x = 6/10{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_fs_B10 = `trm_cellsize' / `N2t' * `N2c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_fs_B10 = `trm_cellsize' / `N2t' * `N2t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_fs_B10 = `trm_cellsize' / `N2t' * `N2t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_fs_B10 if CTL==1 & type==2
sum weight_fs_B10 if ALL==1 & type==2
sum weight_fs_B10 if B10==1 & type==2

forv x = 11/15{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_fs_B10 = `trm_cellsize' / `N3t' * `N3c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_fs_B10 = `trm_cellsize' / `N3t' * `N3t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_fs_B10 = `trm_cellsize' / `N3t' * `N3t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_fs_B10 if CTL==1 & type==3
sum weight_fs_B10 if ALL==1 & type==3
sum weight_fs_B10 if B10==1 & type==3

assert weight_fs_B10!=.

***** Make FS weights for PRC, CPN and ENH, for "By sample" graphs (not excluding PPLS-other here) 

forv a = 1/3 {								// loop treatments
	local t1 : word `a' of NOP NOC STD		// binary var names
	local t2 : word `a' of PRC CPN ENH	

	* the number of B10 hhds in treatments and control
	count if type == 1 & CTL != 1
	local N1t = `r(N)'
	count if type == 1 & CTL == 1
	local N1c = `r(N)'
	count if type == 1 & `t1' == 1
	local N1t1 = `r(N)'
	count if type == 1 & `t2' == 1
	local N1t2 = `r(N)'

	di "`N1t1'+`N1t2' = `N1t'"  // true

	* the number of PPLS-other hhds in treatments and control
	count if type == 2 & CTL != 1
	local N2t = `r(N)'
	count if type == 2 & CTL == 1
	local N2c = `r(N)'
	count if type == 2 & `t1' == 1
	local N2t1 = `r(N)'
	count if type == 2 & `t2' == 1
	local N2t2 = `r(N)'

	* the number of non-PPLShhds in treatments and control
	count if type == 3 & CTL != 1
	local N3t = `r(N)'
	count if type == 3 & CTL == 1
	local N3c = `r(N)'
	count if type == 3 & `t1' == 1
	local N3t1 = `r(N)'
	count if type == 3 & `t2' == 1
	local N3t2 = `r(N)'

* for B10 hhds
forv x = 1/5{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_fs_`t2'_2 = `trm_cellsize' / `N1t' * `N1c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N1t' * `N1t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N1t' * `N1t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_fs_`t2'_2 if CTL==1 & type==1
sum weight_fs_`t2'_2 if `t1'==1 & type==1
sum weight_fs_`t2'_2 if `t2'==1 & type==1

* for PPLS-other hhds
forv x = 6/10{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_fs_`t2'_2 = `trm_cellsize' / `N2t' * `N2c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N2t' * `N2t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N2t' * `N2t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_fs_`t2'_2 if CTL==1 & type==2
sum weight_fs_`t2'_2 if `t1'==1 & type==2
sum weight_fs_`t2'_2 if `t2'==1 & type==2

* for non-PPLS hhdsB
forv x = 11/15{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_fs_`t2'_2 = `trm_cellsize' / `N3t' * `N3c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N3t' * `N3t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_fs_`t2'_2 = `trm_cellsize' / `N3t' * `N3t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_fs_`t2'_2 if CTL==1 & type==3
sum weight_fs_`t2'_2 if `t1'==1 & type==3
sum weight_fs_`t2'_2 if `t2'==1 & type==3

assert weight_fs_`t2'!=. | treated==.
}

}

*		********************************************
*		**** CS1 Comparable Sample (CS1) weights ***
*		********************************************

* redo exactly the same as in Full Sample, ommiting sample A = subsamples 1 5 9
{
tempfile uptocs1weights
save `uptocs1weights'

keep if analysis_2==1

* the number of treated eligible in treatment and control
count if treated == 1 & CTL != 1
local Net = `r(N)'
count if treated == 1 & CTL == 1
local Nec = `r(N)'
		
* the number of treated ineligible in treatment and control
count if treated == 0 & CTL != 1
local Nit = `r(N)'
count if treated == 0 & CTL == 1
local Nic = `r(N)'

gen weight_cs1_CvC=.

* Treated vs Untreated (TvU) graphs
gen weight_cs1_PRC=.
gen weight_cs1_CPN=.
gen weight_cs1_ENH=.

* by sample (byS) graphs
gen weight_cs1_B10=.

* by sample (bySw) graphs
gen weight_cs1_PRC_2=.
gen weight_cs1_CPN_2=.
gen weight_cs1_ENH_2=.

***** FS weights for Control vs Cards graphs
forv x = 1/10{
	*control cell size
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	*treatment cell size, excluding PPLS-other (they have treated=.)
	count if sample == `x' & CTL != 1 & treated == 1
	local trm_cellsize = `r(N)'

	replace weight_cs1_CvC = `trm_cellsize'/`Net' * `Nec'/`ctl_cellsize' ///
	         if sample == `x' & CTL == 1
	replace weight_cs1_CvC = 1 if sample == `x' & CTL != 1 & treated != .
}

// check : the mean should be 1 among eligible (we are not changing 
// total weight of the eligible group)
sum weight_cs1_CvC if treated==1 & CTL==1
sum weight_cs1_CvC if treated==1 & CTL==0
pause

forv x = 11/15{
	*control cell size
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	*treatment cell size
	count if sample == `x' & CTL != 1 
	local trm_cellsize = `r(N)'

	replace weight_cs1_CvC = `trm_cellsize'/`Nit' * `Nic'/`ctl_cellsize' ///
	      if sample == `x' & CTL == 1
	replace weight_cs1_CvC = 1 if sample == `x' & CTL != 1 & treated != .
}
// check : the mean should be 1 
sum weight_cs1_CvC if treated==0 & CTL==1
sum weight_cs1_CvC if treated==0 & CTL==0

******* FS weights for PRC, CPN and ENH, for Treated vs Untreated graphs
forv a = 1/3 {								// loop treatments
	local t1 : word `a' of NOP NOC STD		// binary var names
	local t2 : word `a' of PRC CPN ENH	
	count if treated == 1 & `t1' == 1
	local Net1 = `r(N)'
	count if treated == 1 & `t2' == 1
	local Net2 = `r(N)'
	count if treated == 0 & `t1' == 1
	local Nit1 = `r(N)'
	count if treated == 0 & `t2' == 1
	local Nit2 = `r(N)'
	
forv x = 1/10{
	di "x if `x'"
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' & CTL != 1 & treated == 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1 & treated == 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1 & treated == 1
	local trm2_cellsize = `r(N)'

	di "`trm_cellsize'/`Net'"
	
	replace weight_cs1_`t2' = `trm_cellsize'/`Net'*`Nec' /`ctl_cellsize'  ///
	       if sample == `x' & CTL == 1
	replace weight_cs1_`t2' = `trm_cellsize'/`Net'*`Net1'/`trm1_cellsize' ///
	       if sample == `x' & `t1'== 1 & treated == 1
	replace weight_cs1_`t2' = `trm_cellsize'/`Net'*`Net2'/`trm2_cellsize' ///
	       if sample == `x' & `t2'== 1 & treated == 1
}

// check : the mean should be 1 
sum weight_cs1_`t2' if treated==1 &  CTL==1
sum weight_cs1_`t2' if treated==1 & `t1'==1
sum weight_cs1_`t2' if treated==1 & `t2'==1
pause

forv x = 11/15{
	di "x if `x'"
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' & CTL != 1 & treated == 0
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1 & treated == 0
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1 & treated == 0
	local trm2_cellsize = `r(N)'

	replace weight_cs1_`t2' = `trm_cellsize'/`Nit'*`Nic' /`ctl_cellsize'  ///
	        if sample == `x' & CTL == 1
	replace weight_cs1_`t2' = `trm_cellsize'/`Nit'*`Nit1'/`trm1_cellsize' ///
	        if sample == `x' & `t1'== 1 & treated == 0
	replace weight_cs1_`t2' = `trm_cellsize'/`Nit'*`Nit2'/`trm2_cellsize' ///
	        if sample == `x' & `t2'== 1 & treated == 0
}


sum weight_cs1_`t2' if treated==0 & CTL==1
sum weight_cs1_`t2' if treated==0 & `t1'==1
sum weight_cs1_`t2' if treated==0 & `t2'==1
pause 

assert weight_cs1_`t2'!=. | treated==.
}

**** Make FS weights for "By sample B10/ALL" graphs 
// (not excluding PPLS-other here)
// We want to keep the total weight in each sample (B10, PPLS-o, n-PPLS) 
// times treatment arm (control, B10, ALL) constant. 

* the number of B10 hhds in treatment and control
count if type == 1 & CTL != 1
local N1t = `r(N)'
count if type == 1 & CTL == 1
local N1c = `r(N)'
count if type == 1 & ALL == 1
local N1t1 = `r(N)'
count if type == 1 & B10 == 1
local N1t2 = `r(N)'

di "`N1t1'+`N1t2' = `N1t'"  // true

* the number of PPLS-other hhds in treatment and control
count if type == 2 & CTL != 1
local N2t = `r(N)'
count if type == 2 & CTL == 1
local N2c = `r(N)'
count if type == 2 & ALL == 1
local N2t1 = `r(N)'
count if type == 2 & B10 == 1
local N2t2 = `r(N)'

* the number of non-PPLShhds in treatment and control
count if type == 3 & CTL != 1
local N3t = `r(N)'
count if type == 3 & CTL == 1
local N3c = `r(N)'
count if type == 3 & ALL == 1
local N3t1 = `r(N)'
count if type == 3 & B10 == 1
local N3t2 = `r(N)'

forv x = 1/5{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_cs1_B10 = `trm_cellsize' / `N1t' * `N1c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_cs1_B10 = `trm_cellsize' / `N1t' * `N1t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_cs1_B10 = `trm_cellsize' / `N1t' * `N1t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_cs1_B10 if CTL==1 & type==1
sum weight_cs1_B10 if ALL==1 & type==1
sum weight_cs1_B10 if B10==1 & type==1

forv x = 6/10{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_cs1_B10 = `trm_cellsize' / `N2t' * `N2c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_cs1_B10 = `trm_cellsize' / `N2t' * `N2t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_cs1_B10 = `trm_cellsize' / `N2t' * `N2t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_cs1_B10 if CTL==1 & type==2
sum weight_cs1_B10 if ALL==1 & type==2
sum weight_cs1_B10 if B10==1 & type==2

forv x = 11/15{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'

	count if sample == `x' & CTL != 1
	local trm_cellsize = `r(N)'

	count if sample == `x' &  ALL== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  B10== 1 
	local trm2_cellsize = `r(N)'

	replace weight_cs1_B10 = `trm_cellsize' / `N3t' * `N3c'/`ctl_cellsize' ///
	        if sample == `x' & CTL == 1
	replace weight_cs1_B10 = `trm_cellsize' / `N3t' * `N3t1'/`trm1_cellsize' /// 
		    if sample == `x' & ALL== 1
	replace weight_cs1_B10 = `trm_cellsize' / `N3t' * `N3t2'/`trm2_cellsize' ///
			if sample == `x' & B10== 1	
}
// means should be 1
sum weight_cs1_B10 if CTL==1 & type==3
sum weight_cs1_B10 if ALL==1 & type==3
sum weight_cs1_B10 if B10==1 & type==3

assert weight_cs1_B10!=.

***** Make FS weights for PRC, CPN and ENH, for "By sample" graphs (not excluding PPLS-other here) 

forv a = 1/3 {								// loop treatments
	local t1 : word `a' of NOP NOC STD		// binary var names
	local t2 : word `a' of PRC CPN ENH	

	* the number of B10 hhds in treatments and control
	count if type == 1 & CTL != 1
	local N1t = `r(N)'
	count if type == 1 & CTL == 1
	local N1c = `r(N)'
	count if type == 1 & `t1' == 1
	local N1t1 = `r(N)'
	count if type == 1 & `t2' == 1
	local N1t2 = `r(N)'

	di "`N1t1'+`N1t2' = `N1t'"  // true

	* the number of PPLS-other hhds in treatments and control
	count if type == 2 & CTL != 1
	local N2t = `r(N)'
	count if type == 2 & CTL == 1
	local N2c = `r(N)'
	count if type == 2 & `t1' == 1
	local N2t1 = `r(N)'
	count if type == 2 & `t2' == 1
	local N2t2 = `r(N)'

	* the number of non-PPLShhds in treatments and control
	count if type == 3 & CTL != 1
	local N3t = `r(N)'
	count if type == 3 & CTL == 1
	local N3c = `r(N)'
	count if type == 3 & `t1' == 1
	local N3t1 = `r(N)'
	count if type == 3 & `t2' == 1
	local N3t2 = `r(N)'

* for B10 hhds
forv x = 1/5{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N1t' * `N1c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N1t' * `N1t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N1t' * `N1t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_cs1_`t2'_2 if CTL==1 & type==1
sum weight_cs1_`t2'_2 if `t1'==1 & type==1
sum weight_cs1_`t2'_2 if `t2'==1 & type==1

* for PPLS-other hhds
forv x = 6/10{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N2t' * `N2c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N2t' * `N2t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N2t' * `N2t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_cs1_`t2'_2 if CTL==1 & type==2
sum weight_cs1_`t2'_2 if `t1'==1 & type==2
sum weight_cs1_`t2'_2 if `t2'==1 & type==2

* for non-PPLS hhdsB
forv x = 11/15{
	count if sample == `x' & CTL == 1
	local ctl_cellsize = `r(N)'
	
	count if sample == `x' &  CTL!= 1
	local trm_cellsize = `r(N)'
	
	count if sample == `x' &  `t1'== 1
	local trm1_cellsize = `r(N)'
	
	count if sample == `x' &  `t2'== 1
	local trm2_cellsize = `r(N)'

	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N3t' * `N3c'/`ctl_cellsize' ///
			if sample == `x' & CTL == 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N3t' * `N3t1'/`trm1_cellsize' ///
			if sample == `x' & `t1'== 1
	replace weight_cs1_`t2'_2 = `trm_cellsize' / `N3t' * `N3t2'/`trm2_cellsize' ///
			if sample == `x' & `t2'== 1
}
// means should be 1
sum weight_cs1_`t2'_2 if CTL==1 & type==3
sum weight_cs1_`t2'_2 if `t1'==1 & type==3
sum weight_cs1_`t2'_2 if `t2'==1 & type==3

assert weight_cs1_`t2'!=. | treated==.
}

* Re-weigh B10 people relative to PPLS-other to match what this is in CS1

* make the change for the weigths used in CvC and TvU treatments
foreach suf in CvC PRC CPN ENH{

* get CS1 weights that we want to match
preserve
	use "1Data/codeddata/cards_paper/beneficiaries and randomization.dta",clear 
	gen weightCvC = weightPRC  // same whether we use PRC, ENH or CPN
	
	*total weight of B10 			in CS1
	sum weight`suf' if type == 1 & treated == 1
	local n1_cs1 = `r(sum)'
	*total  weight of PPLS-other	 in CS1
	sum weight`suf' if type == 2 & treated == 1
	local n2_cs1 = `r(sum)'
	*total  weight of eligibles		 in CS1
	sum weight`suf' if (type==1 | type == 2) & treated == 1
	local ne_cs1 = `r(sum)'
	
restore

* get midline weights so far
	*total current weight of B10 
	sum weight_cs1_`suf' if type == 1 & treated == 1
	local n1 = `r(sum)'
	*total current weight of PPLS-other	
	sum weight_cs1_`suf' if type == 2 & treated == 1
	local n2 = `r(sum)'
	*total current weight of eligibles
	sum weight_cs1_`suf' if (type==1 | type == 2) & treated == 1
	local ne = `r(sum)'
	di "`ne' = `n1'+`n2'" //true

* get the relative ratio b/w B10 and PPLS-other in cs1 and mid
di "The total weights in the three income groups:"
di "mid: B10: `n1' and PPLS-other: `n2'" 
di "CS1: B10: `n1_cs1' and PPLS-other: `n2_cs1'" 
local mid_ratio=`n1'/`n2'
local cs1_ratio=`n1_cs1'/`n2_cs1'
di "Ratio in mid : `mid_ratio' = `n1'/`n2'"
di "Ratio in cs1 : `cs1_ratio' = `n1_cs1'/`n2_cs1'"

* update the midline weigths
replace weight_cs1_`suf' = `n1_cs1'/`ne_cs1' * `ne' / `n1' * weight_cs1_`suf' ///
		if type == 1 
replace weight_cs1_`suf' = `n2_cs1'/`ne_cs1' * `ne' / `n2' * weight_cs1_`suf' ///
		if type == 2 
		
* check that updating worked (ratio before should equal ratio after)
qui sum weight_cs1_`suf' if type == 1 
local n1_after = r(sum)
qui sum weight_cs1_`suf' if type == 2
local n2_after = r(sum)
local mid_ratio_after = `n1_after'/`n2_after'

di "Ratio in mid (before) : `mid_ratio' = `n1'/`n2'"
di "Ratio in mid (after ) : `mid_ratio_after' = `n1_after'/`n2_after'"
di "Ratio in cs1 : `cs1_ratio' = `n1_cs1'/`n2_cs1'"

}


keep hhid_midline weight_cs1* 
tempfile weights_cs1
sa `weights_cs1'

}

use `uptocs1weights'

merge 1:1 hhid_midline using `weights_cs1'
assert _m==3 | (_m==1 & analysis_2!=1) 
drop _m

****************************
* 10. Kabupaten 
****************************

merge m:1 hhea using `kabname'
assert _m!=1
keep if _m==3
drop _m

****************************
* 11. Clean up and SAVE
****************************

rename hhid_midline hhid
keep hhid hhea jpal_id kab_id type type_panel type2* t* TR1* kecagroup t2treatment ///
     t2trm*  ALL CTL B10 PRC NOP NOC CPN STD ///
     ENH treatment treated kec_id sample int_day int_month weight* analysis* ///
	 samplea sampleb samplec
	 
saveold "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid", replace

