/*******************************************************************************
RASKIN ENDLINE SURVEY - LEAKAGES AND TARGETING
NOTES:	
	kg to L rice conversion: .8 kg / L of rice
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off
pause off
set seed 6104691
set sortseed 6104691

cd "$RASKIN"

** INPUT DATA ******************************************************************

u "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta", clear
gen kea = hhea
gen kea1 = hhea1
merge m:1 kea kea1 using "1Data/originaldata/3_Endline/k_cr.dta"
assert _m == 3
drop kea kea1
drop _m

merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_c.dta"
assert _m==3
drop _m 

merge 1:m hhid using "1Data/originaldata/3_Endline/hh_b2.dta"	// 4 lines per HH
assert _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i = 1/12{
	gen FE`i' = (b22_mth == `i')
}

* confirm only one month per observation
assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day >= 25 | type_b22 >= 2)
	/* interview is on or after 25th of the month we're talking about, or we're
		talking about a previous month. */
* alternate
g usable2 = 1 if (int_day == 30 | int_day == 31 | type_b22 >= 2)

** HERE WE DEFINE A LOCAL SO WE CAN CHANGE THE DEFINITION OF USABLE ************
local usable_lcl usable
local usability_options usable usable2
********************************************************************************

** BOUGHT RASKIN ***************************************************************

* outcome 1a: rice in last month.
recode b25 (3 = 0) (8 = 0) (. = 0)

assert b25 == 0 | b25 == 1

** Gen the boughtrask variable
bys hhid: egen boughtrask = mean(b25) if `usable_lcl' == 1
la var boughtrask "Raskin purchase since Sept 2013"

** Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen boughtrask_`option' = mean(b25) if `option' == 1
	la var boughtrask_`option' "Raskin purchase since Sept 2013 (`option')"
}

// In theory there should be a single "max" for one household, but this fails
// because of an error in b22_mth
forv i = 1/5{
	local x : word `i' of 9 10 11 12 1
	local mon : word `i' of sep13 oct13 nov13 dec13 jan14
	g temp = b25 if b22_mth == `x' & `usable_lcl' == 1
	bys hhid: egen boughtrask_`mon' = max(temp)
		bys hhid: egen temp2 = min(temp)   
		count if temp2 != boughtrask_`mon'
		// pause
		assert `r(N)'<=0   
		
	drop temp temp2
	la var boughtrask_`mon' "HH bought raskin (`mon')"
}


* 6/30/14: Bought_s with correct usability restriction
g bought_s_sep = (boughtrask_sep13==1 | boughtrask_nov13==1 | boughtrask_dec13==1)
bys hhid: egen bought_s_sep13 = max(bought_s_sep)
drop bought_s_sep
la var bought_s_sep13 "Bought raskin since September"

g bought_s_nov = (boughtrask_nov13==1 | boughtrask_dec13==1)
bys hhid: egen bought_s_nov13 = max(bought_s_nov)
drop bought_s_nov
la var bought_s_nov13 "Bought raskin since November"

* Bought last2m
gen bought_last2m = bought_s_nov13
la var bought_last2m "Bought Raskin since Nov 2013"

preserve
	keep hhid bought_s_sep13 bought_s_nov13 bought_last2m
	duplicates drop
	isid hhid
	saveold "1Data/codeddata/cards_paper/endline/bought_s.dta", replace
restore

** AMOUNT PURCHASED ************************************************************
* outcome 2: amount purchased
replace b26 = . if b26 == 9995

*replace b26 = b26 / 10  // *WAS: what's this?
assert b26 < 100 | b26 == .	

* convert Liters to Kg
replace b26 = b26 * 0.8 if b26_x == 1 
replace b26 = 0 if b25 == 0

** Cleaning of odd values for amount.

replace b26 = . if b26 > 35 | b26 < 0

** Generate the amtraskin variable.
bys hhid: egen amtraskin = mean(b26) if `usable_lcl' == 1
la var amtraskin "Amount of raskin purchased per month since Sept 2013 (kg)"

** Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen amtraskin_`option' = mean(b26) if `option' == 1
	la var amtraskin_`option' "Amount of raskin purchased per month since Sept 2013 (kg) (`option')"
}

** Amtraskin variables for each month
forv i = 1/5{
	local x : word `i' of 9 10 11 12 1
	local mon : word `i' of sep13 oct13 nov13 dec13 jan14
	g temp = b26 if b22_mth == `x' & `usable_lcl' == 1
	bys hhid: egen amtraskin_`mon' = max(temp)
		bys hhid: egen temp2 = min(temp)   
		assert temp2 == amtraskin_`mon' 
			/* this catches cases where a hh gives more than one record of a
			given month and they conflict on b26 */
	drop temp temp2
	la var amtraskin_`mon' "Amount of raskin (kg, `mon')"
}

* amount was 15
g temp = amtraskin == 15
bys hhid: egen amtis15 = max(temp)
la var amtis15 "HH bought exactly 15 kg at least once"
drop temp

** PRICE PAID ******************************************************************
* (according to HH) (keep temp to define month from last time)

// convert to price per kg
replace b27 = b27 / b26 if b27_x == 1	// if it's a total price
replace b27 = b27 * 1.25 if b27_x == 2	// if it's a liter price

* Clean.
replace b27 = . if b27 < 500 | b27 >10000 // absurd values.

** Generate price_hh variables
bys hhid: egen price_hh = mean(b27) if `usable_lcl' == 1
la var price_hh "Raskin price since Sept 2013 (Rp/kg)"

** Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen price_hh_`option' = mean(b27) if `option' == 1
	la var price_hh_`option' "Raskin price since Sept 2013 (Rp/kg) (`option')"
}

** price_hh variables for each month
forv i = 1/5{
	local x : word `i' of 9 10 11 12 1
	local mon : word `i' of sep13 oct13 nov13 dec13 jan14
	g price_hh_`mon' = b27 if b22_mth == `x' & `usable_lcl' == 1
	la var price_hh_`mon' "Price of raskin (Rp/kg, `mon')"
}

** MARKET PRICE OF RICE ********************************************************
*prep for outcomes 4a and 4b.
replace c04 = c04 * 1.25 if c04_x == 2

* marketprice for rice of similar quality
sum c04 if c05 == 2 // condition is that quality was the same as raskin
local mprice = `r(mean)'
gen marketprice = `r(mean)'
la var marketprice "Market price of rice"

preserve
	gen c04_v2 = c04 if c05 == 2
	collapse kab_marketprice = c04_v2, by(kab_id)
	la var kab_marketprice "Market price of rice (avg in district)"
	gen marketprice = `mprice'
	la var marketprice "Market price of rice (avg overall)"
	saveold "1Data/codeddata/cards_paper/endline/marketprices_end.dta", replace
restore

ta c05
	/* only 4% of hh's report that the rice they purchased in the market
		was of the same quality as raskin (95% said market rice was better) */
		
** Village raskin price
bys hhea: egen raskprice = mean(b27)

foreach var in CTL ALL B10 PRC CPN ENH{
	sum c04 if `var' == 1 & c05 == 2
}
replace b27 = raskprice if b27 == . & b26 != 0 & b26 != .  
drop raskprice

** SUBSIDY *********************************************************************

g sub = ((marketprice - b27) * b26)

** Clean odd values of subsidy variable
replace sub = 0 if b26 == 0 | sub < 0

* outcome 4b: subsidy received (rp)
bys hhid: egen subsidy_rcvd = mean(sub) if `usable_lcl' == 1
la var subsidy_rcvd "Subsidy received (Rp./month avg since September)"

** Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen subsidy_rcvd_`option' = mean(sub) if `option' == 1
	la var subsidy_rcvd_`option' "Subsidy received (Rp./month avg since September) (`option')"
}

** price_hh variables for each month
forv i = 1/5{
	local x : word `i' of 9 10 11 12 1
	local mon : word `i' of sep13 oct13 nov13 dec13 jan14
	g temp = sub if b22_mth == `x' & `usable_lcl' == 1
	bys hhid: egen subsidy_rcvd_`mon' = max(temp)
		bys hhid: egen temp2 = min(temp)
	assert temp2 == subsidy_rcvd_`mon' 
			/* this catches cases where a hh gives more than one record of a
			given month and they conflict on subsidy received */
	drop temp temp2
	la var subsidy_rcvd_`mon' "Subsidy received (Rp. `mon')"
}

** RICE WAS HIGH-QUALITY *******************************************************

gen qual_mo = b30 == "A" if !mi(b30)

* Generate the quality mean variable.
bys hhid: egen qual_mean = mean(qual_mo) if `usable_lcl' == 1
la var qual_mean "Mean of month dummies for whether rice was quality"

* Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen qual_mean_`option' = mean(qual_mo) if `option' == 1
	la var qual_mean_`option' "Mean of month dummies for whether rice was quality (`option')"
}


* RICE AMOUNT WAS FAIR ********************************************************

gen fair_mo = b25c < 3 if !inlist(b25c,8,.)

* Generate the fair mean variable.
bys hhid: egen fair_mean = mean(fair_mo) if `usable_lcl' == 1
la var fair_mean ///
  "Mean of month dummies for whether received at least as much rice as paid for"

* Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen fair_mean_`option' = mean(fair_mo) if `option' == 1
	la var fair_mean_`option' ///
	  "Mean of month dummies for whether received at least as much rice as paid for"
}

drop sub qual_mo fair_mo usable* cr01_mth-b30 marketprice

****************************
* 3. Collapse
****************************

foreach v of varlist boughtrask* amtraskin* price_hh* subsidy_rcvd* qual_mean* fair_mean* {
	local a : var label `v'
	ren `v' a`v'
	bys hhid: egen `v' = max(a`v')
	bys hhid: egen b`v' = min(a`v')
	assert b`v' == `v'
	drop a`v' b`v'
	la var `v' "`a'"
}

preserve
	keep hhid FE1-FE12
	collapse (sum) FE1-FE12 , by(hhid)
		forv i = 1/12{
			count if FE`i' > 1
			assert `r(N)' <= 3 
			replace FE`i' = 1 if FE`i' > 1
		}
	tempfile fes
	sa `fes'
restore

drop FE1-FE12

duplicates drop

merge 1:1 hhid using `fes'
assert _m == 3
drop _m

****************************
* 4. Village level variable
****************************

**price variance
g price_variance = .
g price_range = .
levelsof hhea
foreach h in `r(levels)' {
	sum price_hh if hhea == "`h'"
	if `r(N)' > 0 replace price_variance = `r(sd)' if hhea == "`h'"
	if `r(N)' > 0 replace price_range = `r(max)' - `r(min)' if hhea == "`h'"
	}
la var price_var "SD of price in village"
la var price_range "Max - min of price in village"


****************************
* 5. Clean up and save
****************************

isid hhid
saveold "1Data/codeddata/cards_paper/endline/leakagestargeting_end.dta", replace
