/*******************************************************************************
RASKIN ENDLINE SURVEY - WEIGHTS CODING
OUTLINE:
	- Loop over full sample (fs) and CS1-comparable sample
	- Force balance of beneficiary status across treatment and control
	- Force balance of beneficiary status across CS1 and Midline subsamples, 
		within kecamatans
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off

pause off
set seed 6104691
set sortseed 6104691

scalar precise = 1e-15

cd "$RASKIN"

		
** WEIGHTS *********************************************************************
********************************************************************************
********************************************************************************

/*  Intuition: 
	
	We want to identify the effect of each subtreatment by comparing the mean
	outcome of the treatment group with the mean outcome of the control group.
	In a straightforward RCT, we could be confident that the treatment and
	control groups were comparable because they would be randomly selected from
	the same population.  Or suppose we were particularly worried that a certain
	observable trait would not be balanced in the treatment and control
	populations and would thereby misleadingly and differentially affect the
	mean outcomes of our two groups.  We could stratify on that trait, mandating
	that it be equally represented in the treatment and control groups.
	
	For example, in the case at hand, one trait which is likely to affect mean 
	outcomes is	household income.  In particular, each household is categorized
	as B10 (bottom 10% of the income distribution), Other Beneficiary (11-30%
	of the income distribution), or Non-Beneficiary (everyone else).  One of our
	subtreatments depends on this categorization: in villages assigned to the
	"Bottom 10" treatment, only B10 households are assigned to receive a card.
	More broadly, however, the treatment we're interested in is "being assigned
	to receive a card", as compared with "being ineligible to buy Raskin".  
	So the PPLS-other households in villages given the B10 treatment are dropped
	from every analysis besides the B10 subtreatment analysis, as they were
	neither assigned to receive a card nor were they ineligible to buy Raskin.
	
	This creates problems for our comparison.  The composition of the treatment
	group is now measurably different from that of the control group, since
	a big chunk of people from a certain income category were dropped from
	the treatment group but no corresponding drop was made from the control
	group.  If we were to compare the means of the treatment and the control
	groups, any effect might be attributable not to the treatment but to the
	income differences between the two groups.
	
	Weights to the rescue.  We give more weight to households from the 
	underrepresented category in the group in which they are underrepresented,
	such that the composition of the treatment group and the control group are
	equal.  To accomplish this, we first look at the treatment group.  We measure
	the fraction of the treatment group which comes from each subsample we're
	interested in.  In the case of endline data, we care about 6 subsample
	cells:

			3 hh types (B10, PPLS-other, Non-Ben) 
		  x	2 sources (CS1, midline).
	
	Let "subsample_fraction" denote the fraction of households in a group
	(treatment or control) which come from a given subsample.
	We then construct weights FOR EACH SUBSAMPLE such that:
	
		weight * (subsample_fraction_control) == (subsample_fraction_treatment)
		   
	Rearranging, we get:

		weight = (1 / subsample_fraction_control) * (subsample_fraction_treatment)
		
	which is how you'll see it constructed below.
	
	
	WEIGHTS INTUITION PART 2:
	Likewise, we want to ensure that there are equal proportions of each income
	bracket subsample in the CS1 group and the Midline group.  We enforce this
	balance even more strictly than that described above -- within each 
	subtreatment * kecamatan.
*/

** LOOP OVER FULL SAMPLE WEIGHTS AND CS1-COMPARABLE WEIGHTS ********************
********************************************************************************

foreach smp in fs cs1{

use "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end", clear

	if "`smp'" == "cs1"{
	
		** CS1-COMPARABLE SAMPLE WEIGHTS ***********************************************
		********************************************************************************

		/* 	What does "CS1-comparable" mean?
			For the Midliners, we have to drop everyone who came from Midline Sample A, 
			and drop every PKH-ineligible hh.  For CS1, we only have to drop every 
			PKH-ineligible hh.  */
	
		keep if inlist(jpal_id,"E1A","E2A","E3A") // keep CS1 subsample

		** Making CS1 CS1-comparable
		** Drop the PKH-ineligibles from CS1
		preserve
			use "1Data/originaldata/1_CS1/hh_ar.dta", clear
			* time of baseline T2 - Dec 2010 - Feb 2011

			// Date of CS1: November 2012
			* exclude babies born after sept 2011 and teens who were 16 in dec 2010
			gen tooyoung = (ar04a_m < 15)
			gen tooold   = (ar04a_yr >= 17)

			gen temp = !tooyoung & !tooold
			by hhid: egen pkhelig = sum(temp)
			replace pkhelig = pkhelig > 0

			duplicates drop hhid, force
			replace hhid = hhid + "A"
			keep hhid pkhelig
			tempfile pkhelig_cs1
			sa `pkhelig_cs1'
		restore

		merge 1:1 hhid using `pkhelig_cs1'
		assert _m != 1 // all cs1ers from endline should be found in CS1 itself
		drop if _m == 2 // drop people not in our endline
		drop if pkhelig == 0
		drop _m

		tempfile cs1sub
		sa `cs1sub'

		** Making Midline CS1-comparable
		** Find which midliners came from Sample A, so we can drop them.
		use "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end", clear
		keep if inlist(jpal_id,"E1B","E2B","E3B") // keep midline subsample
			
		preserve
			ren jpal_id jpal_id_end
			keep hhid jpal_id_end
			gen hhid_end = hhid
			replace hhid = substr(hhid,1,length(hhid) - 1)
			merge 1:1 hhid using "1Data/codeddata/cards_paper/midline/combined_mid.dta"
			assert _m != 1
			keep if _m == 3
			ren jpal_id jpal_id_mid
			drop hhid
			ren hhid_end hhid
			keep hhid jpal_id_mid
			tempfile xwalk_mid
			sa `xwalk_mid'
		restore

		** Drop hh's from Midline Sample "A"
		merge 1:1 hhid using `xwalk_mid'
		ta jpal_id_mid
		drop if inlist(jpal_id_mid,"A1","A2")
		drop _m

		** Drop the PKH-ineligibles from Midline.
		preserve
			use "1Data/originaldata/2_midline/hh_ar1.dta", clear
			* time of baseline T2 - Dec 2010 - Feb 2011

			// Midline date : March 2013
			* exclude babies born after sept/2011 and teens who were 16 in dec 2010
			gen tooyoung = (ar04a_m < 19)
			gen tooold   = (ar04a_yr >= 18)
			
			gen temp = !tooyoung & !tooold
			by hhid: egen pkhelig = max(temp)

			duplicates drop hhid, force
			replace hhid = hhid + "B"
			keep hhid pkhelig
			tempfile pkhelig_mid
			sa `pkhelig_mid'
		restore

		merge 1:1 hhid using `pkhelig_mid'
		assert _m != 1 // all midliners from endline should be found in midline itself
		drop if _m == 2 // drop people not in our endline
		drop if pkhelig == 0
		drop _m

		** COMBINE THE FILTERED CS1 AND MIDLINE SUBSAMPLES
		append using `cs1sub'
	}
	
	** NOW CALCULATE WEIGHTS ON RESULTING DATASET ******************************
	
	
	** ENSURE RATIO OF B10/PPLS-o HH'S IS THE SAME IN TREATMENT AND CONTROL. ***
	****************************************************************************
	
	** MAIN WEIGHTS FOR OVERALL CARDS v. CONTROL TREATMENT 
	/*	"control" 	: raskin-eligible control hh's
		"treatment"	: card-assigned hh's		*/
	
	* the number of "eligible" hh's in treatment and control, respectively
	count if treated == 1 & CTL != 1
	local Net = `r(N)'  /* # of hh's assigned to receive a card */
	count if treated == 1 & CTL == 1
	local Nec = `r(N)'  /* # of hh's eligible to get raskin in control villages */

	gen double weight_`smp'_CvC = .
	replace weight_`smp'_CvC = 1 if treated == 0
		// Ineligible get their own weight
	replace weight_`smp'_CvC = 1 if CTL != 1 & treated != .
		// Likewise Eligible in the treatment group
				
	forv x = 1/2{  // iterate over B10 and PPLS-other (subsamples of eligibles)
		* # of control hh's from subsample cell
		count if type == `x' & CTL == 1
		local ctl_cellsize = `r(N)'
		
		* # of treatment hh's from subsample cell
			// (excluding PPLS-other hh's from B10-treated villages)
		count if type == `x' & CTL != 1 & treated == 1
		local trm_cellsize = `r(N)'

		* Create weights for Eligible control hh's of this type
		replace weight_`smp'_CvC = `trm_cellsize'/`Net' * `Nec'/`ctl_cellsize'  ///
		  if type == `x' & CTL == 1
	}

	** Make sure that we have reweighted WITHIN the four eligibility status *
		* treatment status cells, but not changed their weights relative to each
		* other.
	
	sum weight_`smp'_CvC if treated == 1 & CTL == 1
		
		assert `r(mean)' == 1
	sum weight_`smp'_CvC if treated == 1 & CTL == 0
		assert `r(mean)' == 1
	sum weight_`smp'_CvC if treated == 0 & CTL == 1
		assert `r(mean)' == 1
	sum weight_`smp'_CvC if treated == 0 & CTL == 0
		assert `r(mean)' == 1
		
	
	** Weights for subtreatments: PRC, CPN ENH 
	/* Intuition:
		Here, the same intuition applies as with the more broadly defined treatment
		above, but we create weights this time to force the subsample composition of
		each subtreatment group (treated and untreated) to reflect that of the
		control group (no treatment). */ 

	forv a = 1/3 {								// loop treatments
		local t1 : word `a' of NOP NOC STD
		local t2 : word `a' of PRC CPN ENH
		
		gen double weight_`smp'_`t2' = .

		count if treated == 1 & `t1' == 1
		local Net1 = `r(N)'
		count if treated == 1 & `t2' == 1
		local Net2 = `r(N)'
		
		forv x = 1/2{
			di "type `x'"
			count if type == `x' & CTL == 1
				local ctl_cellsize = `r(N)'
			count if type == `x' & CTL != 1 & treated == 1
				local trm_cellsize = `r(N)'
			count if type == `x' & `t1'== 1 & treated == 1
				local trm1_cellsize = `r(N)'
			count if type == `x' & `t2'== 1 & treated == 1
				local trm2_cellsize = `r(N)'

			di "subsample_fraction_treatment = `trm_cellsize'/`Net'"
			replace weight_`smp'_`t2' = `trm_cellsize'/`Net' * `Nec'/`ctl_cellsize'  ///
			   if type == `x' & CTL == 1
			replace weight_`smp'_`t2' = `trm_cellsize'/`Net' * `Net1'/`trm1_cellsize' ///
			   if type == `x' & `t1'== 1 & treated == 1
			replace weight_`smp'_`t2' = `trm_cellsize'/`Net' * `Net2'/`trm2_cellsize' ///
			   if type == `x' & `t2'== 1 & treated == 1
		}
		
		replace weight_`smp'_`t2' = 1 if treated == 0
			/* Ineligibles require no reweighting */

		// check : the mean should be 1 
		sum weight_`smp'_`t2' if treated == 1 &  CTL == 1
			assert `r(mean)' == 1
		sum weight_`smp'_`t2' if treated == 1 & `t1' == 1
			assert `r(mean)' == 1
		sum weight_`smp'_`t2' if treated == 1 & `t2' == 1
			assert `r(mean)' == 1
		sum weight_`smp'_`t2' if treated == 0 & CTL == 1
			assert `r(mean)' == 1
		sum weight_`smp'_`t2' if treated == 0 & `t1' == 1
			assert `r(mean)' == 1
		sum weight_`smp'_`t2' if treated == 0 & `t2' == 1
			assert `r(mean)' == 1

		assert weight_`smp'_`t2' != . | treated == .
	}

	** Weights for B10/ALL subtreatment 
	gen double weight_`smp'_B10 = 1
	
	
	** ENSURE RATIO OF B10/PPLS-o HH'S IS THE SAME IN MID AND CS1 SUBSAMPLES. **
	** WITHIN EACH KECAMATAN ***************************************************
	
	** Set missing weights to 0, for now.
	
	foreach EXT in CvC ENH PRC CPN B10{
		replace weight_`smp'_`EXT' = 0 if weight_`smp'_`EXT' == .
	}
	
	forv i=1/14{
		local suf: word `i' of CvC CvC       ENH ENH ENH PRC PRC PRC CPN CPN CPN B10 B10 B10
		local t1 : word `i' of CTL treatment CTL STD ENH CTL NOP PRC CTL NOC CPN CTL ALL B10
		
		** Count type-specific cell sizes in CS1 and Midline.
		foreach src in cs1 mid{
			bys kec_id: egen  n1_`suf'_`t1'_`smp'_`src' = ///
				sum(weight_`smp'_`suf'*(type==1)*`t1'*`src')
			bys kec_id: egen  n2_`suf'_`t1'_`smp'_`src' = ///
				sum(weight_`smp'_`suf'*(type==2)*`t1'*`src')
			bys kec_id: egen  n3_`suf'_`t1'_`smp'_`src' = ///
				sum(weight_`smp'_`suf'*(type==3)*`t1'*`src')
		}
		
		** When a CS1 cell is empty, also empty the corresponding midline cell 
		** and vice versa.
		forv x = 1/3{
			local num 		: word `x' of 	n1 			n2 			n3
			local condition : word `x' of "type == 1" "type == 2" "type == 3"
			replace `num'_`suf'_`t1'_`smp'_cs1 = 0 ///
			  if inlist(0,`num'_`suf'_`t1'_`smp'_cs1,`num'_`suf'_`t1'_`smp'_mid) ///
			  & `condition' & `t1' == 1
			replace `num'_`suf'_`t1'_`smp'_mid = 0 ///
			  if inlist(0,`num'_`suf'_`t1'_`smp'_cs1,`num'_`suf'_`t1'_`smp'_mid) ///
			  & `condition' & `t1' == 1
		}
		
		** Now that we've emptied out some type-specific cells, calculate totals
		foreach src in cs1 mid{
			bys kec_id: gen tot_`suf'_`t1'_`smp'_`src' = ///
				n1_`suf'_`t1'_`smp'_`src' + n2_`suf'_`t1'_`smp'_`src' + ///
				n3_`suf'_`t1'_`smp'_`src'
		}
		
		forv type = 1/3{
			** Make the adjustments to Midline cells
			* multiply by (cs1 cell weight), divide by (midline cell weight)
			* multiply by (midline total cell weight - all income groups),
			* divide by (cs1 total cell weight - all income groups)
			replace weight_`smp'_`suf' = weight_`smp'_`suf' * ///
			  n`type'_`suf'_`t1'_`smp'_cs1 / n`type'_`suf'_`t1'_`smp'_mid * ///
			  tot_`suf'_`t1'_`smp'_mid / tot_`suf'_`t1'_`smp'_cs1 ///
			  if type == `type' & `t1' & mid == 1
			
			** Also set weights on cs1 cells to 0 if type-specific cell is now empty.
			replace weight_`smp'_`suf' = 0 if ///
			  inlist(0,n`type'_`suf'_`t1'_`smp'_cs1,n`type'_`suf'_`t1'_`smp'_mid) ///
			  & type == `type' & `t1' & cs1 == 1
		}
			
	}

	** Set 0 weights back to missing.
	foreach EXT in CvC ENH PRC CPN B10{
		replace weight_`smp'_`EXT' = . if weight_`smp'_`EXT' == 0
	}	
	
	

	** CHECKS ******************************************************************
	
	* test that the relative ratios of the three income groups is the same for 
	* midline and cs1 data, by treatment x keca_id, and for the 2 samples (fs and cs1)
	
	preserve
		destring kec_id, gen(k2)
		drop kec_id
		rename k2 kec_id
		
		
		forv i=1/14{
		local tr : word `i' of CTL treatment CTL STD ENH CTL B10 ALL CTL CPN NOC CTL PRC NOP
		local suf: word `i' of CvC CvC       ENH ENH ENH B10 B10 B10 CPN CPN CPN PRC PRC PRC   
			
		 qui tab kec_id type if `tr' & cs1 == 1 [aweight=weight_`smp'_`suf'], matcell(m1) matrow(n1)		
		 qui tab kec_id type if `tr' & mid == 1 [aweight=weight_`smp'_`suf'], matcell(m2)
			 
			svmat n1
			svmat m1
			svmat m2
			g m1t = m11+m12+m13
			g m2t = m21+m22+m23
			
			replace m11=m11/m1t
			replace m12=m12/m1t
			replace m13=m13/m1t
			
			replace m21=m21/m2t
			replace m22=m22/m2t
			replace m23=m23/m2t
			
			gen d1 = abs(m11 - m21)
			gen d2 = abs(m12 - m22)
			gen d3 = abs(m13 - m23)
			
			count if (d1>.05 & d1!=.)
			if `r(N)'>0 pause "group 1 `tr' `suf'"	
			count if (d2>.05 & d2!=.)
			if `r(N)'>0 pause "group 2 `tr' `suf'"
			count if (d3>.05 & d3!=.)
			if `r(N)'>0 pause "group 3 `tr' `suf'"
			
			drop n11-d3
		}

		
		// pause weights work - cell by cell there is balance between bottom10, UDB-other and non-UDB
	restore
	
	** KEEP WEIGHTS AND SAVE TEMP
	keep hhid weight* 
	tempfile weights_`smp'
	sa `weights_`smp''	
	
}

** CLEAN UP AND SAVE ***********************************************************
u `weights_fs', clear
merge 1:1 hhid using `weights_cs1'
assert _m != 2
gen analysis_2 = 1 if _m == 3
drop _m
	 
saveold "1Data/codeddata/cards_paper/endline/weights_end.dta", replace

