/*******************************************************************************
RASKIN PREP - VARIABLES WHICH APPEAR IN ALL WAVES OF SURVEY
1Data/dofiles/prep/allwave_vars.do

SUMMARY: 
	Prepare variables which appear in CS1, Midline, and Endline.
OUTLINE:
	This file prepares variables which are needed in the competition paper analysis,
	and which appear in all waves of the survey, but which weren't prepared
	as part of the cards paper analysis.
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

********************************************************************************
** PREP OF VARIABLES IN ALL SURVEY WAVES ***************************************
	/*  generate these variables for all waves of the survey so we can 
		control for a hh's previous responses to the question.*/

forv i = 1/3{
** Set up the loops to do this for each dataset.
	local path_name : 		word `i' of 1_CS1 2_Midline 3_Endline
	local path : 			word `i' of 1_CS1/NewUpdate 2_Midline 3_Endline
	local village_id : 		word `i' of commid commid kea
	local _suf : 			word `i' of _cs1 _mid ""
	local X : 				word `i' of A B ""
	local _ : 				word `i' of "" "" _

** Distribution location *******************************************************
	u "1Data/originaldata/`path'/hh_b1", clear
	replace hhid = hhid + "`X'"
	ren b14 distance`_suf'
	replace distance`_suf' = distance`_suf' * 1000 if b14`_'x == 1 // convert km to meters
	ren b16 time`_suf'
	replace time`_suf' = time`_suf' * 60 if b16`_'x == 1 // convert hrs to minutes
	gen in_rt`_suf' = inlist(b13,4,5) if !inlist(b13,98,.)
	la var distance`_suf' "`_suf'Distance to Raskin purchase point (meters)"
	la var time`_suf' "`_suf'Time to Raskin purchase point (minutes)"
	la var in_rt`_suf' "`_suf'HH purchased Raskin in own RT"
	
** Payment in advance
	gen pay_adv`_suf' = b09 == 1 if b09 != 8 & b09 != .
	la var pay_adv`_suf' "`_suf'HH purchased Raskin in advance"	
	keep hhid distance`_suf' time`_suf' in_rt`_suf' pay_adv`_suf'
	tempfile loc_adv`_suf'
	sa `loc_adv`_suf''
	
** Do they believe they're on the list? ****************************************
	u "1Data/originaldata/`path'/hh_sr", clear
	replace hhid = hhid + "`X'"
	gen believe_onlist`_suf' = sr06 == 1 if sr06 != 3
	la var believe_onlist`_suf' "`_suf'HH reports being included on the Raskin list"
	cap gen sr06`_suf' = sr06
	keep hhid believe_onlist`_suf' sr06`_suf'
	tempfile onlist`_suf'
	sa `onlist`_suf''

** Satisfaction ****************************************************************
	u "1Data/originaldata/`path'/hh_f", clear
	replace hhid = hhid + "`X'"
	forv xx = 1/10{
		local newvar : word `xx' of satis_prog all_should place_easy ///
		  selected_poor amt_rcvd time_matched list_announced moving_easy ///
		  trust_bidcom satis_proc  
		local numvar : word `xx' of f01a f01b f02 f03 f04 f05 f06 f07 f08 f09
	* Dummy
		gen `newvar'_dum`_suf' = inlist(`numvar',1,2) if !inlist(`numvar',6,.)
	* Categorical
		gen `newvar'_cat`_suf' = `numvar'
		recode `newvar'_cat`_suf' (1 = 4) (2 = 3) (3 = 2) (4 = 1) (6 = .)
	* Categorical - 0-1 Scaled
		gen `newvar'_cat01`_suf' = (`newvar'_cat`_suf' - 1)/(4-1)
		assert `newvar'_cat01`_suf' == . if `newvar'_cat`_suf' == .
	* No opinion dummy
		gen `newvar'_noop`_suf' = `numvar' == 6 if !mi(`numvar')
	}
	forv yy = 1/3{
		local typ	: word `yy' of dum cat cat01
		local desc	: word `yy' of "binary" "4 categories" "0-1 scale"
		la var satis_prog_`typ'`_suf' "`_suf'Satisfied with Raskin program (`desc')"
		la var all_should_`typ'`_suf' "`_suf'All HHs in this RT should receive Raskin (`desc')"
		la var place_easy_`typ'`_suf' "`_suf'Raskin distribution place is easy to reach (`desc')"
		la var selected_poor_`typ'`_suf' "`_suf'HHs selected are poor (`desc')"
		la var amt_rcvd_`typ'`_suf' "`_suf'Amt of Raskin received is matched with regulation (`desc')"
		la var time_matched_`typ'`_suf' "`_suf'Time for Raskin distribution is matched with regulation (`desc')"
		la var list_announced_`typ'`_suf' "`_suf'HHs that receive Raskin according to the list of beneficiaries have been announced before (`desc')"
		la var moving_easy_`typ'`_suf' "`_suf'Moving Raskin from shared point to the beneficiary's HH is easy (`desc')"
		la var trust_bidcom_`typ'`_suf' "`_suf'Trust in Raskin dist. committee (`desc')"
		la var satis_proc_`typ'`_suf' "`_suf'Satisfied with process for determining Raskin beneficiaries (`desc')"
	}
	keep hhid satis_prog* all_should* place_easy* ///
		  selected_poor* amt_rcvd* time_matched* list_announced* moving_easy* ///
		  trust_bidcom* satis_proc*  
	tempfile satis`_suf'
	sa `satis`_suf''
}

** Combine          ************************************************************

** Endline
u `loc_adv', clear
foreach data in satis onlist{
	merge 1:1 hhid using ``data''
	assert _m == 3
	drop _m
}

** CS1/Midline
local numHH = _N
foreach data in loc_adv satis onlist{
	foreach suf in cs1 mid{
		merge 1:1 hhid using ``data'_`suf''
		count if _m == 3
		local count_`suf' = `r(N)'
		keep if _m != 2
		drop _m
	}
	assert `count_cs1' + `count_mid' == `numHH'
		// everyone has followup data from either cs1 or midline
}

** SAVE ************************************************************************

saveold "1Data/codeddata/competition/allwave_vars.dta", replace

