/*******************************************************************************
RASKIN - COMBINE FORM AND SURVEY DATA FOR BIDDERS
1Data/dofiles/prep/bidders_form_survey_crosswalk.do

SUMMARY: 
	Combines bidding proposal (form) data with endline distributor survey data
	for bidding villages. 
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* GET DATA, PREP VARIABLES *****************************************************

** Form Data *******************************************************************
u "1Data/codeddata/competition/bidders", clear
merge m:1 commid using "1Data/codeddata/competition/biddingrejection"
	assert reject_bidding==1 if _m==2
	drop if reject_bidding==1 | reject_nobids==1
	drop _m
drop if column == .
isid commid column

**** Keep only variables that we want
keep commid column multiplebidders n_bids n_bidders winner old_dist price_dist markup_dist vehicle_dist ///
	deliver_village deliver_subvillage deliver_household pay_before pay_during pay_after  dist_credit ///
	own_village_dist old_dist trader_dist

**** Rename form variables
foreach var of varlist winner-trader_dist {
	rename `var' `var'_form
	}

//create and save temp file
tempfile form
sa `form'

** Crosswalk Data **************************************************************

u "1Data/originaldata/4_CE/crosswalk_f8a_distributor_resp", clear
rename d00_col column
drop if column == .
**** Want to merge with form data --> need commid column to identify data
bys commid column: gen N_id = _N
levelsof pr_id1 if N_id > 1, sep(,) local(multiple_obs)

**** Want to see which (if any) of these multiple_obs are actually in distributor data
preserve
	u "1Data/codeddata/competition/distributors", clear
	levelsof pr_id1 if inlist(pr_id1, `multiple_obs'), sep(,) local(in_dist)
restore

keep if N_id == 1 | inlist(pr_id1, `in_dist') //single observation and/or in distributor data
isid commid column
keep commid pr_ea pr_id1 pr_id2 column

//create and save temp file
tempfile crosswalk
sa `crosswalk'

** Merge Form and Crosswalk Data ***********************************************
merge 1:1 commid column using `form'
gen form = _m==2
la var form "Observation in form data, but not crosswalk"
gen cw = _m==1
la var cw "Observation in crosswalk data, but not form data"
drop _m

**** Missing Identifiers
replace pr_id2 = "0" if pr_id2==""
replace pr_ea = commid if pr_ea == ""
drop if pr_id1=="" //need to match to endline distributor survey data

**** Make sure data is uniquely identified
//isid pr_ea pr_id1 pr_id2 //False
bys pr_ea pr_id1 pr_id2: gen N_id = _N
bys pr_ea pr_id1 pr_id2: gen n_id = _n
levelsof pr_id1 if N_id > 1, sep(,) local(multiple_obs)
duplicates tag commid pr_ea pr_id1 pr_id2 multiplebidders-n_bids, gen(dup) 
	//duplicates on everything except column
assert dup == 1 if inlist(pr_id1, `multiple_obs') 
	//data not uniquely IDed because of duplicates
drop if inlist(pr_id1, `multiple_obs') & n_id>1 
	//drop latter duplicate observation
drop n_id N_id
isid pr_ea pr_id1 pr_id2

//create and save temp file
tempfile formcross
sa `formcross'

** Distributor Survey Data *****************************************************

u "1Data/codeddata/competition/distributors", clear
isid pr_ea pr_id1 pr_id2
keep if tr_dist == 1 //matching with bidder data --> only want bidding treatment
drop tr_moni*
bys pr_ea pr_id2: gen n_interviewed = _N
la var n_interviewed "# distributors surveyed at endline in village"

** Merge! **********************************************************************

merge 1:1 pr_ea pr_id1 pr_id2 using `formcross'

**** Deal with data sources
gen not_survey = _m == 2
la var not_survey "Observation in form/crosswalk, but not endline survey"
la var not_survey "Observation in form/crosswalk, but not endline survey"
gen only_survey = _m == 1
la var only_survey "Observation in endline survey, but not in form"
egen only_form = rowmax(not_survey form)
la var only_form "Observation in form, but not in endline survey"
assert only_form + only_survey <= 1
gen matched = _m==3
la var matched "Observation sucessfully matched between form and survey"
drop form cw not_survey 
drop _m

**** Deal with rejected villages
merge m:1 hhea using "1Data/codeddata/competition/biddingrejection"
sort pr_ea
foreach v of varlist reject* blocked_by* return_sq never_dist *some* old_win {
	bys pr_ea: egen `v'1 = min(`v')
	replace `v' = `v'1 if `v' == .
	drop `v'1
}
drop _m

//order variables
order commid column pr_ea pr_id1 pr_id2 hhea only_survey only_form matched winner_form multiplebidders 

** SAVE FINAL DATA SET. ********************************************************

saveold "1Data/codeddata/competition/bid_dist_all.dta", replace
