/*******************************************************************************
COMPETITION - CREATE PROCESS VARIABLES FOR BIDDING MEETINGS
1Data/dofiles/prep/bidding_meeting_prep.do

SUMMARY: 
	Descriptive info on bidding meetings for bidding villages (meetings held, 
	composition of bidding commitess, meeting quality, etc)
*******************************************************************************/

* SETUP AND MACROS *************************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* CREATE/COMPILE VARIABLES *****************************************************

** Compliance with treatment ***************************************************

//load in data
u "1Data/codeddata/competition/biddingrejection.dta", clear

//create and save tempfile
tempfile mtg_compliance
sa `mtg_compliance'

** Women in Selection Committee (For Women Quota) ******************************

//load in data
use "1Data/originaldata/4_CE/f6a_b.dta", clear

assert b03 == 1 | b03 == 3
recode b03 (1=0) (3=1) 							//1=female, 0 = male

//generate variable for proportion of women on committee
bys commid: gen N = _N 							//number on committee per village
collapse b03 N, by(commid)
rename b03 female_selection 					//proportion of women on committee
la var female_selection "Proportion of Women on Selection Committee"

//generate variable for total number of women on committee
gen female_selection_n = female_selection*N 	//number of women on committee
la var female_selection_n "Number of Women on Selection Committee"

//create village id variable
gen hhea = commid
drop N

//create and save temp file
tempfile selection
sa `selection' 

** Meeting length *************************************************************

//load in data
u "1Data/originaldata/4_CE/f8a_a1.dta", clear

//generate total length of meeting in hrs
rename commid hhea
recode *min *hr (99=.)
replace a05_min = a05_min/60
replace a06_min = a06_min/60
gen start 		= a05_hr + a05_min
gen end 		= a06_hr + a06_min
gen mtg_time 	= end - start
recode mtg_time (0=.)
la var mtg_time "Length of Meeting (Hrs)"

//keep village id and meeting time
keep hhea mtg_time

//drop if meeting time is missing
drop if mi(mtg_time)

//create and save temp file
tempfile mtg_length
sa `mtg_length'
	
** Composition of meetings *****************************************************

//load in data
u "1Data/originaldata/4_CE/f8a_b.dta", clear

//rename village id variable
rename commid hhea

//Total # Attendees
gen mtg_total = b03_9
la var mtg_total "Attendees"

//# Women Attendees
gen mtg_female = b03_9a
la var mtg_female "Female Attendees" 

//#Male Attendees
gen mtg_male = b03_9b
la var mtg_male "Male Attendees" 

//#Raskin Recipient Attendees
gen mtg_raskin = b03_7
la var mtg_raskin "Raskin Beneficiaries" 

//#Formal Elite
egen mtg_official = rowtotal(b03_1 b03_2 b03_3 b03_4)
replace mtg_official = . if mtg_official > mtg_total 
la var mtg_official "Formal Village Officials (village/hamlet officials)"

//#Non-Raskin Recipient Attendees
gen mtg_nonraskin = b03_9 - b03_7 //because other categories may be double counted
replace mtg_nonraskin = . if mtg_nonraskin < 0
la var mtg_nonraskin "Non Raskin Recipients" 

//keep relevant variables
keep hhea mtg_total mtg_female mtg_male mtg_raskin mtg_nonraskin mtg_official

//create and save tempfile
tempfile mtg_female
sa `mtg_female'

** Quality of Meetings *********************************************************

//Presentation Quality/Time                    *********************************

//load in data
u "1Data/originaldata/4_CE/f8a_d.dta", clear

//average presentation quality and duration
recode d14 (9 = .)
recode d15 (999 = .) (0 = .)
collapse (mean) mtg_quality=d14 mtg_time=d15, by(commid)
la var mtg_quality "Average presentation quality at meeting (1-4 Scale)"
la var mtg_time "Average presentation duration at meeting (in minutes)"
rename commid hhea

//create and save temp file with relevant variables
keep hhea mtg_quality mtg_time
tempfile mtg_qt
sa `mtg_qt'

//Comments/Participation                       *********************************

//load in data
u "1Data/originaldata/4_CE/f8a_e.dta", clear

//rename villag id
rename commid hhea

//questions/comments at meeting
assert e02 == . if e01 !=1
recode e01 (9 = .) (3 = 0)
rename e01 mtg_questions
la var mtg_questions "Did anyone at meeting leave question, comment, etc?"
la def no_yes 0 "No" 1 "Yes"
la val mtg_questions no_yes
rename e02 mtg_questions_n
la var mtg_questions_n "How people left question, comment, etc at mtg?"

//create and save temp file with relevant variables
keep hhea mtg_questions mtg_questions_n
tempfile mtg_q
sa `mtg_q'

//Proportion of people leaving comments/participating
u "1Data/originaldata/4_CE/f8a_v1.dta", clear
rename commid hhea
gen mtg_discuss_none			= v05 == 1
la var mtg_discuss_none "No discussion at meeting"
gen mtg_discuss_slight 			= v05 == 2
la var mtg_discuss_slight "<10% of people talk"
gen mtg_discuss_majority 		= v05 == 3
la var mtg_discuss_majority "10-50% of people talk"
gen mtg_discuss_vastmajority	= v05 == 4
la var mtg_discuss_vastmajority ">50% of people talk"

//replace with missing if relevant
foreach var of varlist mtg_discuss_none mtg_discuss_slight mtg_discuss_majority mtg_discuss_vastmajority {
	replace `var' = . if v05==9
}


//create and save temp file with relevant variables
keep hhea mtg_*
tempfile mtg_q_v05
sa `mtg_q_v05'

* MERGE EVERYTHING      ********************************************************

use `mtg_compliance', clear
merge 1:1 hhea using `mtg_length'
assert _m != 2
drop _m

merge 1:1 hhea using `mtg_female'
assert _m != 2
drop _m

merge 1:1 hhea using `selection'
assert _m != 2
drop _m

merge 1:1 hhea using `mtg_qt'
assert _m != 2
drop _m

merge 1:1 hhea using `mtg_q'
assert _m != 2
drop _m

merge 1:1 hhea using `mtg_q_v05'
assert _m != 2
drop _m

merge 1:1 hhea using "1Data/codeddata/competition/treatments.dta", ///
	keepusing(TR2_2013-TR2c tr_dist)
keep if tr_dist==1
assert _m==3
drop _m

foreach var of varlist mtg_total- mtg_discuss_vastmajority {
	replace `var' = . if reject_bidding == 1
}

** SAVE FINAL DATA SET. ********************************************************

saveold "1Data/codeddata/competition/bidding_meeting.dta", replace
