/*******************************************************************************
RASKIN - COMBINE ENDLINE, MIDLINE, CS1 DATASETS - PREP DATA
1Data/dofiles/prep/cards_combine_all.do

SUMMARY: 
	Combine the CS1, Midline, and Endline waves of the survey.
	Prepare other variables for competition-treatment analysis.
OUTLINE:
	The surveys called "CS1" and "Midline" for the Cards project treatment function as
	a baseline for the Competition treatment.  "Endline" survey gives us post-
	Competition-treatment outcomes.  However, because in many cases we want to
	control for outcomes at baseline, we often need variables from CS1 and
	Midline.  This file produces a big dataset which includes the
	prepared variables from all three waves of the survey.
NOTES:
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** COMBINE CS1, MIDLINE, ENDLINE ***********************************************
** DATA PREVIOUSLY PREPARED FOR CARDS ANALYSIS *********************************

** PREP CS1/MIDLINE     ********************************************************

u "1Data/codeddata/cards_paper/paper/combined_pooled.dta", clear

//confirm that exactly one of surveys (via hhid) in missing
assert mi(hhid_cs1) + mi(hhid_mid) == 1

//generate hhid depending on which survey
gen hhid = hhid_cs1 + "A" if !mi(hhid_cs1)
replace hhid = hhid_mid + "B" if !mi(hhid_mid)

//again confirm that hhid is not missing
assert hhid != ""
cap drop _m

/* Since most variables have the same names in each wave of the survey, we add
	a prefix _f ("f" for follow-up) at the end of these variable names to distinguish
	them from the same variables in the endline survey */
local subtractme hhid
ds *
local allvars `r(varlist)'
local vars : list allvars - subtractme

foreach var in `vars'{
	ren `var' `var'_f // 
	la var `var'_f "`: var l `var'_f' (follow-up)"
}


** GENERATE DISTRIBUTIONAL DUMMIES
count
local nobs = `r(N)'
forv wave = 1/2{
	local name : word `wave' of cs1 mid
	preserve
		keep if wave == `wave'
		foreach v in subsidy_rcvd price_hh amtraskin{
			sum `v'_f, d
			gen `v'_b25_f = `v'_f < `r(p25)' if `v'_f != .
			gen `v'_b50_f = `v'_f < `r(p50)' if `v'_f != .
			gen `v'_a25_f = `v'_f > `r(p25)' if `v'_f != .
		}
		tempfile `name'
		save ``name''
	restore
}
clear
append using `cs1' `mid'

//create and save tempfile
tempfile followup
sa `followup'

** MERGE WITH ENDLINE DATA.      ***********************************************
use "1Data/codeddata/cards_paper/endline/combined_end.dta", clear
merge 1:1 hhid using `followup'
assert  _m != 1
keep if _m == 3
drop _merge

** SAVE ************************************************************************
saveold "1Data/codeddata/competition/cards_combined_all.dta", replace


exit


