/*******************************************************************************
RASKIN PREP - COMPETITION
1Data/dofiles/prep/competition_prep.do

SUMMARY: 
	Combine the variables created by other prep files, and create the variables
	necessary for the competition analysis.
	This file creates the final dataset which will be used in the competition
	regressions.
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** COMBINE VARIOUS PIECES ******************************************************

** Market Prices -- For Subsidy Var, later
use "1Data/codeddata/cards_paper/marketprices.dta", clear
renvars marketprice kab_marketprice / marketprice_cs1 kab_marketprice_cs1
merge 1:1 kab_id using "1Data/codeddata/cards_paper/midline/marketprices_mid.dta"
assert _m==3
drop _m
renvars marketprice kab_marketprice / marketprice_mid kab_marketprice_mid
merge 1:1 kab_id using "1Data/codeddata/cards_paper/endline/marketprices_end.dta"
assert _m==3
drop _m
renvars marketprice kab_marketprice / marketprice_end kab_marketprice_end
drop marketprice_*

//create and save temp file
tempfile marketprices
sa `marketprices'

use "1Data/codeddata/competition/cards_combined_all.dta", clear

** Household Variables
foreach data in allwave_vars endline_vars{
	merge 1:1 hhid using "1Data/codeddata/competition/`data'.dta"
	assert _m == 3
	drop _m
}

** Variables from the CS1/Midline pooled dataset
foreach data in cs1midline_vars consumption_cs1mid{
	merge 1:1 hhid using "1Data/codeddata/competition/`data'.dta"
	assert _m != 1
	keep if _m == 3
	drop _m
}

** Village-level variables 
foreach data in village_prices good_strata treatments{
	merge m:1 hhea using "1Data/codeddata/competition/`data'.dta"
	assert _m == 3
	drop _m
}

** Merge in Market Prices
	merge m:1 kab_id using `marketprices'
	assert _m == 3
	drop _m
	
** CREATE MORE VARIABLES *******************************************************

** MARKUP
gen markup_hh		= price_hh - 1600
replace markup_hh 	= 0 if markup_hh < 0
la var markup_hh 	"Raskin Price Markup"
gen markup_hh_f 	= price_hh_f - 1600
replace markup_hh_f = 0 if markup_hh_f < 0
la var markup_hh_f 	"Raskin Price Markup at Baseline"

bys hhea: egen markup_hhea 	 = mean(markup_hh)
cap drop markup_hhea_f
bys hhea: egen markup_hhea_f = mean(markup_hh_f)

** Alternative Subsidy Definition
/* Calculate subsidy using the average market price in the district, 
	rather than the market price in their village. */
gen kab_market			= kab_marketprice_end
gen kab_market_f 		= kab_marketprice_cs1 if cs1==1
replace kab_market_f 	= kab_marketprice_mid if mid==1
assert kab_market_f 	!= .
	
bys hhea	: egen price_hhea	= mean(price_hh)
gen raskprice	 	= price_hh 
replace raskprice 	= price_hhea if mi(raskprice)
gen raskprice_f		= price_hh_f 
replace raskprice_f = price_hhea_f if mi(raskprice_f)

gen subsidy_rcvd_kab 	 	= (kab_market   - raskprice  )*amtraskin
replace subsidy_rcvd_kab  	= 0 if amtraskin == 0 | subsidy_rcvd_kab < 0
gen subsidy_rcvd_kab_f 	 	= (kab_market_f - raskprice_f)*amtraskin_f
replace subsidy_rcvd_kab_f 	= 0 if amtraskin_f == 0 | subsidy_rcvd_kab_f < 0

la var subsidy_rcvd_kab   "Subsidy Received (Using district-average market prices)"
la var subsidy_rcvd_kab_f "Baseline Subsidy Received (Using district-average market prices)"

drop kab_marketprice* kab_market* price_hhea raskprice*

** ELIGIBLE TO RECEIVE RASKIN
gen eligible = (t1==1 | t2==1)	
la var eligible "HH eligible to receive Raskin"
gen ineligible = (eligible==0)
la var eligible "HH not eligible to receive Raskin"

** ALTERNATIVE ELIGIBILITY DEFINITION
preserve
	//Looking at randomly selected households
	keep if sample3cs1==1 | samplec_f==1
	qui count
	local n_total = `r(N)'
	//Of randomly selected households, how many were actually eligible?
	qui count if t1==1|t2==1
	local n_eligible = `r(N)'
	//Proportion Eligible
	local p_eligible = 100*`n_eligible'/`n_total'
	display `p_eligible'
	/*Finding log consumption cutoff such that eligibility proportions equivalent 
	between definitions for randomly selected sample*/
	quietly summ logconsumption_f
	local n_logc = `r(N)'
	pctile ptile_logc = logconsumption_f, genp(p_logc) nq(`n_logc')
	gen treated_alt = p_logc <= `p_eligible'
	quietly summ treated_alt
	local p_treated_alt = `r(mean)'*100
	assert abs(`p_eligible' - `p_treated_alt')<.1
	bys treated_alt: egen treated_alt_cutoff = max(logconsumption_f)
	qui sum treated_alt_cutoff
	local treated_alt_cutoff = `r(min)'
	display `treated_alt_cutoff' 
restore
//Using log consumption cutoff to define treated_alt for whole sample
gen treated_alt = logconsumption_f <= `treated_alt_cutoff'
la var treated_alt "Eligible based on baseline log consumption"

** EXCLUSION ERROR AND MISTARGETING (BASELINE aka FOLLOW-UP)

gen excl_error_f = bought_last2m_f == 0 if inlist(type,1,2)
la var excl_error_f "Exclusion error (Did not purchase Raskin, if eligible)"
gen incl_error_f = bought_last2m_f == 1 if type == 3
la var incl_error_f "Inclusion error (Did purchase Raskin, if ineligible)"
gen mistargeting_f = excl_error_f == 1 | incl_error_f == 1
la var mistargeting_f "Mistargeting (eligible and didn't purchase, or ineligible and did purchase)"

** KNOWLEDGE ABOUT BIDDING PROCESS
gen know_process = ((b07b == 1 & TR2_2013 == 2) ///
				 | (b07b == 3 & TR2_2013 != 2)) if !inlist(b07b,.,8)
la var know_process "HH correctly identifies competition treatment status"

** "BASELINE" CONTROL VARIABLE (either CS1 or Midline) FOR EACH VARIABLE.
// we already have it for bought, amt, price, subsidy
// "_f" for "follow-up survey"
ds, not(type string)
foreach v in `r(varlist)'{
	cap conf v `v'_cs1
	if !_rc{
		gen `v'_f = `v'_cs1
		replace `v'_f = `v'_mid if mi(`v'_f)
	}
}

** GENERATE DISTRIBUTIONAL DUMMIES
foreach v in subsidy_rcvd price_hh amtraskin{
	sum `v', d
	gen `v'_b25 = `v' < `r(p25)' if `v' != .
		gen `v'_b25_mis = mi(`v'_b25)
	gen `v'_b50 = `v' < `r(p50)' if `v' != .
		gen `v'_b50_mis = mi(`v'_b50)
	gen `v'_a25 = `v' > `r(p25)' if `v' != .
		gen `v'_a25_mis = mi(`v'_a25)
}

** NOW MAKE A VERSION WHICH IS FILLED IN WITH THE AVERAGE WHEN BASELINE MISSING
** ALSO MAKE DUMMIES FOR WHETHER THE BASELINE IS MISSING
ds, not(type string)
foreach v in `r(varlist)'{
	cap conf v `v'_f
	if !_rc{
		cap conf v `v'_f_mis
		if _rc gen `v'_f_mis = mi(`v'_f)
		cap conf v `v'_f2
		if _rc{
			sum `v'_f
			if `r(N)' == 0 continue // skip variables with no observations.
			gen `v'_f2 = `v'_f
			replace `v'_f2 = `r(mean)' if mi(`v'_f)
			assert `v'_f2 != .
		}
	}
}

** AVERAGE SUBSIDY FOR ELIGIBLE HOUSEHOLDS IN EACH VILLAGE
bys hhea : egen subavg = mean(subsidy_rcvd) if treated == 1
bys hhea : egen subavg_hhea = max(subavg)

** TRUNCATE VALUES ABOVE THE 99TH PCTILE FOR THESE VARS WITH ABSURD VALUES
foreach v in distance time{
	foreach _f in "" _f _f2{
		sum `v'`_f', d
		replace `v'`_f' = . if `v'`_f' > `r(p99)' | `v'`_f' < `r(p1)'
	}
}

** BASELINE AVERAGE KECEMATAN PRICE IN CARDS CONTROL GROUP VILLAGES ONLY
preserve
	keep if treatment==0
	collapse kec_price_f = price_hh_f, by(kecagroup)
	sum kec_price_f, d
	gen hi_kec_price_f = kec_price_f > `r(p50)'
	local mean_price = `r(mean)'
	
	centile kec_price_f, centile(33 66)
	gen lo_kec_f = kec_price_f < `r(c_1)' if !mi(kec_price_f)
	gen med_kec_f = kec_price_f > `r(c_1)' & kec_price_f < `r(c_2)' ///
	  if !mi(kec_price_f)
	gen hi_kec_f = kec_price_f > `r(c_2)' if !mi(kec_price_f)
	la var lo_kec_f "Dummy: Baseline kec price < 33rd pctile"
	la var med_kec_f "Dummy: 33rd pctile < Baseline kec price < 66th pctile"
	la var hi_kec_f "Baseline kec price > 66th pctile"
	
	//create and save temp file
	tempfile kec_price_f
	sa `kec_price_f'
restore

merge m:1 kecagroup using `kec_price_f'
gen kec_price_f_mis = _m==1
gen kec_price_f2 = kec_price_f
replace kec_price_f2 = `mean_price' if kec_price_f_mis == 1
drop _m
la var kec_price_f "baseline kecamatan price in control villages"
la var hi_kec_price_f "Baseline Kecamatan Price > Median"
la var kec_price_f2 "Baseline kecamatan price (filled in)"
la var kec_price_f_mis "No control villages in kecamatan"
		
** GENERATE INTERACTIONS
** Continuous interactions
gen dist_price = tr_dist * price_hhea_f
gen moni_price = tr_moni * price_hhea_f
gen minbids_price = tr_minbids * price_hhea_f
gen nomin_price = tr_nomin * price_hhea_f
la var dist_price "Bidding * Baseline price (village avg)"
la var moni_price "Info * Baseline price (village avg)"
la var minbids_price "Min Bids * Baseline price (village avg)"
la var nomin_price "Open Bids * Baseline price (village avg)"

** Continuous interactions - Markup
gen dist_markup = tr_dist * markup_hhea_f
gen moni_markup = tr_moni * markup_hhea_f
gen minbids_markup = tr_minbids * markup_hhea_f
gen nomin_markup = tr_nomin * markup_hhea_f
la var dist_markup "Bidding * Baseline markup (village avg)"
la var moni_markup "Info * Baseline markup (village avg)"
la var minbids_markup "Min Bids * Baseline markup (village avg)"
la var nomin_markup "Open Bids * Baseline markup (village avg)"

** Dummy interactions
gen dist_hiprice = tr_dist * hiprice_hhea_f
gen moni_hiprice = tr_moni * hiprice_hhea_f
la var dist_hiprice "Bidding treatment * (Avg baseline price in village > avg baseline price in median village)"
la var moni_hiprice "Info treatment * (Avg baseline price in village > avg baseline price in median village)"

** Dummy interactions - Min bid & low-medium-high prices
forv i = 1/3 {
	local x : word `i' of hi lo med 
	local n : word `i' of "> avg baseline price in 66th pctile" ///
		"< avg baseline price in 33rd pctile" "btwn avg baseline in 33rd & 66th pctile"
	
	foreach var in dist minbids nomin moni {
		gen `var'_`x' = tr_`var' * `x'_f
		la var `var'_`x' "`var' * (Avg baseline price in village `n'"
	}
}

** Interactions with baseline kecamatan price
forv i=1/2 {
	local tr2 : word `i' of "dist" "moni"
	local tr2_lab :  word `i' of "Bidding treatment" "Information treatment"
	gen `tr2'Xkec_price_f = tr_`tr2' * kec_price_f
	la var `tr2'Xkec_price_f "`tr2_lab' * baseline kecamatan price"
	gen `tr2'Xhi_kec_price_f = tr_`tr2' * hi_kec_price_f
	la var `tr2'Xhi_kec_price_f "`tr2_lab' * kecamatan price > median"
	gen `tr2'Xkec_price_f2 = tr_`tr2' * kec_price_f2
	la var `tr2'Xkec_price_f2 "`tr2_lab' * baseline kecamatan price (filled in)"
	
	foreach var of varlist hi_kec_f med_kec_f lo_kec_f {
		gen `tr2'X`var' = tr_`tr2' * `var'
		la var `tr2'X`var' "`tr2_lab' * `var'"
	}
}	

** DEFINE VALUE LABELS
la def ag4dis1 4 "Strongly Agree" 3 "Agree" 2 "Disagree" 1 "Strongly disagree"
la def ag4dis1_dummies 1 "Agree or strongly agree" 0 "Disagree or strongly disagree"
la def hi4lo1 4 "Very high" 3 "High" 2 "Low" 1 "No"
la def hi4lo1_dummies 1 "Very high or high" 0 "Low or no"

foreach var in satis_prog trust_bidcom satis_proc place_easy amt_rcvd ///
  satis_qual satis_price transparent{
	label values `var'_dum* ag4dis1_dummies
	label values `var'_cat* ag4dis1
}

foreach var in crpt_central crpt_coord{
	label values `var'_dum* hi4lo1_dummies
	label values `var'_cat* hi4lo1
}

** SAVE ************************************************************************

saveold "1Data/codeddata/competition/endmidcs1.dta", replace


exit


