/*******************************************************************************
CONSUMPTION, FROM CS1 AND MIDLINE FOLLOW-UP SURVEYS.
1Data/dofiles/prep/consumption_cs1mid.do

SUMMARY:
	Household consumption data at consumption baseline (CS1/Midline).
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

*****************************
**Consumption (RP1 section)**
*****************************

forv i = 1/2{
	local path : word `i' of 1_CS1/NewUpdate 2_Midline
	local suf : word `i' of cs1 mid

	** Household consumption.       ********************************************

	//load in and merge data
	use "1Data/originaldata/`path'/hh_ks1.dta",clear
	merge 1:1 hhid using "1Data/originaldata/`path'/hh_ks2.dta"
	
	//confirm that all match
	assert _merge==3
	drop _merge
	
	/* recode missing values, don't know and not applicable to missing */
	foreach var of varlist ks01_1a - ks01_14b{
		gen missing_`var' = (`var' >= 999990)
		replace `var'=. if `var' >= 999990
	}
	foreach var of varlist  ks03_15a - ks04_20{
		gen missing_`var' = (`var' >= 99999990)
		replace `var'=. if `var' >= 99999990
	}	
	egen missing = rsum( missing_ks01_1a- missing_ks04_20 )

	***Food Consumption***
	egen wfood = rsum(ks01_1a-ks01_14b)
	la var wfood "Consumption on food last week"
	gen mfood = wfood * 30 / 7 //convert to monthly consumption
	la var mfood "Monthly food consumtion"
		
	***Nonfood Consumption***
	egen m = rowtotal(ks03_15a ks03_15c ks03_15d ks03_16a ks03_16d ks03_16e)
	egen y = rowtotal(ks04_15b ks04_16b ks04_16c ks04_17 ks04_18 ks04_19a ///
	  ks04_19b ks04_19c ks04_19d ks04_20)
	gen mnonfood = m + (y / 12)
	la var mnonfood "Monthly nonfood consumption"
	
	***Food and Nonfood Consumption***
	gen hhconsumption_f = (mfood + mnonfood)
	replace hhconsumption_f = . if missing >= 4
	la var hhconsumption_f "Monthly household consumption in Rp (follow-up)"
	
	*keep hhid, generate hhea
	keep hhid hhconsumption_f
	gen hhea = substr(hhid,1,3)

	*create and save tempfile
	tempfile hhconsumption
	sa `hhconsumption'	
		
	** Household size **********************************************************

	if "`path'" == "1_CS1/NewUpdate" local a
	else if "`path'" == "2_Midline" local a 1
	use "1Data/originaldata/`path'/hh_ar`a'.dta", clear
	
	//generate household size and collapse by household
	bys hhid: egen hhsize_f = count(ar00)
	keep hhid hhsize_f
	collapse hhsize_f, by(hhid)
	
	//merge with consumption data
	merge 1:1 hhid using `hhconsumption'
	
	//confirm all merged
	assert _m == 3
	drop _m
	
	//generate consumption per hh. member variables
	gen consumption_f = (hhconsumption_f / hhsize_f)
	gen logconsumption_f = log(consumption_f)
	la var hhsize_f "Household size (follow-up)"
	la var consumption_f "Per capita consumption in Rp (follow-up)"
	la var logconsumption_f "Log per capita consumption (follow-up)"

	//generate consumption variable relative to village
	bys hhea: egen rank_pcexp_f = rank(consumption)
	la var rank_pcexp "Rank per capita consumption within village (follow-up)"
	//create variable for number of households in village
	bys hhea: gen nhhrank_pcexp_f = _N
	la var nhhrank_pcexp_f "number of household in village (follow-up)"
	//generate rank variable
	gen rankconsumption_f = rank_pcexp_f / nhhrank_pcexp_f
	la var rankconsumption_f "Rank per capita consumption within village in percentiles (follow-up)"

	if "`path'" == "1_CS1/NewUpdate" local X A
	else if "`path'" == "2_Midline" local X B
	replace hhid = hhid + "`X'"
	
	//create and save tempfile
	tempfile consumption_`suf'
	sa `consumption_`suf''
}

** COMBINE *********************************************************************
u `consumption_cs1', clear
append using `consumption_mid'

** SAVE FINAL DATA SET. ********************************************************
saveold "1Data/codeddata/competition/consumption_cs1mid.dta", replace




