/*******************************************************************************
RASKIN PREP - ENDLINE
1Data/dofiles/prep/endline_vars.do

SUMMARY: 
	Prepare variables which appear only in Endline survey (18 months after
	cards treatment) for competition paper analysis.
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** PREP VARIABLES WHICH EXIST ONLY IN ENDLINE **********************************
********************************************************************************

** KNOWLEDGE *******************************************************************

//load in data
u "1Data/originaldata/3_Endline/hh_b1", clear

gen know_dist = b07gx == 1 if !mi(b07gx)
	* "Not Applicable" are zeros.
la var know_dist "HH correctly identifies name and position of village Raskin distribution coordinator"

gen say_bidding = b07b == 1 if !inlist(b07b,.,8)
la var say_bidding "HH reports there was a bidding process"

//create and save tempfile with relevant variables
keep hhid b07b know_dist say_bidding
tempfile b1
sa `b1'

** SOCIALIZATION ***************************************************************

//load in data
u "1Data/originaldata/3_Endline/hh_sr", clear

gen say_committee = sr10a == 1 if !inlist(sr10a,.,8)
la var say_committee "HH reports there is a bidding or monitoring committee"

//create and save tempfile with relevant variables
keep hhid say_committee
tempfile sr
sa `sr'

** SATISFACTION ****************************************************************

//load in data
u "1Data/originaldata/3_Endline/hh_f", clear

//create variables related to Raskin quality, price, and transparency (binary, scale 1-4, scale 0-1)
forv xx = 1/3{
	local newvar : word `xx' of satis_qual satis_price transparent
	local numvar : word `xx' of f09a f09b f09c
	gen `newvar'_dum = inlist(`numvar',1,2) if !inlist(`numvar',6,.)
	gen `newvar'_cat = `numvar'
	recode `newvar'_cat (1 = 4) (2 = 3) (3 = 2) (4 = 1) (6 = .)
	gen `newvar'_cat01 = (`newvar'_cat - 1)/(4 - 1)
}
forv yy = 1/3{
	local typ	: word `yy' of dum cat cat01
	local desc	: word `yy' of "binary" "4 categories" "0-1 scale" 
	la var satis_qual_`typ' "Satisfied with Raskin quality (`desc')"
	la var satis_price_`typ' "Satisfied with Raskin price (`desc')"
	la var transparent_`typ' "Selection process was transparent (`desc')"
}

//create variables related to complaints/protests
gen complaint_hh = f11_a == 1 if !mi(f11_a)
la var complaint_hh "Member of HH participated in complaint"
gen protest_hh = f11_b == 1 if !mi(f11_b)
la var complaint_hh "Member of HH participated in protest"

//create and save tempfile with relevant variables
keep hhid satis* transparent*
tempfile f
sa `f'

** LIKELIHOOD OF CORRUPTION	****************************************************

//load in data
u "1Data/originaldata/3_Endline/hh_kp", clear

//reshape data according to type
reshape wide kp02, i(hhid) j(kp1type) string

//create variables on corruption for both central government and village distributor
forv xx = 1/2{
	local newvar : word `xx' of crpt_central crpt_coord
	local numvar : word `xx' of kp02A kp02H
	gen `newvar'_dum = `numvar' > 2 if `numvar' < 6
	gen `newvar'_cat = `numvar'
	recode `newvar'_cat (6 = .) (7 = .) (8 = .)
}
forv yy = 1/2{
	local typ	: word `yy' of dum cat
	local desc	: word `yy' of "binary" "4 categories"
	la var crpt_central_`typ' "Central govt is corrupt(`desc')"
	la var crpt_coord_`typ' "Village raskin distribution coordinator is corrupt (`desc')"
}

//measure difference in corruption
gen crpt_diff = crpt_coord_cat - crpt_central_cat
la var crpt_diff "Corruption of coordinator - corruption of central govt"

//create and save tempfile with relevant variables
keep hhid crpt*
tempfile kp
sa `kp'

** CREDIT FROM RASKIN DISTRIBUTOR *********************************************

//load in data
u "1Data/originaldata/3_Endline/hh_b1.dta", clear

//id variable
gen hhea = substr(hhid,1,3)

//create variable for if HH borrowed money for Raskin
gen dist_borrow = regexm(b10b, "D")
replace dist_borrow = . if b10b==""
assert b10b=="" if b10==3
la var dist_borrow "HH borrowed money to purchase raskin from raskin coordinator"

//create variable for if someone in village borrowed money for Raskin
bys hhea : egen dist_borrow_vil = max(dist_borrow)
la var dist_borrow_vil "Someone in village borrowed money to purchase raskin from raskin coordinator"

** LOCATION OF RASKIN PURCHASE *************************************************
//Question the same as distributor survey, but no comments for "other" values
gen deliver_village_loc = inlist(b12, 1,2,3,6)
gen deliver_subvillage_loc = inlist(b12, 4,5,7)
gen deliver_household_loc = inlist(b12, 8) 

//Where was the location of [place above]?
gen deliver_village = inlist(b13, 2)
gen deliver_subvillage = inlist(b13, 3,4)
gen deliver_household = inlist(b13, 5) 

//replace if missing, label variables
foreach location in village subvillage household {
	replace deliver_`location'_loc = . if b12 ==95| b12 ==98
	la var deliver_`location'_loc "Raskin is distributed at `location' level (based on type of location)"
	
	replace deliver_`location' = . if b13 == 1| b13 ==98
	la var deliver_`location' "Raskin is distributed at `location' level (based on location)"
	}

//create and save temp file with relevant variables
keep hhid dist_borrow* deliver*
tempfile b1_2
sa `b1_2'

** COMBINE *********************************************************************

//merge all 5 temp files
u `b1', clear
foreach data in f kp sr b1_2{
	merge 1:1 hhid using ``data''
	assert _m == 3
	drop _m
}

** SAVE FINAL DATA SET. ********************************************************

saveold "1Data/codeddata/competition/endline_vars.dta", replace


