/*******************************************************************************
RANDOMIZATION CHECK PREP
1Data/dofiles/prep/rand_check_prep.do

SUMMARY: 
	Prepare the variables we use for the randomization check in competition
	analysis.
OUTLINE:
	Some of these variables come from Targeting II.
	Some appear in both CS1 and Midline community surveys, so we average them.
	Some are from the Midline Raskin distributor survey.
NOTES:
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** VARIABLES FROM TARGETING II *************************************************
u "1Data/codeddata/cards_paper/paper/T2_controls.dta", clear
la var pctagriculture "Percentage of agriculture households in RT (Targeting 2)"
la var distance_kec "distance to kecamatan (Targeting 2)"
keep hhea distance_kec pctagriculture
ren pctagriculture pctagri
ren (distance_kec pctagri) =_t2
tempfile t2
sa `t2'

** VARIABLES FROM COMMUNITY SURVEY *********************************************
forv i = 1/2{
	local path : 		word `i' of 1_CS1/NewUpdate 2_Midline
	local path_name : 	word `i' of 1_CS1 			2_Midline

	u "1Data/originaldata/`path'/k_id.dta", clear
	drop if id01 == .
	gen lognumberhh_f = log(id01)
	gen hhea = commid
	gen source = "`path_name'"
	keep hhea lognumberhh_f source
	tempfile id_`path_name'
	sa `id_`path_name''

	u "1Data/originaldata/`path'/k_kd.dta", clear
	/* 
		SD / paket A = 6 years
		SMP / paket B = 9 years
		SMA / paket C = 12 years
		D3 = 14 years
		S1 = 16 years
		S2 = 18 years
		this is if highest grade completed = tamat (graduated)
		if they haven't graduated then you we the previous cateogry + grade
	*/
	gen yredrthead_f = 0
	forv x = 1/6{
		local yrs_grad	: word `x' of 6 9 12 14 16 18
		local yrs_prev 	: word `x' of 0 6 9 12 14 16
		replace yredrthead_f = `yrs_grad' 		if kd02 == `x' ///
		  & (kd03 == 7 | kd03 >= `yrs_grad' - `yrs_prev')
		replace yredrthead_f = `yrs_prev' + kd03 	if kd02 == `x' ///
		  & !(kd03 == 7 | kd03 >= `yrs_grad' - `yrs_prev')
	}
	gen hhea = commid
	gen source = "`path_name'"
	keep hhea yredrthead_f source
	tempfile kd_`path_name'
	sa `kd_`path_name''
	
	** MERGE TOGETHER ALL VARIABLES FROM THIS WAVE
	u `id_`path_name'', clear
	foreach data in kd{
		merge 1:1 hhea using ``data'_`path_name''
		assert _m == 3
		drop _m
	}
	tempfile `path_name'
	sa ``path_name''
}

** AVERAGE CS1 AND MIDLINE together
u `1_CS1', clear
append using `2_Midline'
isid hhea source
collapse lognumberhh_f yredrthead_f, by(hhea)

//label variables
la var lognumberhh_f "Log village size (follow-up)"
la var yredrthead_f "Yrs of education of village head (follow-up)"

//create and save temp file
tempfile village
sa `village'

** DISTRIBUTOR VARIABLES *******************************************************

u "1Data/originaldata/2_Midline/k_rd1.dta", clear
gen village_off_f = regexm(rd05,"A|F")
la var village_off_f "Village government official is part of Raskin distribution committee (follow-up)"
gen sub_off_f = regexm(rd05,"B|C")
la var sub_off_f "Sub-village government official is part of Raskin distribution committee (follow-up)"
gen other = regexm(rd05,"V")
ren commid hhea

//keep relevant variables, create temp file, save temp file
keep hhea village_off_f sub_off_f
tempfile dist
sa `dist'

	
** MERGE ALL VARIABLES TOGETHER. ***********************************************

foreach data in t2 village{
	merge 1:1 hhea using ``data''
	assert _m == 3
	drop _m
}

** SAVE ************************************************************************

saveold "1Data/codeddata/competition/rand_check_village.dta", replace


exit


