/*******************************************************************************
COMPETITION - CREATE PROCESS VARIABLES FOR BIDDING MEETINGS
1Data/dofiles/prep/randomization_inference_5000.do

SUMMARY: 
	Run randomization inference for 1,000 iterations.
*******************************************************************************/

** SETUP AND MACROS ************************************************************

clear all

set more off
set matsize 1600
set maxvar 31000

cd "$RASKIN"

************************
** 1. SET ENVIRONMENT **
************************
clear
set sortseed 20130225
set seed 20130226
local iterations = 1000

* STRATEGY:
* 1. Stratification is on kabupaten, Targeting II treatment, Main cards treatment, and socialization treatment, in that order.
* 2. If strata have less than 6, enhanced-vs.-standard-socialization boundary is dissolved. If still have less than 6, All-v-B10 boundary dissolved.
* 3. Leftovers are sorted by kabupaten, TII, Main cards, and socialization, in that order, then put into groups of 6.
* 4. The groups of 6 are split into two groups of 3, and assigned 1/2/3. One village in each 6 assigned 3 is re-assigned 1 (monitoring-->control).
* 5. The last two leftovers are done manually on the same algorithm.
* 6. Subtreatment A is assigned in groups of 2 made from the groups-of-6 (which each have 2 distribution villages). The leftover is assigned randomly.
* 7. Subtreatment B is randomly assigned to the first two villages, then in inverse to those vis-a-vis Subtreatment A in the next two. The leftover is assigned randomly.
* 8. Subtreatment C is randomly assigned to the first four village, then in inverse to thsoe vis-a-vis Subtreatments A and B in the next four. The leftover is assigned randomly.

qui forv i = 1/`iterations' {
	noi di `i'
	
	**********************
	** 2. RANDOMIZATION **
	**********************

	* for main treatments

	**************************************************
	* TR2: COMMUNITY INVOLVEMENT: CONTROL (300), MONITORING (100), DISTRIBUTION (200)
	**************************************************

	* IMPORT ORIGINAL RANDOMIZATION
	use "1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta", clear
	
	
	* DROP DROPPED VILLAGES
	preserve
		insheet using "1Data/originaldata/0_Partner_Intervention/120914 List of villages to drop.csv", comma clear
		keep desaid
		tostring desaid, replace
		replace desaid = "0"+desaid if length(desaid)<3
		replace desaid = "0"+desaid if length(desaid)<3
		ren desaid desa_id2
		tempfile drop
		sa `drop'
	restore
	merge 1:1 desa_id2 using `drop'
	drop if _m==3
	drop _m

	* CREATE STRATA
	replace TR1c = 3 if TR1c==. // missing is control, but can't create groups that way
	egen strata = group(kab_id t2treatment TR1 TR1c)
	la var strata "Main strata, including dissolutions"

	* DISSOLVE SOCIALIZATION BOUNDARIES IF UNDER 6
	bys strata: g numvillages = _N
	g under = numvillages<6
	bys kab_id t2treatment TR1: egen temp = max(under)
	egen strata_temp = group(kab_id t2treatment TR1) if temp==1
	replace strata = strata_temp+300 if temp==1
	drop numvillages under temp strata_temp

	* DISSOLVE B10/ALL BOUNDARY IF UNDER 6
	bys strata: g numvillages = _N
	g under = numvillages<6
	bys kab_id t2treatment: egen temp = max(under)
	egen strata_temp = group(kab_id t2treatment) if temp==1
	replace strata = strata_temp+600 if temp==1
	drop numvillages under temp strata_temp

	gen good_strata = strata
	
	* RANDOMIZATION EXCEPT FOR REMAINING VILLAGES AFTER DIVIDING EACH STRATA INTO SIX GROUPS
	gen rand_id4=uniform()
	bys strata: egen rank_rand_id4=rank(rand_id4)
	bys strata: gen numvillages4=_N
	gen TR2_2013=mod(rank_rand_id4,6)+1 if rank_rand_id4 <= numvillages4 - mod(numvillages4, 6)

	* IDENTIFY LEFTOVERS
	gen leftovers4=(TR2_2013==.)

	* RANDOMLY SORT TARGETING II GROUPS
	bys t2treatment: gen rand4_2=uniform() if _n==1
	egen rand_rank_t2_temp4=rank(rand4_2)
	bys t2treatment: egen rand_rank_t2_4=mean(rand_rank_t2_temp4)

	* RANDOMLY SORT KABUPATEN
	bys kab_id: gen rand4_3=uniform() if _n==1
	egen rand_rank_kab_temp4=rank(rand4_3)
	bys kab_id: egen rand_rank_kab_4=mean(rand_rank_kab_temp4)

	* RANDOMLY SORT TR1 GROUPS
	bys TR1: gen rand4_4=uniform() if _n==1
	egen rand_rank_TR1_temp4=rank(rand4_4)
	bys TR1: egen rand_rank_TR1_4=mean(rand_rank_TR1_temp4)

	* RANDOMLY SORT SOCIALIZATION GROUPS
	bys TR1c: gen rand4_5=uniform() if _n==1
	egen rand_rank_TR1c_temp4=rank(rand4_5)
	bys TR1c: egen rand_rank_TR1c_4=mean(rand_rank_TR1c_temp4)

	* CREATE GROUPS OF 6 AND FIND LEFTOVERS AGAIN
	sort leftovers4 rand_rank_t2_4 rand_rank_kab_4 rand_rank_TR1_4 rand_rank_TR1c_4
	g tempgroup = floor((_n-1)/6) if leftovers4==1		// break order into groups of 6
	la var tempgroup "Groups of 6 leftovers"
	bys tempgroup: g tempnum = _N						// find leftovers again
	g leftovers4_2 = tempnum<6

	* ASSIGN TREATMENT IN GROUPS OF 6
	bys tempgroup: g temp = _n<=3 if leftovers4==1 & leftovers4_2!=1	
	egen tempgroup2 = group(tempgroup temp)			// groups of 3 within groups of 6; in same sort order
	g rand4_7 = uniform() if leftovers4==1	
	bys tempgroup2: egen rank_rand_leftovers4 = rank(rand4_7) if leftovers4_2!=1 		// assign randomly within groups for non-leftovers
	g rand4_7_2 = uniform() if rank_rand_leftovers4==3
	bys tempgroup: egen rank_rand_leftovers4_2 = rank(rand4_7_2)
	replace rank_rand_leftovers4 = 1 if rank_rand_leftovers4 ==3 & rank_rand_leftovers4_2 ==1
	drop temp tempgroup2

	* ASSIGN LAST TWO LEFTOVERS. SELECT FROM CTL,DIST,MON WITHOUT REPLACEMENT; IF DRAW MONITORING, DRAW 50-50 FOR MON V CTL
	* ORDER THEM-->1,2, THEN RANDOMLY CHOOSE ONE OF A,B,C TO LEAVE OUT.
	g rand4_8 = uniform() if leftovers4_2==1
	egen rank_rand4_8 = rank(rand4_8)
	g rand4_9 = uniform()
	sum rand4_9 if _n==1
	if `r(mean)'>(1/3) replace rank_rand4_8 = 3 if rank_rand4_8==2	// skip B
	if `r(mean)'>(2/3) replace rank_rand4_8 = 2 if rank_rand4_8==1	// skip A; fill in B
	g rand4_10 = uniform() if leftovers4_2==1
	replace rank_rand4_8 = 1 if rank_rand4_8==3 & rand4_10<.5		// replace monitoring to control with 50% probability

	* SAVE THESE NEW GROUP-OF-6 STRATA WE'VE CREATED
	g strata_alt = strata if leftovers4!=1
	replace strata_alt = tempgroup+1000 if leftovers4==1 & leftovers4_2!=1
	bys strata_alt: g temp = _N
	assert inlist(temp,6,12,18,24,30) if strata_alt!=.
	drop temp
	la var strata_alt "Groups of 6; either strata or leftover-groups"

	* REPLACE TREATMENT
	replace TR2_2013 = rank_rand_leftovers4 if TR2_2013==. & leftovers4_2!=1
	replace TR2_2013 = rank_rand4_8 if leftovers4_2==1

	* COMBINE THREE GROUPS TO CREATE CONTROL, AND TWO GROUPS FOR DISTRIBUTION
	replace TR2_2013=1 if inrange(TR2_2013,4,5)		// note this has already been done for leftovers
	replace TR2_2013=2 if TR2_2013==6

	* LABEL TREATMENT VARIABLE 	
	label var TR2_2013 "Community Treatment, Revised Assignment in 2013"
	label def TR2_2013 1 "Control" 2 "Distribution" 3 "Monitoring"
	label val TR2_2013 TR2_2013
	foreach rand of varlist rand4* {
		label var `rand' "Random value for randomization"
	}

	replace TR1c = . if TR1c==3

	**************************************************
	** SUB-TREATMENTS FOR DISTRIBUTION
	* A. WOMEN QUOTA / NO WOMEN QUOTA
	* B. MIN BIDS / NO MIN BIDS
	* C. ENHANCED SUPERVISION
	**************************************************

	* KEEP ONLY THE ONES WE NEED
	preserve
		keep if TR2_2013!=2	// monitoring and control villages
		tempfile monitorcontrol
		sa `monitorcontrol'
	restore
	drop if TR2_2013!=2

	* CREATE GROUPS OF 2
	g rand_extra = runiform()
	so strata_alt rand_extra
	g group_2 = floor((_n-1)/2)
	bys group_2: egen groupin2 = rank(rand_extra)
	bys group_2: g temp = _N
	count if temp!=2
	assert `r(N)'<=1
	drop temp
	tempfile group2
	sa `group2'

	* CREATE GROUP VARIABLES TO LOOP ON
	egen strat1 = group(t2treatment kab_id TR1 TR1c), missing
	egen strat2 = group(t2treatment kab_id TR1)
	egen strat3 = group(t2treatment kab_id)
	egen strat4 = group(t2treatment)

	* CREATE GROUPS OF 4
	bys group_2: keep if _n==1			// keep only 1 per group_2 to make it easier to handle. later restore using the tempfile.
	keep group_2 strat*
	forv x = 1/4 {						// loop over different pseudo strata
		so strat`x' group_2
		g rand`x'_4group = runiform()
		so strat`x' rand`x'_4group
		bys strat`x': g group_4 = floor((_n-1)/2) + 3*strat`x' + 1000*`x'		// pair the groups of 2 to groups of 4
		bys group_4: g temp = _N
		preserve
			keep if temp==2														// keep the real pairs
			drop temp
			qui count
			if `r(N)' != 0 {													// if there ARE real pairs
				bys group_4: egen group2in4 = rank(rand`x'_4group)				// in a random order
				g assignround_4group=`x'										// note which time through loop we assigned this
			}
			if `x'==1 tempfile group4											// put it in the group4 tempfile
			else append using `group4'
			sa `group4', replace
		restore
		drop if temp==2															// drop the ones that are already paired
		drop temp group_4
		}
	* if there are still leftovers
	qui count
	if `r(N)' != 0 {
		g rand_4group = runiform()
		g group_4 = floor((_n-1)/2)
		bys group_4: egen group2in4 = rank(rand_4group)
		g assignround_4group = 5
	}
	append using `group4'
	merge 1:m group_2 using `group2'											// merge back to dataset
	assert _m==3
	drop _m
	sa `group4', replace

	* CREATE GROUPS OF 8 (identical code)
	bys group_4: keep if _n==1			// keep only 1 per group_4 to make it easier to handle. later restore using tempfile.
	keep group_4 strat*
	forv x = 1/4 {						// loop over different pseudo strata
		so strat`x' group_4
		g rand`x'_8group = runiform()
		so strat`x' rand`x'_8group
		bys strat`x': g group_8 = floor((_n-1)/2) + 3*strat`x' + 1000*`x'		// pair the groups of 4 to groups of 8
		bys group_8: g temp = _N
		preserve
			keep if temp==2														// keep the real pairs
			drop temp
			qui count
			if `r(N)' != 0 {													// if there ARE real pairs
				bys group_8: egen group4in8 = rank(rand`x'_8group)				// in a random order
				g assignround_8group=`x'										// note which time through loop we assigned this
			}
			if `x'==1 tempfile group8											// put it in the group8 tempfile
			else append using `group8'
			sa `group8', replace
		restore
		drop if temp==2
		drop temp group_8
		}
	* if there are still leftovers
	qui count
	if `r(N)' != 0 {
		g rand_8group = runiform()
		g group_8 = floor((_n-1)/2)
		bys group_8: egen group4in8 = rank(rand_8group)
		g assignround_8group = 5
	}
	append using `group8'
	merge 1:m group_4 using `group4'											// merge back to dataset
	assert _m==3
	drop _m

	* SUBTREATMENT 1
	so group_2 groupin2
	gen rand_2a = runiform()
	by group_2: egen rank_rand_id2a = rank(rand_2a)
	by group_2: g temp = _N
	g TR2a = rank_rand_id2a-1 if temp==2
	replace TR2a = round(rand_2a) if temp==1		// just one leftover, and round is ok b/c we're just between 0 and 1
	drop temp

	* SUBTREATMENT 2
	so group_4 group2in4 groupin2
	g rand_2b = runiform()
	by group_4: egen rank_rand_id2b = rank(rand_2b) if group2in4==1
	g TR2b = rank_rand_id2b-1
	bys group_4 TR2a: egen sum = max(TR2b)
	replace TR2b = 1-sum if TR2b==.
	bys group_4 TR2a: g temp = _N					// find the one that was not balanced; 1 true leftover
	replace TR2b = round(rand_2b) if temp==1		// assign independently
	drop sum temp

	* SUBTREATMENT 3
	so group_8 group4in8 group2in4 groupin2
	g rand_2c = runiform()
	* 1st 4
	by group_8: egen rank_rand_id2c = rank(rand_2c) if group4in8==1 & group2in4==1
	g TR2c = rank_rand_id2c - 1 if rank_rand_id2c!=.
	bys group_4 TR2a: egen sum = max(TR2c)
	replace TR2c = 1-sum if TR2c==.
	drop sum
	* next 4
	bys group_8 TR2a TR2b: egen sum = max(TR2c)
	replace TR2c = 1-sum if TR2c==.
	bys group_8 TR2a TR2b: g temp = _N				// find the one that was not balanced; 1 true leftover
	replace TR2c = round(rand_2c) if temp==1		// assign independently
	drop sum temp

	* ADD MONITORING AND CONTROL BACK
	append using `monitorcontrol'	
	isid desa_id2

	* DEFINE SUBTREATMENTS
	la var TR2a "Min # of bids subtreatment"
	la define TR2a 0 "No min # of bids" 1 "Min # of bids"
	la values TR2a TR2a

	la var TR2b "Women quota subtreatment"
	la define TR2b 0 "No women quota" 1 "Women quota"
	la values TR2b TR2b

	la var TR2c "Enhanced supervision subtreatment"
	la define TR2c 0 "Regular supervision" 1 "Enhanced supervision"
	la values TR2c TR2c

	drop rank* rand_rank* leftovers* numvillages* 
	renpfix group Agroup


	**************************************************
	** SUB-TREATMENTS FOR MONITORING
	* A. WOMEN QUOTA / NO WOMEN QUOTA
	* B. FACILITATED MONITORING / UNFACILITATED MONITORING
	**************************************************

	* KEEP ONLY THE ONES WE NEED
	preserve
		keep if TR2_2013!=3	// monitoring and control villages
		tempfile distcontrol
		sa `distcontrol'
	restore
	drop if TR2_2013!=3


	* CREATE GROUP VARIABLES TO LOOP ON
	drop strat*
	egen strat1 = group(t2treatment kab_id TR1 TR1c), missing
	egen strat2 = group(t2treatment kab_id TR1)
	egen strat3 = group(t2treatment kab_id)
	egen strat4 = group(t2treatment)

	* CREATE GROUPS OF 2
	forv x = 1/4 {						// loop over different pseudo strata
		so strat`x' desa_id2
		g rand`x'_2group = runiform()
		so strat`x' rand`x'_2group
		bys strat`x': g group_2 = floor((_n-1)/2) + 3*strat`x' + 1000*`x'		// pair to groups of 2
		bys group_2: g temp = _N
		preserve
			keep if temp==2														// keep the real pairs
			drop temp
			qui count
			if `r(N)' != 0 {													// if there ARE real pairs
				bys group_2: egen orderin2 = rank(rand`x'_2group)				// in a random order
				g assignround_2group=`x'										// note which time through loop we assigned this
			}
			if `x'==1 tempfile group2											// put it in the group2 tempfile
			else append using `group2'
			sa `group2', replace
		restore
		drop if temp==2															// drop the ones that are already paired
		drop temp group_2
		}
	* if there are still leftovers
	qui count
	if `r(N)' != 0 {
		g rand_2group = runiform()
		g group_2 = floor((_n-1)/2)
		bys group_2: egen orderin2 = rank(rand_2group)
		g assignround_2group = 5
	}
	append using `group2'
	sa `group2', replace

	* CREATE GROUPS OF 4 (identical code)
	bys group_2: keep if _n==1			// keep only 1 per group_4 to make it easier to handle. later restore using tempfile.
	keep group_2 strat*
	forv x = 1/4 {						// loop over different pseudo strata
		so strat`x' group_2
		g rand`x'_4group = runiform()
		so strat`x' rand`x'_4group
		bys strat`x': g group_4 = floor((_n-1)/2) + 3*strat`x' + 1000*`x'		// pair the groups of 4 to groups of 8
		bys group_4: g temp = _N
		preserve
			keep if temp==2														// keep the real pairs
			drop temp
			qui count
			if `r(N)' != 0 {													// if there ARE real pairs
				bys group_4: egen orderin4 = rank(rand`x'_4group)				// in a random order
				g assignround_4group=`x'										// note which time through loop we assigned this
			}
			if `x'==1 tempfile group4											// put it in the group8 tempfile
			else append using `group4'
			sa `group4', replace
		restore
		drop if temp==2
		drop temp group_4
		}
	* if there are still leftovers
	qui count
	if `r(N)' != 0 {
		g rand_4group = runiform()
		g group_4 = floor((_n-1)/2)
		bys group_4: egen orderin4 = rank(rand_4group)
		g assignround_4group = 5
	}
	append using `group4'
	merge 1:m group_2 using `group2'											// merge back to dataset
	assert _m==3
	drop _m

	* SUBTREATMENT 1
	so group_2 orderin2
	gen rand_2d = runiform()
	by group_2: egen rank_rand_id2d = rank(rand_2d)
	by group_2: g temp = _N
	g TR2d = rank_rand_id2d-1 if temp==2
	replace TR2d = round(rand_2d) if temp==1		// just one leftover, and round is ok b/c we're just between 0 and 1
	drop temp

	* SUBTREATMENT 2
	so group_4 orderin4 orderin2
	g rand_2e = runiform()
	by group_4: egen rank_rand_id2e = rank(rand_2e) if orderin4==1
	g TR2e = rank_rand_id2e-1
	bys group_4 TR2d: egen sum = max(TR2e)
	replace TR2e = 1-sum if TR2e==.						// if no leftovers done here
	count if TR2e==. 
	if `r(N)'!=0 {
		bys group_4 TR2d: g temp = _N					// find the one that was not balanced; 1 true leftover
		replace TR2e = round(rand_2e) if temp==1		// assign independently
		local sum sum temp
	}
	else local sum sum
	assert TR2d!=.
	assert TR2e!=.
	drop `sum'


	* ADD DISTRIBUTION AND CONTROL BACK
	append using `distcontrol'	
	isid desa_id2


	* DEFINE SUBTREATMENTS
	la var TR2d "Women subtreatment (information)"
	la define TR2d 0 "No women quota" 1 "Women quota"
	la values TR2d TR2d

	la var TR2e "Facilitated monitoring subtreatment (information)"
	la define TR2e 0 "No facilitated monitoring" 1 "Facilitated monitoring"
	la values TR2e TR2e


	* CLEAN UP DATASET	
	keep  desa_id2 TR2_2013 TR2a TR2b TR2c TR2d TR2e
	gen tr_dist = TR2_2013 == 2
	gen tr_moni = TR2_2013 == 3
	foreach var of varlist  TR2_2013-tr_moni {
		rename `var' `var'_`i'
	}
	
	tempfile rand_`i'
	sa `rand_`i''
	
	if `i'>1 {
		u `rand_1', clear
		merge 1:1 desa_id2 using `rand_`i''
		assert _m==3
		drop _m
		tempfile rand_1
		sa `rand_1', replace
	}
}
	
* SAVE DATA
u `rand_1', clear
saveold "1Data/codeddata/competition/rerandomization.dta", replace
