/*******************************************************************************
RASKIN PREP - REJECTION
1Data/dofiles/prep/rejection_prep.do

SUMMARY: 
	Code variable for villages that reject the bidding treatment at some point. 
	Based on...
	(1) Summary of villages that reject the bidding process
	(2) Form 8A (Return to status quo), found in "1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx"
		and as reported in the forms
	(3) Endline village head survey questions
*******************************************************************************/

********************************************************************************
* SETUP AND MACROS *************************************************************
********************************************************************************

clear all

set more off

** DIRECTORIES
cd "$RASKIN"

********************************************************************************
* CODING ***********************************************************************
********************************************************************************

* 0. Create bidding variables we'll need later on ******************************

**** A. Win or lose, according to form F8A        ******************************

//load in data, and merge
import excel "1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx", sheet("chk_sq_info") firstrow
merge 1:m commid using "1Data/originaldata/4_CE/f8a_f"

//drop if not matched
drop if _m!=3
drop _m

//cleaning
rename f00_col c00_col
rename f07 winner
recode winner (3=0) (9=.)
replace winner = . if f08==1 //village returned to status quo
replace winner = . if commid == "309"
	
**** B. Current Distributor (At time of bidding process) --> Old Distributor ***

//merge data, drop if only in using data
merge 1:1 commid c00_col using "1Data/originaldata/4_CE/f7a_c"
rename c00_col column
keep if _m!=2
drop _m

//cleaning
recode c05 (9=.)(3=0)
rename c05 old_dist
la var old_dist "Bidder is Raskin distributor at time of bidding"

**** C. Final Steps.                              ******************************
//create and save tempfile with relevant variables
keep commid column winner old_dist f08
tempfile bidders
sa `bidders'

* 1. Rejection at community meeting to form bidding committee ******************

//load in data	
u "1Data/codeddata/competition/treatments.dta", clear 
gen commid = desa_id2

//generate dummy if village rejects treatment
gen reject_bidding = inlist(desa_id2, "746", "563", "240", "960", "229", "566")
la var reject_bidding ///
	"Village rejects bidding treatment before bidding occurs"

* 2. No Bids/Number of Bids at Bidding Meeting *********************************

preserve
	u "1Data/originaldata/4_CE/f8a_f", clear
	collapse (count) n_bidders = f00_col, by(commid)
	tempfile n
	sa `n'
restore
merge 1:1 commid using `n'

replace n_bidders = 0 if tr_dist==1 & _m==1
gen reject_nobids 	= n_bidders == 0
replace reject_nobids 	= . if reject_bidding==1
replace n_bidders 		= . if reject_bidding==1
la var n_bidders "Number of bids presented at bidding meeting"
la var reject_nobids "No bids presented at bidding meeting"

//can drop _m variable now
drop _m

* 3. Return to status quo at end of bidding meeting ****************************

preserve
	clear
	import excel "1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx", sheet("chk_sq_info") firstrow
	gen return_sq = f08 == 1
	replace return_sq = . if f08==9
	tempfile sq
	save `sq'
restore
	
merge 1:1 commid using `sq'
assert _m!=2
drop _m

*Drop if rejected in previous stage
replace return_sq = . if reject_bidding==1 | reject_nobids==1
la var return_sq "Village reverts to status quo at end of bidding meeting"
	
* 4. Winner chosen, but blocked from ever distributing *************************

**** A. All of BANDAR LAMPUNG ordered to cancel bidding results

gen kab_reject = inlist(kab_name, "KOTA BANDAR LAMPUNG")

* Doesn't matter if winner was old distributor - it's returning to them anyway
preserve
	u `bidders', clear
	keep if winner == 1
	isid commid
	keep commid old_dist
	tempfile winners
	sa `winners'
restore

merge 1:1 commid using `winners'
drop _m

replace kab_reject = 0 if old_dist==1 | return_sq == 1

*Drop if rejected in previous stage
replace kab_reject = . if reject_bidding == 1 | reject_nobids == 1

//create and save tempfile
tempfile tr
sa `tr'	
		
**** B. Rejection Based on Endline Village Head Survey.    *********************

******** GET DATA                                          *********************

	*Merge with bidding vars
	u "1Data/originaldata/3_Endline/k_rd1", clear
	gen hhea = kea
	merge m:1 hhea using `tr'
	assert _m==3
	drop _m
	keep if tr_dist==1
	
******** CREATE VARS                                       *********************

	*Did winner ever organize raskin after bidding?
	gen never_dist = rd01d == 3
	la var never_dist "Elected coordinator never organized Raskin distribution, per village head"

	*If never organized Raskin despite winning, is it because were blocked by others?
	gen reject_blocked = regexm(rd01g, "D") & never_dist==1	
	la var reject_blocked "Bidding winner blocked from distributing"

	*Coordinator distributed, but no longer
	gen some_dist = rd01f==3
	la var some_dist "Elected coordinator organized distribution, but no longer, per village head"

	*Was coordinator blocked by others after distributing at least once?
	gen some_blocked = regexm(rd01g, "D") & some_dist==1	
	la var some_blocked "Elected coordinator organized at least once, but was terminated"
	
	*Drop if rejected in previous stage
	foreach var of varlist never_dist reject_blocked some_dist some_blocked {
		replace `var' = . if reject_bidding == 1 | reject_nobids == 1 | return_sq == 1
	}
	
	replace never_dist = 1 if kab_reject == 1 		//not always captured
	replace reject_blocked = 1 if kab_reject == 1	//blocked by kab
	replace some_dist = 0 if reject_blocked == 1	//consistency
	replace some_blocked = . if some_dist == 0		//consistency
	replace some_blocked = . if reject_blocked == 1 //consistency
		
	*For how long did coordinator distribute?
	gen months_someblocked = strlen(rd01e)
	replace months_someblocked = . if some_blocked!=1
	la var months_someblocked "# months coordinator organized distribution, if terminated"

	*If Terminated, by Whom?
	forv i=1/4 {
		local letter 	: word `i' of A B C D
		local group  	: word `i' of vill_forum vill_govt kec_govt kab_govt
		local label		: word `i' of "village-level forum" "village-level government" ///
							"kecamatan government" "kabupaten/kota government"
		gen blocked_by_`group' = regexm(rd01h, "`letter'") & reject_blocked==1
		replace blocked_by_`group' = . if reject_blocked!=1
		la var blocked_by_`group' "Bidding winner blocked by `label'"
	}
	replace blocked_by_kab_govt = 1 if kab_reject == 1
	
* 5. Final Steps ***************************************************************

//keep relevant variables
keep commid hhea kea kea1 n_bidders never_dist reject* *some* blocked* return_sq old_dist

* Let old_dist = 1 if return to status quo
replace old_dist = 1 if return_sq == 1
replace old_dist = 0 if commid == "309"
rename old_dist old_win
la var old_win "Old distributor won bidding or village returned to SQ"

* Rejection of treatment at any stage
egen reject = rowmax(reject* return_sq)
la var reject "Bidding treatment rejected at any stage"

//order and sort variables
order commid hhea kea kea1 n_bidders reject reject_* return_sq blocked_* never_dist some_dist some_blocked months_someblocked 
sort reject_bidding reject_nobids reject_blocked old_win return_sq

drop if kea1!="0"

** SAVE ************************************************************************

saveold "1Data/codeddata/competition/biddingrejection.dta", replace


exit
